@@ -3,7 +3,7 @@
  *  Implement the SETVCP command
  */
 
-// Copyright (C) 2014-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -14,107 +14,88 @@
 
 #include "public/ddcutil_types.h"
 
+#include "util/error_info.h"
+#include "util/string_util.h"
+
 #include "base/core.h"
 #include "base/ddc_errno.h"
+#include "base/ddc_packets.h"
+#include "base/feature_metadata.h"
+#include "base/rtti.h"
 
-#include "vcp/vcp_feature_codes.h"
+#include "cmdline/parsed_cmd.h"
 
-#include "ddc/ddc_packet_io.h"
 #include "ddc/ddc_vcp.h"
-#include "ddc/ddc_vcp_version.h"
 
 #include "dynvcp/dyn_feature_codes.h"
 
 #include "app_setvcp.h"
 
+// Default trace class for this file
+static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_TOP;
+
 
 /** Converts a VCP feature value from string form to internal form.
+ *  Error messages are written to stderr.
  *
- *  \param   string_value
- *  \param   parsed_value    location where to return result
+ *  @param   string_value
+ *  @param   parsed_value    location where to return result
  *
- *  \return  true if conversion successful, false if not
- *
- *  \todo
- *  Consider using canonicalize_possible_hex_value()
+ *  @return  true if conversion successful, false if not
  */
 bool
 parse_vcp_value(
       char * string_value,
-      long * parsed_value)
+      int * parsed_value_loc)
 {
-   bool debug = false;
-
-   FILE * ferr = stderr;
    assert(string_value);
-   bool ok = true;
-   char buf[20];
-
+   bool debug = false;
    DBGMSF(debug, "Starting. string_value = |%s|", string_value);
-   strupper(string_value);
-   if (*string_value == 'X' ) {
-      snprintf(buf, 20, "0%s", string_value);
-      string_value = buf;
-      DBGMSF(debug, "Adjusted value: |%s|", string_value);
-   }
-   else if (*(string_value + strlen(string_value)-1) == 'H') {
-      int newlen = strlen(string_value)-1;
-      snprintf(buf, 20, "0x%.*s", newlen, string_value);
-      string_value = buf;
-      DBGMSF(debug, "Adjusted value: |%s|", string_value);
-   }
 
-   char * endptr = NULL;
-   errno = 0;
-   long longtemp = strtol(string_value, &endptr, 0 );  // allow 0xdd  for hex values
-   int errsv = errno;
-   DBGMSF(debug, "errno=%d, string_value=|%s|, &string_value=%p, longtemp = %ld, endptr=0x%02x",
-                 errsv, string_value, &string_value, longtemp, *endptr);
-   if (*endptr || errsv != 0) {
-      f0printf(ferr, "Not a number: %s\n", string_value);
+   FILE * errf = ferr();         // at app level will always be stderr
+   char * canonical = canonicalize_possible_hex_value(string_value);
+   bool ok = str_to_int(canonical, parsed_value_loc, 0);
+   free(canonical);
+   if (!ok) {
+      f0printf(errf, "Not a number: \"%s\"", string_value);
       ok = false;
    }
-   else if (longtemp < 0 || longtemp > 65535) {
-      f0printf(ferr, "Number must be in range 0..65535:  %ld\n", longtemp);
+   else if (*parsed_value_loc < 0 || *parsed_value_loc > 65535) {
+      f0printf(errf, "Number must be in range 0..65535:  %d\n", *parsed_value_loc);
       ok = false;
    }
-   else {
-      *parsed_value = longtemp;
-      ok = true;
-   }
 
-   DBGMSF(debug, "Done. *parsed_value=%ld, returning: %s", *parsed_value, sbool(ok));
+   DBGMSF(debug, "Done. *parsed_value_loc=%d, returning: %s", *parsed_value_loc, SBOOL(ok));
    return ok;
 }
 
 
-/** Parses the Set VCP arguments passed and sets the new value.
+/** Parses the arguments passed for a single feature and sets the new value.
  *
- *   \param  dh         display handle
- *   \param  feature    feature code
- *   \param  value_type indicates if a relative value
- *   \param  new_value  new feature value (as string)
- *   \param  force      attempt to set feature even if feature code unrecognized
- *   \return NULL if success, Error_Info if error
+ *   @param  dh          display handle
+ *   @param  feature     feature code
+ *   @param  value_type  indicates if a relative value
+ *   @param  new_value   new feature value (as string)
+ *   @param  force       attempt to set feature even if feature code unrecognized
+ *   @return #Error_Info if error
  */
 Error_Info *
 app_set_vcp_value(
-      Display_Handle * dh,
-      Byte             feature_code,
+      Display_Handle *  dh,
+      Byte              feature_code,
       Setvcp_Value_Type value_type,
-      char *           new_value,
-      bool             force)
+      char *            new_value,
+      bool              force)
 {
-   FILE * errf = ferr();
-   bool debug = false;
-   DBGTRC_STARTING(debug,DDCA_TRC_TOP, "feature=0x%02x, new_value=%s, value_type=%s, force=%s",
-                feature_code, new_value, setvcp_value_type_name(value_type), sbool(force));
-
    assert(new_value && strlen(new_value) > 0);
+   FILE * errf = ferr();   // at app level will always be stderr()
+   bool debug = false;
+   DBGTRC_STARTING(debug,TRACE_GROUP, "feature=0x%02x, new_value=%s, value_type=%s, force=%s",
+                feature_code, new_value, setvcp_value_type_name(value_type), sbool(force));
 
    DDCA_Status                ddcrc = 0;
    Error_Info *               ddc_excp = NULL;
-   long                       longtemp;
+   int                        itemp;
    Display_Feature_Metadata * dfm = NULL;
    bool                       good_value = false;
    DDCA_Any_Vcp_Value         vrec;
@@ -157,7 +138,7 @@ app_set_vcp_value(
    }
 
    else {  // the usual non-table case
-      good_value = parse_vcp_value(new_value, &longtemp);
+      good_value = parse_vcp_value(new_value, &itemp);
       if (!good_value) {
          f0printf(errf, "Invalid VCP value: %s\n", new_value);
          // what is better status code?
@@ -168,8 +149,6 @@ app_set_vcp_value(
       if (value_type != VALUE_TYPE_ABSOLUTE) {
          if ( !(dfm->feature_flags & DDCA_CONT) ) {
             f0printf(errf, "Relative VCP values valid only for Continuous VCP features\n");
-            // char * feature_name =  get_version_sensitive_feature_name(entry, vspec);
-            // f0printf(ferr, "Feature %s (%s) is not continuous\n", feature, feature_name);
             ddc_excp = errinfo_new2(DDCRC_INVALID_OPERATION, __func__,
                            "Relative VCP values valid only for Continuous VCP features");
             goto bye;
@@ -185,70 +164,70 @@ app_set_vcp_value(
          if (ddc_excp) {
             ddcrc = ERRINFO_STATUS(ddc_excp);
             // is message needed?
-            // char * feature_name =  get_version_sensitive_feature_name(entry, vspec);
-            // f0printf(ferr(), "Error reading feature %s (%s)\n", feature, feature_name);
-            f0printf(errf, "Getting value failed for feature %02x. rc=%s\n", feature_code, psc_desc(ddcrc));
+            f0printf(errf, "Getting value failed for feature %02x. rc=%s\n",
+                           feature_code, psc_desc(ddcrc));
             if (ddcrc == DDCRC_RETRIES)
                f0printf(errf, "    Try errors: %s\n", errinfo_causes_string(ddc_excp));
             ddc_excp = errinfo_new_with_cause3(ddcrc, ddc_excp, __func__,
-                                               "Getting value failed for feature %02x, rc=%s", feature_code, psc_desc(ddcrc));
+                          "Getting value failed for feature %02x, rc=%s",
+                          feature_code, psc_desc(ddcrc));
             goto bye;
          }
 
          if ( value_type == VALUE_TYPE_RELATIVE_PLUS) {
-            longtemp = parsed_response->cur_value + longtemp;
-            if (longtemp > parsed_response->max_value)
-               longtemp = parsed_response->max_value;
+            itemp = RESPONSE_CUR_VALUE(parsed_response) + itemp;
+            if (itemp > RESPONSE_MAX_VALUE(parsed_response))
+               itemp = RESPONSE_MAX_VALUE(parsed_response);
          }
          else {
             assert( value_type == VALUE_TYPE_RELATIVE_MINUS);
-            longtemp = parsed_response->cur_value - longtemp;
-            if (longtemp < 0)
-               longtemp = 0;
+            itemp = RESPONSE_CUR_VALUE(parsed_response)  - itemp;
+            if (itemp < 0)
+               itemp = 0;
          }
          free(parsed_response);
       }
 
       vrec.opcode        = feature_code;
       vrec.value_type    = DDCA_NON_TABLE_VCP_VALUE;
-      vrec.val.c_nc.sh = (longtemp >> 8) & 0xff;
-      // assert(vrec.val.c_nc.sh == 0);
-      vrec.val.c_nc.sl = longtemp & 0xff;
+      vrec.val.c_nc.sh = (itemp >> 8) & 0xff;
+      vrec.val.c_nc.sl = itemp & 0xff;
    }
 
    ddc_excp = ddc_set_vcp_value(dh, &vrec, NULL);
 
    if (ddc_excp) {
       ddcrc = ERRINFO_STATUS(ddc_excp);
-      switch(ddcrc) {
-      case DDCRC_VERIFY:
-            // f0printf(ferr(), "Verification failed for feature %02x\n", feature_code);
-            ddc_excp = errinfo_new_with_cause3(ddcrc, ddc_excp, __func__,
-                                               "Verification failed for feature %02x", feature_code);
-            break;
-      default:
-         // Is this proper error message?
-         // f0printf(ferr(), "Setting value failed for feature %02x. rc=%s\n", feature_code, psc_desc(ddcrc));
-         // if (ddcrc == DDCRC_RETRIES)
-         //    f0printf(ferr, "    Try errors: %s\n", errinfo_causes_string(ddc_excp));
+      if (ddcrc == DDCRC_VERIFY)
          ddc_excp = errinfo_new_with_cause3(ddcrc, ddc_excp, __func__,
-                                            "Setting value failed for feature %02x, rc=%s",
-                                            feature_code, psc_desc(ddcrc));
-      }
+                       "Verification failed for feature %02x", feature_code);
+      else
+         ddc_excp = errinfo_new_with_cause3(ddcrc, ddc_excp, __func__,
+                       "Setting value failed for feature %02x, rc=%s",
+                       feature_code, psc_desc(ddcrc));
    }
 
 bye:
    dfm_free(dfm);  // handles dfm == NULL
 
-   DBGTRC_DONE(debug, DDCA_TRC_TOP, "Returning: %s", errinfo_summary(ddc_excp));
+   DBGTRC_RET_ERRINFO(debug, TRACE_GROUP, ddc_excp, "");
    return ddc_excp;
 }
 
 
-bool app_setvcp(Parsed_Cmd * parsed_cmd, Display_Handle * dh)
+/** Execute command SETVCP
+ *
+ *  @param  parsed_cmd  parsed command
+ *  @param  dh          display handle
+ *  @return status code
+ */
+Status_Errno_DDC
+app_setvcp(Parsed_Cmd * parsed_cmd, Display_Handle * dh)
 {
-   bool ok = true;
+   bool debug = false;
+   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s", dh_repr(dh));
    Error_Info * ddc_excp = NULL;
+   Status_Errno_DDC ddcrc = 0;
    for (int ndx = 0; ndx < parsed_cmd->setvcp_values->len; ndx++) {
       Parsed_Setvcp_Args * cur =
             &g_array_index(parsed_cmd->setvcp_values, Parsed_Setvcp_Args, ndx);
@@ -262,11 +241,17 @@ bool app_setvcp(Parsed_Cmd * parsed_cmd, Display_Handle * dh)
          f0printf(ferr(), "%s\n", ddc_excp->detail);
          if (ddc_excp->status_code == DDCRC_RETRIES)
             f0printf(ferr(), "    Try errors: %s\n", errinfo_causes_string(ddc_excp));
-         ERRINFO_FREE_WITH_REPORT(ddc_excp, report_freed_exceptions);
-         ok = false;
+         ddcrc = ERRINFO_STATUS(ddc_excp);
+         ERRINFO_FREE_WITH_REPORT(ddc_excp, debug || IS_TRACING() || report_freed_exceptions);
          break;
       }
    }
-return ok;
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, ddcrc,"");
+   return ddcrc;
 }
 
+
+void init_app_setvcp() {
+   RTTI_ADD_FUNC(app_setvcp);
+   RTTI_ADD_FUNC(app_set_vcp_value);
+}
