@@ -14,8 +14,10 @@
 #include <errno.h>
 #include <glib-2.0/glib.h>
 #include <setjmp.h>
+#include <sys/stat.h>
 #include <stdbool.h>
 #include <stdio.h>
+
 #include <stdlib.h>
 #include <string.h>
 #include <syslog.h>
@@ -27,6 +29,7 @@
 #include "util/failsim.h"
 #include "util/file_util.h"
 #include "util/glib_string_util.h"
+#include "util/i2c_util.h"
 #include "util/linux_util.h"
 #include "util/report_util.h"
 #include "util/simple_ini_file.h"
@@ -57,7 +60,7 @@
 #include "base/thread_sleep_data.h"
 #include "base/tuned_sleep.h"
 
-#include "ddc/common_init.h"
+#include "i2c/i2c_sysfs.h"
 
 #include "vcp/parse_capabilities.h"
 #include "vcp/persistent_capabilities.h"
@@ -73,7 +76,10 @@
 #include "usb/usb_displays.h"
 #endif
 
+#include "ddc/ddc_common_init.h"
 #include "ddc/ddc_displays.h"
+#include "ddc/ddc_display_ref_reports.h"
+#include "ddc/ddc_display_selection.h"
 #include "ddc/ddc_multi_part_io.h"
 #include "ddc/ddc_output.h"
 #include "ddc/ddc_packet_io.h"
@@ -96,8 +102,10 @@
 #include "app_ddcutil/app_interrogate.h"
 #include "app_ddcutil/app_probe.h"
 #include "app_ddcutil/app_getvcp.h"
+#include "app_ddcutil/app_services.h"
 #include "app_ddcutil/app_setvcp.h"
 #include "app_ddcutil/app_vcpinfo.h"
+#include "app_ddcutil/app_watch.h"
 #ifdef INCLUDE_TESTCASES
 #include "app_ddcutil/app_testcases.h"
 #endif
@@ -114,28 +122,19 @@ static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_TOP;
 static void add_rtti_functions();
 
 
-static bool detect_ddcci(Parsed_Cmd * parsed_cmd) {
-   bool detected = false;
-   if ( directory_exists("/dev/bus/ddcci") && (!(parsed_cmd->flags & CMD_FLAG_FORCE_SLAVE_ADDR)) ) {
-      f0printf(fout(), "Driver ddcci is loaded. "
-                       "ddcutil may require option --force-slave-address to recover from EBUSY errors.\n");
-      detected = true;
-   }
-   return detected;
-}
-
 //
 // Report core settings and command line options
 //
 
-
 static void
 report_performance_options(int depth)
 {
       int d1 = depth+1;
       rpt_label(depth, "Performance and Retry Options:");
       rpt_vstring(d1, "Deferred sleep enabled:                      %s", sbool( is_deferred_sleep_enabled() ) );
+#ifdef OLD   // SLEEP_SUPPRESSION
       rpt_vstring(d1, "Sleep suppression (reduced sleeps) enabled:  %s", sbool( is_sleep_suppression_enabled() ) );
+#endif
       bool dsa_enabled =  tsd_get_dsa_enabled_default();
       rpt_vstring(d1, "Dynamic sleep adjustment enabled:            %s", sbool(dsa_enabled) );
       if ( dsa_enabled )
@@ -146,8 +145,6 @@ report_performance_options(int depth)
 
 static void
 report_optional_features(Parsed_Cmd * parsed_cmd, int depth) {
-   rpt_vstring( depth, "%.*s%-*s%s", 0, "", 28, "Force I2C slave address:",
-                       sbool(i2c_force_slave_addr_flag));
    rpt_vstring( depth, "%.*s%-*s%s", 0, "", 28, "User defined features:",
                        (enable_dynamic_features) ? "enabled" : "disabled" );
                        // "Enable user defined features" is too long a title
@@ -172,6 +169,7 @@ report_all_options(Parsed_Cmd * parsed_cmd, char * config_fn, char * default_opt
        report_build_options(depth);
     show_reporting();  // uses fout()
     report_optional_features(parsed_cmd, depth);
+    report_tracing(depth);
     report_performance_options(depth);
     report_experimental_options(parsed_cmd, depth);
 
@@ -183,38 +181,59 @@ report_all_options(Parsed_Cmd * parsed_cmd, char * config_fn, char * default_opt
 // Initialization functions called only once but factored out of main() to clarify mainline
 //
 
+#ifdef UNUSED
 #ifdef TARGET_LINUX
 
 static bool
 validate_environment_using_libkmod()
 {
    bool debug = false;
-   DBGMSF(debug, "Starting");
+   DBGTRC_STARTING(debug, TRACE_GROUP, "");
 
    bool ok = false;
-   if (is_module_loaded_using_sysfs("i2c_dev")) {
+   if (is_module_loaded_using_sysfs("i2c_dev")) {  // only finds loadable modules, not those built into kernel
       ok = true;
    }
    else {
       int module_status = module_status_using_libkmod("i2c-dev");
-      if (module_status < 0) {
+      if (module_status == 0) {   // MODULE_STATUS_NOT_FOUND
+         ok = false;
+         fprintf(stderr, "Module i2c-dev is not loaded and not built into the kernel.\n");
+      }
+      else if (module_status == KERNEL_MODULE_BUILTIN) {   // 1
+         ok = true;
+      }
+      else if (module_status == KERNEL_MODULE_LOADABLE_FILE) {   //
+
+         int rc = is_module_loaded_using_libkmod("i2c_dev");
+         if (rc == 0) {
+            fprintf(stderr, "Loadable module i2c-dev exists but is not loaded.\n");
+            ok = false;
+         }
+         else if (rc == 1) {
+            ok = true;
+         }
+         else {
+            assert(rc < 0);
+            fprintf(stderr, "ddcutil cannot determine if loadable module i2c-dev is loaded.\n");
+            ok = true;  // make this just a warning, we'll fail later if not in kernel
+            fprintf(stderr, "Execution may fail.\n");
+         }
+      }
+
+      else {
+         assert(module_status < 0);
          fprintf(stderr, "ddcutil cannot determine if module i2c-dev is loaded or built into the kernel.\n");
          ok = true;  // make this just a warning, we'll fail later if not in kernel
          fprintf(stderr, "Execution may fail.\n");
       }
-      else if (module_status == 0) {   // MODULE_STATUS_NOT_FOUND
-         ok = false;
-         fprintf(stderr, "Module i2c-dev is not loaded and not built into the kernel.\n");
-      }
-      else {
-          ok = true;
-      }
    }
 
-   DBGMSF(debug, "Done.    Returning: %s", sbool(ok));
+   DBGTRC_RET_BOOL(debug, TRACE_GROUP, ok, "");
    return ok;
 }
 #endif
+#endif
 
 
 static bool
@@ -224,6 +243,11 @@ validate_environment()
    DBGMSF(debug, "Starting");
    bool ok;
 
+   ok = dev_i2c_devices_exist();
+   if (!ok)
+      fprintf(stderr, "No /dev/i2c devices exist.\n");
+
+#ifdef OLD
 #ifdef TARGET_LINUX
    if (is_module_loaded_using_sysfs("i2c_dev")) {
       ok = true;
@@ -234,10 +258,12 @@ validate_environment()
 #else
    ok = true;
 #endif
+#endif
+
    if (!ok) {
-      fprintf(stderr, "ddcutil requires module i2c-dev\n");
+      fprintf(stderr, "ddcutil requires module i2c-dev.\n");
       // DBGMSF(debug, "Forcing ok = true");
-      ok = true;  // make it just a warning in case we're wrong
+      // ok = true;  // make it just a warning in case we're wrong
    }
 
    DBGMSF(debug, "Done.    Returning: %s", sbool(ok));
@@ -245,6 +271,69 @@ validate_environment()
 }
 
 
+static void verify_i2c_access() {
+   bool debug = false;
+   DBGMSF(debug, "Starting");
+
+   Bit_Set_256 buses_without_devices = EMPTY_BIT_SET_256;
+   Bit_Set_256 inaccessible_devices  = EMPTY_BIT_SET_256;
+
+   Bit_Set_256 buses = get_possible_ddc_ci_bus_numbers();  //sysfs bus numbers, not dev-i2c
+   DBGMSF(debug, "I2C buses to check: %s", bs256_to_string(buses, "x", " "));
+   if (bs256_count(buses) > 0) {
+      Bit_Set_256_Iterator iter = bs256_iter_new(buses);
+      int busno;
+      while ( (busno = bs256_iter_next(iter)) >= 0)  {
+         char fnbuf[20];   // oversize to avoid -Wformat-truncation error
+         snprintf(fnbuf, sizeof(fnbuf), "/dev/i2c-%d", busno);
+         int rc;
+         int errsv;
+         // DBGMSF(debug, "Calling access() for %s", fnbuf);
+         rc = access(fnbuf, R_OK|W_OK);
+         if (rc < 0) {
+            errsv = errno;   // EACCESS if lack permissions, ENOENT if file doesn't exist
+            if (errsv == ENOENT) {
+               buses_without_devices = bs256_insert(buses_without_devices, busno);
+               rpt_vstring(0, "Device %s does not exist. Error = %s",
+                              fnbuf, linux_errno_desc(errsv));
+            }
+            else {
+               assert(errsv == EACCES);
+               inaccessible_devices = bs256_insert(inaccessible_devices, busno);
+               rpt_vstring(0,"Device %s is not readable and writable.  Error = %s",
+                           fnbuf, linux_errno_desc(errsv) );
+               include_open_failures_reported(busno);
+            }
+         }
+      }
+      bs256_iter_free(iter);
+   }
+
+   // DBGMSF(debug, "buses: %d", bs256_count(buses));
+   // DBGMSF(debug, "buses_without_devices: %d", bs256_count(buses_without_devices));
+   // DBGMSF(debug, "inaccessible_devices: %d",  bs256_count(inaccessible_devices));
+   if (bs256_count(buses) == 0) {
+      printf("No display adapters with i2c buses exist.\n");
+      printf("No /sys/bus/i2c buses that might be used for DDC/CI communication exist.\n");
+   }
+   else {
+      if (bs256_count(buses_without_devices) > 0) {
+         printf("/sys/bus/i2c buses without /dev/i2c-N devices: %s\n",
+                bs256_to_string_decimal(buses_without_devices, "/sys/bus/i2c/devices/i2c-", " ") );
+         printf("Driver i2c_dev must be loaded or builtin\n");
+         printf("See https://www.ddcutil.com/kernel_module\n");
+      }
+      if (bs256_count(inaccessible_devices) > 0) {
+         printf("Devices possibly used for DDC/CCI communication cannot be opened: %s\n",
+                bs256_to_string_decimal(inaccessible_devices, "/dev/i2c-", " "));
+         printf("See https://www.ddcutil.com/i2c_permissions\n");
+      }
+   }
+
+   DBGMSF(debug, "Done");
+}
+
+
 /** Master initialization function
  *
  *   \param  parsed_cmd  parsed command line
@@ -409,7 +498,7 @@ find_dref(
    }  // !DISP_ID_BUSNO
 
    *dref_loc = dref;
-   DBGTRC_RETURNING(debug, TRACE_GROUP, final_result,
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, final_result,
                  "*dref_loc = %p -> %s",
                  *dref_loc,
                  dref_repr_t(*dref_loc) );
@@ -433,7 +522,7 @@ execute_cmd_with_optional_display_handle(
       Display_Handle * dh)
 {
    bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "dh = %p -> %s", dh, dh_repr_t(dh));
+   DBGTRC_STARTING(debug, TRACE_GROUP, "dh = %p -> %s", dh, dh_repr(dh));
    int main_rc = EXIT_SUCCESS;
 
    if (dh) {
@@ -456,15 +545,15 @@ execute_cmd_with_optional_display_handle(
          // loadvcp will search monitors to find the one matching the
          // identifiers in the record
          ddc_ensure_displays_detected();
-         bool loadvcp_ok = loadvcp_by_file(parsed_cmd->args[0], dh);
-         main_rc = (loadvcp_ok) ? EXIT_SUCCESS : EXIT_FAILURE;
+         Status_Errno_DDC ddcrc = app_loadvcp_by_file(parsed_cmd->args[0], dh);
+         main_rc = (ddcrc == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
          break;
       }
 
    case CMDID_CAPABILITIES:
       {
          assert(dh);
-         check_dynamic_features(dh->dref);
+         app_check_dynamic_features(dh->dref);
          ensure_vcp_version_set(dh);
 
          DDCA_Status ddcrc = app_capabilities(dh);
@@ -475,7 +564,7 @@ execute_cmd_with_optional_display_handle(
    case CMDID_GETVCP:
       {
          assert(dh);
-         check_dynamic_features(dh->dref);
+         app_check_dynamic_features(dh->dref);
          ensure_vcp_version_set(dh);
 
          Public_Status_Code psc = app_show_feature_set_values_by_dh(dh, parsed_cmd);
@@ -486,11 +575,11 @@ execute_cmd_with_optional_display_handle(
    case CMDID_SETVCP:
       {
          assert(dh);
-         check_dynamic_features(dh->dref);
+         app_check_dynamic_features(dh->dref);
          ensure_vcp_version_set(dh);
 
-         bool ok = app_setvcp(parsed_cmd, dh);
-         main_rc = (ok) ? EXIT_SUCCESS : EXIT_FAILURE;
+         int rc = app_setvcp(parsed_cmd, dh);
+         main_rc = (rc == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
       }
       break;
 
@@ -523,11 +612,11 @@ execute_cmd_with_optional_display_handle(
       {
          assert(dh);
          // MCCS vspec can affect whether a feature is NC or TABLE
-         check_dynamic_features(dh->dref);
+         app_check_dynamic_features(dh->dref);
          ensure_vcp_version_set(dh);
 
          Public_Status_Code psc =
-               dumpvcp_as_file(dh, (parsed_cmd->argct > 0)
+               app_dumpvcp_as_file(dh, (parsed_cmd->argct > 0)
                                       ? parsed_cmd->args[0]
                                       : NULL );
          main_rc = (psc==0) ? EXIT_SUCCESS : EXIT_FAILURE;
@@ -536,7 +625,7 @@ execute_cmd_with_optional_display_handle(
 
    case CMDID_READCHANGES:
       assert(dh);
-      check_dynamic_features(dh->dref);
+      app_check_dynamic_features(dh->dref);
       ensure_vcp_version_set(dh);
 
       app_read_changes_forever(dh, parsed_cmd->flags & CMD_FLAG_X52_NO_FIFO);     // only returns if fatal error
@@ -545,7 +634,7 @@ execute_cmd_with_optional_display_handle(
 
    case CMDID_PROBE:
       assert(dh);
-      check_dynamic_features(dh->dref);
+      app_check_dynamic_features(dh->dref);
       ensure_vcp_version_set(dh);
 
       app_probe_display_by_dh(dh);
@@ -579,6 +668,10 @@ execute_cmd_with_optional_display_handle(
 int
 main(int argc, char *argv[]) {
    bool main_debug = false;
+   char * s = getenv("DDCUTIL_DEBUG_MAIN");
+   if (s && strlen(s) > 0)
+      main_debug = true;
+
    int main_rc = EXIT_FAILURE;
    bool start_time_reported = false;
 
@@ -686,11 +779,19 @@ main(int argc, char *argv[]) {
       }
    }
 
+   if (parsed_cmd->flags & CMD_FLAG_F2) {
+      consolidated_i2c_sysfs_report(0);
+      // rpt_label(0, "*** Tests Done ***");
+      // rpt_nl();
+   }
+
    Call_Options callopts = CALLOPT_NONE;
-   i2c_force_slave_addr_flag = parsed_cmd->flags & CMD_FLAG_FORCE_SLAVE_ADDR;
    if (parsed_cmd->flags & CMD_FLAG_FORCE)
       callopts |= CALLOPT_FORCE;
 
+   // affects all current threads and new threads
+   tsd_dsa_enable_globally(parsed_cmd->flags & CMD_FLAG_DSA);
+
    main_rc = EXIT_SUCCESS;     // from now on assume success;
    DBGTRC_NOPREFIX(main_debug, TRACE_GROUP, "Initialization complete, process commands");
 
@@ -715,7 +816,8 @@ main(int argc, char *argv[]) {
 
    else if (parsed_cmd->cmd_id == CMDID_DETECT) {
       DBGTRC_NOPREFIX(main_debug, TRACE_GROUP, "Detecting displays...");
-      detect_ddcci(parsed_cmd);
+      verify_i2c_access();
+
       if ( parsed_cmd->flags & CMD_FLAG_F4) {
          test_display_detection_variants();
       }
@@ -770,15 +872,14 @@ main(int argc, char *argv[]) {
 
 #ifdef ENABLE_ENVCMDS
    else if (parsed_cmd->cmd_id == CMDID_INTERROGATE) {
-      interrogate(parsed_cmd);
+      app_interrogate(parsed_cmd);
       main_rc = EXIT_SUCCESS;
    }
 #endif
 
    // *** Commands that may require Display Identifier ***
    else {
-      detect_ddcci(parsed_cmd);
-
+      verify_i2c_access();
       Display_Ref * dref = NULL;
       Status_Errno_DDC  rc =
       find_dref(parsed_cmd,
@@ -801,8 +902,7 @@ main(int argc, char *argv[]) {
          }  // dref
 
          if (main_rc == EXIT_SUCCESS) {
-            // affects all current threads and new threads
-            tsd_dsa_enable_globally(parsed_cmd->flags & CMD_FLAG_DSA);
+
             main_rc = execute_cmd_with_optional_display_handle(parsed_cmd, dh);
          }
 
@@ -850,9 +950,10 @@ static void add_rtti_functions() {
    RTTI_ADD_FUNC(main);
    RTTI_ADD_FUNC(execute_cmd_with_optional_display_handle);
    RTTI_ADD_FUNC(find_dref);
-#ifdef ENABLE_ENVCMDS
-   RTTI_ADD_FUNC(interrogate);
+#ifdef UNUSED
+#ifdef TARGET_LINUX
+   RTTI_ADD_FUNC(validate_environment_using_libkmod);
 #endif
-   init_app_capabilities();
-   init_app_dumpload();
+#endif
+   init_app_services();
 }
