@@ -9,7 +9,7 @@
 // #define SYSENV_QUICK_TEST_RUN 1
 
 /** \cond */
-#include <config.h>
+#include "config.h"
 
 // #define _GNU_SOURCE 1       // for function group_member
 #include <assert.h>
@@ -44,11 +44,13 @@
 #include "base/build_info.h"
 #include "base/core.h"
 #include "base/linux_errno.h"
+#include "base/parms.h"
 #include "base/rtti.h"
 
 #include "i2c/i2c_sysfs.h"
 
 #include "ddc/ddc_displays.h"     // for ddc_ensure_displays_detected()
+#include "ddc/ddc_display_ref_reports.h"
 #include "ddc/ddc_watch_displays.h"
 
 #include "query_sysenv_access.h"
@@ -311,7 +313,7 @@ void query_x11() {
 
       rpt_label  (2, "Raw EDID:");
       rpt_hex_dump(edidbytes, 128, 2);
-      Parsed_Edid * parsed_edid = create_parsed_edid(edidbytes);
+      Parsed_Edid * parsed_edid = create_parsed_edid2(edidbytes, "X11");
       if (parsed_edid) {
          report_parsed_edid_base(
                parsed_edid,
@@ -727,10 +729,11 @@ void query_sysenv() {
    char * s = getenv("SYSENV_QUICK_TEST");
    if (s && strlen(s) > 0) {
       sysfs_quick_test = true;
-      rpt_label(0, "Environment variable SYSFS_QUICK_TEST is set.  Skipping some tests.");
+      rpt_label(0, "Environment variable SYSENV_QUICK_TEST is set.  Skipping some tests.");
+   }
+   else if (get_output_level() >= DDCA_OL_VERBOSE) {
+      rpt_label(0, "Set environment variable SYSENV_QUICK_TEST to skip some long-running tests.");
    }
-
-   i2c_force_slave_addr_flag = true;    // be a bully
 
    ddc_ensure_displays_detected();
    DBGTRC_NOPREFIX(debug, TRACE_GROUP, "display detection complete");
@@ -942,6 +945,8 @@ void query_sysenv() {
 #endif
 
       query_xdg_files(0);
+
+      rpt_label(0, "*** environment command complete ***");
    }
 
    env_accumulator_free(accumulator);     // make Coverity happy
