@@ -3,7 +3,7 @@
  * Check I2C devices using directly coded I2C calls
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -11,7 +11,7 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <linux/i2c-dev.h>
-#include <i2c/smbus.h>
+
 #include <limits.h>
 #include <sys/ioctl.h>
 #include <unistd.h>
@@ -23,6 +23,7 @@
 #include "util/sysfs_i2c_util.h"
 #include "util/sysfs_util.h"
 
+#include "base/parms.h"
 #include "base/core.h"
 #include "base/ddc_errno.h"
 #include "base/linux_errno.h"
@@ -30,6 +31,7 @@
 /** \endcond */
 
 #include "i2c/i2c_bus_core.h"
+#include "i2c/i2c_execute.h"
 
 #include "query_sysenv_base.h"
 #include "query_sysenv_sysfs.h"
@@ -39,7 +41,8 @@
 
 
 // Auxiliary function for raw_scan_i2c_devices()
-static bool is_i2c_device_rw(int busno) {
+static
+bool is_i2c_device_rw(int busno) {
    bool debug = false;
    DBGMSF(debug, "Starting. busno=%d", busno);
 
@@ -67,18 +70,17 @@ static bool is_i2c_device_rw(int busno) {
 // Auxiliary function for raw_scan_i2c_devices()
 // adapted from ddc_vcp_tests
 
-static Public_Status_Code
-try_single_getvcp_call(
+static
+Public_Status_Code try_single_getvcp_call(
       int           fh,
       unsigned char vcp_feature_code,
-      bool          use_smbus,
+//    bool          use_smbus,
       int           depth)
 {
    bool debug = false;
    // rpt_nl();
    // DBGMSF(true, "Starting. vcp_feature_code=0x%02x. use_smbus=%s", vcp_feature_code, sbool(use_smbus) );
-   rpt_vstring(depth, "%s: vcp_feature_code=0x%02x, use_smbus=%s", __func__,
-                       vcp_feature_code, sbool(use_smbus) );
+   rpt_vstring(depth, "%s: vcp_feature_code=0x%02x", __func__, vcp_feature_code );
 
    int ndx;
    Status_Errno rc = 0;
@@ -111,69 +113,27 @@ try_single_getvcp_call(
       ddc_cmd_bytes[5] ^= ddc_cmd_bytes[ndx];    // calculate checksum
    int writect = sizeof(ddc_cmd_bytes)-1;
    rpt_vstring(depth, "Sending Get VCP Feature Command request packet: %s", hexstring_t(ddc_cmd_bytes+1, writect));
-   rc = write(fh, ddc_cmd_bytes+1, writect);
+   rc = i2c_ioctl_writer(fh, 0x37, writect, ddc_cmd_bytes+1);
    if (rc < 0) {
       int errsv = errno;
-      DBGMSF(debug, "write() failed, errno=%s", linux_errno_desc(errsv));
+      DBGMSF(debug, "write failed, errno=%s", linux_errno_desc(errsv));
       rc = -errsv;
       goto bye;
    }
-   if (rc != writect) {
-      DBGMSF(debug, "write() returned %d, expected %d", rc, writect );
-      rc = DDCRC_DDC_DATA;    // was DDCRC_BAD_BYTECT
-      goto bye;
-   }
    usleep(50000);
 
    unsigned char ddc_response_bytes[12];
    int readct = sizeof(ddc_response_bytes)-1;
 
    rpt_vstring(depth, "Reading Get Feature Reply response packet");
-
-   if (use_smbus) {   // FAILS, reads 6e 6e 6e ...
-      unsigned long functionality = i2c_get_functionality_flags_by_fd(fh);
-       if (!(functionality & I2C_FUNC_SMBUS_READ_BYTE)) {
-          rpt_vstring(depth, "File descriptor %d does not support I2C_FUNC_SMBUS_READ_BYTE", fh);
-          rc = DDCRC_UNIMPLEMENTED;
-          goto bye;
-       }
-       int actual_ct = 0;
-       rc = 0;
-       int ndx = 0;
-       __s32 smbus_result = 0;
-       for (; ndx < readct && rc == 0; ndx++) {
-          smbus_result = i2c_smbus_read_byte_data(fh, ndx);
-          DBGMSF(debug, "ndx=%d, smbus_result = 0x%08x, %d", ndx, smbus_result, smbus_result);
-          if (smbus_result < 0)
-             rc = -errno;
-          else {
-             ddc_response_bytes[ndx+1] = smbus_result;
-             actual_ct = ndx+1;
-          }
-       }
-       if (rc < 0) {
-          rpt_vstring(depth,"i2c_smbus_read_byte_data() failed. errno = %s",
-                            linux_errno_desc(errno));
-          goto bye;
-       }
-       rpt_vstring(depth+1, "%d bytes were read", actual_ct);
-       rpt_vstring(depth, "ddc_response_bytes+1-> %s", hexstring_t(ddc_response_bytes+1,actual_ct) );
+   rc = i2c_ioctl_reader(fh, 0x37, false, readct, ddc_response_bytes+1);
+   if (rc < 0) {
+      rc = -errno;
+      DBGMSF(debug, "read failed, errno=%s", linux_errno_desc(-rc));
+      goto bye;
    }
-   else {
-      rc = read(fh, ddc_response_bytes+1, readct);
-      if (rc < 0) {
-         rc = -errno;
-         DBGMSF(debug, "read() failed, errno=%s", linux_errno_desc(-rc));
-         goto bye;
-      }
-      rpt_vstring(depth, "read() returned %s", hexstring_t(ddc_response_bytes+1,rc) );
+   rpt_vstring(depth, "read returned %s", hexstring_t(ddc_response_bytes+1,rc) );
 
-      if (rc != readct) {
-         DBGMSF(debug, "read() returned %d, should be %d", rc, readct );
-         rc = DDCRC_DDC_DATA;    // was DDCRC_BAD_BYTECT
-         goto bye;
-      }
-   }
    if ( all_bytes_zero( ddc_response_bytes+1, readct) ) {
       DBGMSF(debug, "All bytes zero");
       rc = DDCRC_READ_ALL_ZERO;
@@ -247,20 +207,18 @@ bye:
    return rc;
 }
 
-
-bool simple_read_edid(
+static bool simple_ioctl_read_edid(
       int  busno,
       int  read_size,
       bool write_before_read,
-      bool use_smbus,
       int  depth)
 {
    assert(read_size == 128 || read_size == 256);
    rpt_nl();
-   rpt_vstring(depth, "Attempting simple %d byte EDID read of /dev/i2c-%d, %s initial write() using %s",
+   rpt_vstring(depth, "Attempting simple %d byte EDID read of /dev/i2c-%d, %s initial write",
                   read_size, busno,
-                  (write_before_read) ? "WITH" : "WITHOUT",
-                  (use_smbus) ?  "i2c_smbus_read_byte_data()" : "read()");
+                  (write_before_read) ? "WITH" : "WITHOUT"
+                  );
    int rc = 0;
    char i2cdev[20];
    Byte edid_buf[256];
@@ -271,82 +229,30 @@ bool simple_read_edid(
       rpt_vstring(depth, "Open failed for %s, errno=%s", i2cdev, linux_errno_desc(errno));
    }
    else {
-      uint16_t op = I2C_SLAVE;
-      rc = ioctl(fd, op, 0x50);
-      int errsv = 0;
-      if (rc < 0) {
-         errsv = errno;
-         rpt_vstring(depth, "ioctl I2C_SLAVE returned errno=%s", linux_errno_desc(errno));
-         if (errsv == EBUSY) {
-            rpt_label(depth, "Retrying ioctl I2C_SLAVE_FORCE...");
-            errno = 0;
-            op = I2C_SLAVE_FORCE;
-            rc = ioctl(fd, op, 0x50);
-            if (rc < 0) {
-               rpt_vstring(depth, "ioctl(I2C_FORCE_SLACE) returned %s", linux_errno_desc(errno));
-            }
-         }
-         if (rc < 0) {
-            goto close;
-         }
-      }
       if (write_before_read) {
          edid_buf[0] = 0x00;
-         rc = write(fd, edid_buf, 1);
+         rc = i2c_ioctl_writer(fd, 0x50, 1, edid_buf);
          if (rc < 0) {
-            rpt_vstring(depth, "write() of 1 byte failed, errno = %s", linux_errno_desc(errno));
+            rpt_vstring(depth, "write of 1 byte failed, errno = %s", linux_errno_desc(errno));
             rpt_label(depth, "Continuing");
          }
       }
-
-      int actual_ct = 0;
-      if (use_smbus) {
-         unsigned long functionality = i2c_get_functionality_flags_by_fd(fd);
-         if (!(functionality & I2C_FUNC_SMBUS_READ_BYTE)) {
-            rpt_vstring(depth, "%s does not support I2C_FUNC_SMBUS_READ_BYTE", i2cdev);
-         }
-         else {
-            rc = 0;
-            int ndx = 0;
-            __s32 smbus_result = 0;
-            for (; ndx < read_size && rc == 0; ndx++) {
-               smbus_result = i2c_smbus_read_byte_data(fd, ndx);
-               // DBGMSG("smbus_result = 0x%08x, %d", smbus_result, smbus_result);
-               if (smbus_result < 0)
-                  rc = -errno;
-               else {
-                  edid_buf[ndx] = smbus_result;
-                  actual_ct = ndx+1;
-               }
-            }
-            if (rc < 0) {
-               rpt_vstring(depth,"i2c_smbus_read_byte_data() failed. errno = %s",
-                                 linux_errno_desc(errno));
-               goto close;
-            }
-            rpt_vstring(depth+1, "%d bytes were read", actual_ct);
-            rpt_hex_dump(edid_buf, actual_ct, depth+1);
-            ok = true;
-         }
+      rc = i2c_ioctl_reader(fd, 0x50, false, read_size, edid_buf);
+      if (rc < 0) {
+         rpt_vstring(depth,"read failed. errno = %s", linux_errno_desc(errno));
       }
       else {
-         actual_ct = read(fd, edid_buf, read_size);
-         if (actual_ct < 0) {
-            rpt_vstring(depth,"read failed. errno = %s", linux_errno_desc(errno));
-            goto close;
-         }
-         rpt_vstring(depth, "read() returned %d bytes", actual_ct);
-         rpt_hex_dump(edid_buf, actual_ct, depth+1);
+         rpt_hex_dump(edid_buf, read_size, depth+1);
          ok = true;
       }
 
-close:
       close(fd);
    }
    return ok;
 }
 
 
+
 void test_edid_read_variants(Env_Accumulator * accum) {
    bool debug = false;
    DBGMSF(debug, "Starting");
@@ -375,36 +281,19 @@ void test_edid_read_variants(Env_Accumulator * accum) {
          if (!is_i2c_device_rw(busno))   // issues message if not RW
             continue;
 
-         rpt_label(d2, "Tests using read()...");
+         rpt_label(d2, "Tests using ioctl write and read...");
          bool ok = false;
-         rpt_label(d2, "Without write() before read()...");
-         ok = simple_read_edid(busno, 128, false, false, d2);
+         rpt_label(d2, "Without write before read...");
+         ok = simple_ioctl_read_edid(busno, 128, false, d2);
          if (!ok)
-            simple_read_edid(busno, 128, false, false, d2);
-         simple_read_edid(busno, 256, false, false, d2);
+            simple_ioctl_read_edid(busno, 128, false, d2);
+         simple_ioctl_read_edid(busno, 256, false, d2);
          rpt_nl();
-         rpt_label(d2, "Retrying with write() before read()...");
-         ok = simple_read_edid(busno, 128, true, false, d2);
+         rpt_label(d2, "Retrying with write before read...");
+         ok = simple_ioctl_read_edid(busno, 128, true, d2);
          if (!ok)
-            simple_read_edid(busno, 128, true, false, d2);
-         simple_read_edid(busno, 256, true, false, d2);
-         rpt_nl();
-
-         rpt_label(d2, "Tests using i2c_smbus_read_byte_data()...");
-#ifdef FAIL
-         // hang observed w/o write, using i2c_smbus_read_byte_data()
-         rpt_label(d2, "Without write() before read()...");
-         ok = simple_read_edid(busno, 128, false, true, d2);
-         if (!ok)
-            simple_read_edid(busno, 128, false, true, d2);
-         simple_read_edid(busno, 256, false, true, d2);
-         rpt_nl();
-#endif
-         rpt_label(d2, "Retrying with write() before read()...");
-         ok = simple_read_edid(busno, 128, true, true, d2);
-         if (!ok)
-            simple_read_edid(busno, 128, true, true, d2);
-         simple_read_edid(busno, 256, true, true, d2);
+            simple_ioctl_read_edid(busno, 128, true, d2);
+         simple_ioctl_read_edid(busno, 256, true, d2);
          rpt_nl();
       }
    }
@@ -440,8 +329,7 @@ void raw_scan_i2c_devices(Env_Accumulator * accum) {
    Buffer * buf0 = buffer_new(1000, __func__);
    int  busct = 0;
    Public_Status_Code psc;
-   Status_Errno rc;
-   bool saved_i2c_force_slave_addr_flag = i2c_force_slave_addr_flag;
+   Status_Errno rc = 0;
 
    for (int busno=0; busno < I2C_BUS_MAX; busno++) {
       if (i2c_device_exists(busno)) {
@@ -480,7 +368,7 @@ void raw_scan_i2c_devices(Env_Accumulator * accum) {
             else {
                rpt_label(d2, "Raw EDID:");
                rpt_hex_dump(buf0->bytes, buf0->len, d2);
-               edid = create_parsed_edid(buf0->bytes);
+               edid = create_parsed_edid2(buf0->bytes, "I2C");
                if (edid) {
                   report_parsed_edid_base(
                      edid,
@@ -516,12 +404,11 @@ void raw_scan_i2c_devices(Env_Accumulator * accum) {
 
          rpt_nl();
          rpt_vstring(d2, "Trying simple VCP read of feature 0x10...");
-         rc = i2c_set_addr(fd, 0x37, CALLOPT_ERR_MSG);
          if (rc == 0) {
             int maxtries = 3;
             psc = -1;
             for (int tryctr=0; tryctr<maxtries && psc < 0; tryctr++) {
-               psc = try_single_getvcp_call(fd, 0x10, false, d2);
+               psc = try_single_getvcp_call(fd, 0x10, d2);
                if (psc == 0 || psc == DDCRC_NULL_RESPONSE || psc == DDCRC_REPORTED_UNSUPPORTED) {
                   switch (psc) {
                   case 0:
@@ -568,7 +455,6 @@ void raw_scan_i2c_devices(Env_Accumulator * accum) {
       rpt_nl();
    }
 
-   i2c_force_slave_addr_flag = saved_i2c_force_slave_addr_flag;
    buffer_free(buf0, __func__);
 
    // DBGMSG("setting i2c_bus_scan_complete");
@@ -584,6 +470,6 @@ void raw_scan_i2c_devices(Env_Accumulator * accum) {
 void query_i2c_buses() {
    rpt_vstring(0,"Examining I2C buses, as detected by I2C layer...");
    sysenv_rpt_current_time(NULL, 1);
-   i2c_report_buses(true, 1 /* indentation depth */);    // in i2c_bus_core.c
+   i2c_dbgrpt_buses(true, 1 /* indentation depth */);    // in i2c_bus_core.c
 }
 
