@@ -3,7 +3,7 @@
  *  Query environment using /sys file system
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -594,7 +594,7 @@ void query_sys_bus_i2c(Env_Accumulator * accumulator) {
       bva_sort(accumulator->sys_bus_i2c_device_numbers);
       if (accumulator->sysfs_ddcci_devices_exist) {
          rpt_nl();
-         rpt_vstring(1, "Devices created by driver ddcci found in %s", dname);
+         rpt_vstring(1, "Device(s) possibly created by driver ddcci found in %s", dname);
          rpt_vstring(1, "Use ddcutil option --force-slave-address to recover from EBUSY errors.");
       }
    }
@@ -620,14 +620,13 @@ void query_sys_amdgpu_parameters(int depth) {
                         parmdir, errsv);
       }
       else {
-         GPtrArray * sorted_names = g_ptr_array_new();
+         GPtrArray * sorted_names = g_ptr_array_new_with_free_func(g_free);
          while (true){
-            dp = readdir(dirp);
+            dp = readdir(dirp);   // per man page, do not free
             if (!dp)
                break;
             if (dp->d_type & DT_REG) {
-               char * fn = dp->d_name;
-               g_ptr_array_add(sorted_names, fn);
+               g_ptr_array_add(sorted_names, strdup(dp->d_name));
             }
          }
          g_ptr_array_sort(sorted_names, indirect_strcmp);
@@ -638,8 +637,10 @@ void query_sys_amdgpu_parameters(int depth) {
             char n[100];
             g_snprintf(n, 100, "%s:", fn);
             rpt_vstring(d2, "%-20s  %s", n, value);
+            free(value);
          }
          closedir(dirp);
+         g_ptr_array_free(sorted_names, true);
       }
    }
 }
@@ -648,28 +649,28 @@ void query_sys_amdgpu_parameters(int depth) {
 /** Examines /sys/class/drm
  */
 
-
-void insert_drm_xref(int depth, char * cur_dir_name, char * i2c_node_name, Byte * edidbytes) {
+static
+void insert_drm_xref(
+      int          depth,
+      const char * cur_dir_name,
+      const char * i2c_node_name,
+      const Byte * edidbytes) {
    bool debug = false;
    DBGMSF(debug, "depth=%d, cur_dir_name=%s, i2c_node_name = %s, edidbytes=%p",
                  depth, cur_dir_name, i2c_node_name, edidbytes);
    int d2 = depth;
-   // rpt_nl();
+   assert(cur_dir_name);
+   // i2c_node_name should should always be non-null, but don't assume
+   assert(edidbytes);
 
    int drm_busno =  i2c_path_to_busno(cur_dir_name);
-   DBGMSF(debug, "cur_dir_name=%s, drm_busno=%d", cur_dir_name, drm_busno);
+   DBGMSF(debug, "drm_busno=%d", drm_busno);
 
-   Device_Id_Xref * xref = NULL;
-   DBGMSF(debug, "i2c_node_name = %s", i2c_node_name);
-   if (i2c_node_name) {
-      // DBGMSG("Using i2c_node_name");
-
-      xref = device_xref_find_by_busno(drm_busno);
-      if (!xref)
-         DBGMSG("Unexpected. Bus %d not in xref table", drm_busno);
-   }
+   Device_Id_Xref * xref = device_xref_find_by_busno(drm_busno);
+   if (!xref)
+      DBGMSG("Unexpected. Bus %d not in xref table", drm_busno);
    // can we assert that edidbytes != NULL?
-   if (!xref && edidbytes) {   // i.e. if !i2c_node_name or lookup by busno failed
+   if (!xref) {
       // DBGMSG("searching by EDID");
 #ifdef SYSENV_TEST_IDENTICAL_EDIDS
                if (first_edid) {
@@ -689,15 +690,16 @@ void insert_drm_xref(int depth, char * cur_dir_name, char * i2c_node_name, Byte
          rpt_vstring(d2, "Multiple displays have same EDID ...%s", xref->edid_tag);
          rpt_vstring(d2, "drm name, and bus number in device cross reference table may be incorrect");
       }
-      // xref->sysfs_drm_name = strdup(dent->d_name);
       xref->sysfs_drm_name = strdup(cur_dir_name);
-      xref->sysfs_drm_i2c  = i2c_node_name;
+      if (i2c_node_name)
+         xref->sysfs_drm_i2c  = strdup(i2c_node_name);
       xref->sysfs_drm_busno = drm_busno;
       DBGMSF(debug, "sysfs_drm_busno = %d", xref->sysfs_drm_busno);
    }
 }
 
 
+static
 void report_one_connector(
       const char * dirname,     // <device>/drm/cardN
       const char * simple_fn,   // card0-HDMI-1 etc
@@ -708,6 +710,8 @@ void report_one_connector(
    int d1 = depth+1;
    int d2 = depth+2;
    DBGMSF(debug, "Starting. dirname=%s, simple_fn=%s", dirname, simple_fn);
+   assert(dirname);
+   assert(simple_fn);
 
    rpt_nl();
    rpt_vstring(depth, "Connector: %s", simple_fn);
@@ -718,26 +722,30 @@ void report_one_connector(
    RPT_ATTR_TEXT(d1, NULL, dirname, simple_fn, "status");
    RPT_ATTR_EDID(d1, &edid_byte_array, dirname, simple_fn, "edid");
 
-   char * i2c_subdir_name = NULL;
+   char * i2c_subdir_name = NULL;    // i2c-N
    GET_ATTR_SINGLE_SUBDIR(&i2c_subdir_name, is_i2cN, NULL, dirname, simple_fn);
    // rpt_vstring(d1, "i2c_device: %s", i2c_subdir_name);
 
    if (i2c_subdir_name) {
-      char * node_name = NULL;
+      char * node_name = NULL;   // e.g. "AMDGPU DM aux hw bus 0"
       rpt_vstring(d1, "i2c_device: %s", i2c_subdir_name);
       RPT_ATTR_TEXT(d2, &node_name, dirname, simple_fn, i2c_subdir_name, "name");
 
-      i2c_path_to_busno(i2c_subdir_name);
-
       Byte * edid_bytes = NULL;
       if (edid_byte_array) {
          edid_bytes = g_byte_array_free(edid_byte_array, false);
+         insert_drm_xref(d2, i2c_subdir_name, node_name, edid_bytes);
       }
-      insert_drm_xref(d2, i2c_subdir_name, node_name, edid_bytes);
+      free(i2c_subdir_name);
+      free(node_name);
       free(edid_bytes);
    }
-   else
+   else {
       rpt_vstring(d2, "No i2c-N subdirectory");
+      if (edid_byte_array)
+         g_byte_array_free(edid_byte_array, true);
+   }
+
    DBGMSF(debug, "Done");
 }
 
@@ -835,188 +843,6 @@ void show_top_level_sys_entries(int depth) {
 }
 
 
-#ifdef FUTURE
-// 9/28/2021 Requires hardening, testing on other than amdgpu, MST etc
-
-typedef struct {
-   char * connector_name;
-   int    i2c_busno;
-   bool   is_aux_channel;
-   int    base_busno;
-   char * name;
-   char * base_name;
-   Byte * edid_bytes;
-   gsize  edid_size;
-   bool   enabled;
-   char * status;
-} Sys_Drm_Display;
-
-
-void free_sys_drm_display(void * display) {
-   if (display) {
-      Sys_Drm_Display * disp = display;
-      free(disp->connector_name);
-      free(disp->edid_bytes);
-      free(disp->name);
-      free(disp->status);
-      free(disp);
-   }
-}
-
-
-static GPtrArray * sys_drm_displays = NULL;  // Sys_Drm_Display;
-
-// typedef Dir_Filter_Func
-bool is_drm_connector(const char * dirname, const char * simple_fn) {
-   bool debug = false;
-   DBGMSF(debug, "Starting. dirname=%s, simple_fn=%s", dirname, simple_fn);
-   bool result = false;
-   if (str_starts_with(simple_fn, "card")) {
-      char * s0 = strdup( simple_fn + 4);   // work around const char *
-      char * s = s0;
-      while (isdigit(*s)) s++;
-      if (*s == '-')
-         result = true;
-      free(s0);
-   }
-   DBGMSF(debug, "Done.     Returning %s", SBOOL(result));
-   return result;
-}
-
-
-bool fn_starts_with(const char * filename, const char * val) {
-   return str_starts_with(filename, val);
-}
-
-
-// typedef Dir_Foreach_Func
-void one_drm_connector(
-      const char *  dirname,
-      const char *  fn,
-      void *        accumulator,
-      int           depth)
-{
-   bool debug = false;
-   DBGMSF(debug, "dirname=%s, fn=%s, depth=%d", dirname, fn, depth);
-   assert( accumulator == sys_drm_displays);   // temp
-   Sys_Drm_Display * cur = calloc(1, sizeof(Sys_Drm_Display));
-   g_ptr_array_add(sys_drm_displays, cur);
-   cur->connector_name = strdup(fn);
-   char * b1 = NULL;
-   RPT_ATTR_TEXT(depth,&b1, dirname, fn, "enabled");
-   cur->enabled = streq(b1, "enabled");
-   RPT_ATTR_TEXT(depth, &cur->status,  dirname, fn, "status");
-
-   GByteArray * edid_byte_array = NULL;
-   rpt_attr_edid(depth, &edid_byte_array, dirname, fn, "edid");
-   if (edid_byte_array) {
-      cur->edid_bytes = g_byte_array_steal(edid_byte_array, &cur->edid_size);
-   }
-
-   bool has_drm_dp_aux_subdir =
-         RPT_ATTR_SINGLE_SUBDIR(
-               depth,
-               NULL,     // char **      value_loc,
-               fn_starts_with,
-               "drm_dp_aux",
-               dirname,
-               fn);
-
-   char * buf = NULL;
-   bool has_i2c_subdir =
-         RPT_ATTR_SINGLE_SUBDIR(depth, &buf, fn_starts_with,"i2c-",
-                                dirname, fn);
-
-   ASSERT_IFF(has_drm_dp_aux_subdir, has_i2c_subdir);
-   cur->is_aux_channel = has_drm_dp_aux_subdir;
-   if (has_i2c_subdir) {  // DP
-      cur->base_busno = i2c_name_to_busno(buf);
-      RPT_ATTR_TEXT(depth, &cur->name, dirname, fn, buf, "name");
-
-      RPT_ATTR_TEXT(depth, &cur->base_name, dirname, fn, "ddc", "name");
-
-      has_i2c_subdir =
-            RPT_ATTR_SINGLE_SUBDIR(depth, &buf, fn_starts_with, "i2c-",
-                                   dirname, fn, "ddc", "i2c-dev");
-      if (has_i2c_subdir) {
-         cur->base_busno = i2c_name_to_busno(buf);
-      }
-   }
-   else {   // not DP
-      RPT_ATTR_TEXT(depth, &cur->name, dirname, fn, "ddc", "name");
-
-      has_i2c_subdir = RPT_ATTR_SINGLE_SUBDIR(
-            depth,
-            &buf,
-            fn_starts_with,
-            "i2c-",
-            dirname,
-            fn,
-            "ddc",
-            "i2c-dev");
-      if (has_i2c_subdir) {
-         cur->i2c_busno = i2c_name_to_busno(buf);
-      }
-   }
-}
-
-
-void scan_sys_drm_displays(int depth) {
-   bool debug = false;
-   DBGMSF(debug, "Starting");
-   int d0 = depth;
-   int d1 = depth+1;
-   rpt_nl();
-   rpt_label(d0, "Scanning /sys/class/drm for /dev/i2c device numbers and EDIDs");
-   if (sys_drm_displays) {
-      g_ptr_array_free(sys_drm_displays, true);
-      sys_drm_displays = NULL;
-   }
-   sys_drm_displays = g_ptr_array_new_with_free_func(free_sys_drm_display);
-
-   dir_filtered_ordered_foreach("/sys/class/drm",
-                       is_drm_connector,      // filter function
-                       NULL,                    // ordering function
-                       one_drm_connector,
-                       sys_drm_displays,                    // accumulator
-                       d1);
-
-   DBGMSF(debug, "Done");
-}
-
-
-void report_sys_drm_displays(int depth) {
-   int d0 = depth;
-   int d1 = depth+1;
-   rpt_nl();
-   rpt_label(d0, "Displays via DRM connector:");
-   if (!sys_drm_displays)
-     scan_sys_drm_displays(depth);
-   GPtrArray * displays = sys_drm_displays;
-   if (!displays || displays->len == 0) {
-      rpt_label(d1, "None");
-   }
-   else {
-      for (int ndx = 0; ndx < displays->len; ndx++) {
-         Sys_Drm_Display * cur = g_ptr_array_index(displays, ndx);
-         rpt_nl();
-         rpt_vstring(d0, "Connector: %s", cur->connector_name);
-         rpt_vstring(d1, "i2c_busno: %d", cur->i2c_busno);
-         rpt_vstring(d1, "enabled:   %s", sbool(cur->enabled));
-         rpt_vstring(d1, "status:    %s", cur->status);
-         rpt_vstring(d1, "name:      %s", cur->name);
-         rpt_label(d1,   "edid:");
-         rpt_hex_dump(cur->edid_bytes, cur->edid_size, d1);
-         if (cur->is_aux_channel) {
-            rpt_vstring(d1, "base_busno:    %d", cur->base_busno);
-            rpt_vstring(d1, "base_name:     %s", cur->base_name);
-         }
-      }
-   }
-}
-#endif
-
-
 /** Master function for dumping /sys directory
  */
 void dump_sysfs_i2c() {
@@ -1024,16 +850,23 @@ void dump_sysfs_i2c() {
    DBGTRC_STARTING(debug, TRACE_GROUP, "");
    rpt_nl();
 
-   rpt_label(0, "Dumping sysfs i2c entries");
+   rpt_label(0, "****** Dumping sysfs i2c entries ******");
 
    rpt_nl();
    show_top_level_sys_entries(0);
+
    // dump_original_sys_scans();
    // dump_simplified_sys_bus_pci(0);
-   dump_detailed_sys_bus_pci(0);
-#ifdef FUTURE
-   report_sys_drm_displays(0);
-#endif
+   dump_detailed_sys_bus_pci(0);    // keep?
+   rpt_nl();
+
+   rpt_label(0, "*** Scan /sys/bus/i2c ***");
+   rpt_nl();
+   dbgrpt_sys_bus_i2c(1);
+   rpt_nl();
+
+   consolidated_i2c_sysfs_report(0);
+
    DBGTRC_DONE(debug, TRACE_GROUP, "");
 }
 
