@@ -13,7 +13,7 @@
  * - debug and trace messages
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "config.h"
@@ -44,6 +44,7 @@
 #include "util/file_util.h"
 #include "util/glib_util.h"
 #include "util/glib_string_util.h"
+#include "util/linux_util.h"
 #include "util/report_util.h"
 #include "util/string_util.h"
 #include "util/timestamp.h"
@@ -100,9 +101,9 @@ char * interpret_call_options_t(Call_Options calloptions) {
 
 
 static void
-print_simple_title_value(int    offset_start_to_title,
+print_simple_title_value(int          offset_start_to_title,
                          const char * title,
-                         int    offset_title_start_to_value,
+                         int          offset_title_start_to_value,
                          const char * value)
 {
    f0printf(fout(), "%.*s%-*s%s\n",
@@ -113,8 +114,6 @@ print_simple_title_value(int    offset_start_to_title,
 }
 
 
-
-
 /** Reports the output level for the current thread
  *  The report is written to the current **FOUT** device.
  *
@@ -327,31 +326,6 @@ static char * get_traced_files_as_joined_string() {
 }
 
 
-/** Outputs a line reporting the traced function list.
- *  Output is written to the current **FOUT** device.
- */
-void show_traced_functions() {
-   char * buf = get_traced_functions_as_joined_string();
-   print_simple_title_value(SHOW_REPORTING_TITLE_START,
-                              "Traced functions: ",
-                              SHOW_REPORTING_MIN_TITLE_SIZE,
-                              (buf && (strlen(buf) > 0)) ? buf : "none");
-   free(buf);
-}
-
-
-/** Outputs a line reporting the traced file list.
- *  Output is written to the current **FOUT** device.
- */
-void show_traced_files() {
-   char * buf = get_traced_files_as_joined_string();
-   print_simple_title_value(SHOW_REPORTING_TITLE_START,
-                              "Traced files: ",
-                              SHOW_REPORTING_MIN_TITLE_SIZE,
-                              (buf && (strlen(buf) > 0)) ? buf : "none");
-   free(buf);
-}
-
 #ifdef UNUSED
 static char * trace_destination = NULL;
 
@@ -402,8 +376,6 @@ void close_syslog() {
 #endif
 
 
-
-
 /** Checks if a tracing is to be performed.
  *
  * Tracing is enabled if any of the following tests pass:
@@ -446,19 +418,6 @@ bool is_tracing(DDCA_Trace_Group trace_group, const char * filename, const char
 }
 
 
-/** Outputs a line reporting the active trace groups.
- *  Output is written to the current **FOUT** device.
- */
-void show_trace_groups() {
-   // DBGMSG("trace_levels: 0x%04x", trace_levels);
-   char * buf = vnt_interpret_flags(trace_levels, trace_group_table, true /* use title */, ", ");
-   print_simple_title_value(SHOW_REPORTING_TITLE_START,
-                              "Trace groups active: ",
-                              SHOW_REPORTING_MIN_TITLE_SIZE,
-                              (strlen(buf) == 0) ? "none" : buf);
-   free(buf);
-}
-
 
 //
 // Error_Info reporting
@@ -597,30 +556,44 @@ void show_ddcutil_version() {
 }
 
 
+/** Reports the current trace settings.
+ *
+ *  \param depth  logical indentation depth
+ */
+void report_tracing(int depth) {
+   int d1 = depth+1;
+   rpt_label(depth, "Trace Options:");
+
+#ifdef UNUSED
+   show_trace_destination();
+#endif
+
+   char * buf = vnt_interpret_flags(trace_levels, trace_group_table, true /* use title */, ", ");
+   rpt_vstring(d1, "Trace groups active:     %s", (buf && strlen(buf)>0) ? buf : "none");
+   free(buf);
+
+   buf = get_traced_functions_as_joined_string();
+   rpt_vstring(d1, "Traced functions:        %s", (buf && strlen(buf)>0) ? buf : "none");
+   free(buf);
+
+   buf = get_traced_files_as_joined_string();
+   rpt_vstring(d1, "Traced files:            %s", (buf && strlen(buf)>0) ? buf : "none");
+   free(buf);
+
+   rpt_vstring(d1, "Trace to syslog:         %s", SBOOL(trace_to_syslog));
+   rpt_nl();
+}
+
+
 /** Reports output levels for:
  *   - general output level (terse, verbose, etc)
  *   - DDC data errors
- *   - trace groups
- *   - traced functions
- *   - traced files
  *
  * Output is written to the current **FOUT** device.
  */
 void show_reporting() {
    show_output_level();
    show_ddcmsg();
-#ifdef UNUSED
-   show_trace_destination();
-#endif
-   show_trace_groups();
-   show_traced_functions();
-   show_traced_files();
-   print_simple_title_value(SHOW_REPORTING_TITLE_START,
-                              "Trace to syslog: ",
-                              SHOW_REPORTING_MIN_TITLE_SIZE,
-                              SBOOL(trace_to_syslog));
-
-   // f0puts("", fout());
 }
 
 
@@ -653,7 +626,7 @@ char * formatted_wall_time() {
 
 bool trace_to_syslog;
 
-
+#ifdef OLD
 /** Issues an error message.
  *  The message is written to the current FERR device and to the system log.
  *
@@ -688,6 +661,7 @@ void severemsg(
 
       syslog(LOG_ERR, "%s", buf2);
 }
+#endif
 
 
 #ifdef OLD
@@ -802,7 +776,7 @@ bool dbgtrc_old(
 
 
 /** Core function for emitting debug or trace messages.
- *  Normally wrapped in a DBGMSG or TRCMSG macro to simplify calling.
+ *  Used by the dbgtrc*() function variants.
  *
  *  The message is output if any of the following are true:
  *  - the trace_group specified is currently active
@@ -810,27 +784,27 @@ bool dbgtrc_old(
  *  - funcname is the name of a function being traced
  *  - filename is the name of a file being traced
  *
- *  The message is output to the current FERR device and optionally,
- *  depending on the syslog setting, to the system log.
+ *  The message is written to the fout() device for the current thread and
+ *  optionally, depending on the syslog setting, to the system log.
  *
  *  @param trace_group   trace group of caller, 0xff to always output
  *  @param options       execution option flags
  *  @param funcname      function name of caller
  *  @param lineno        line number in caller
  *  @param filename      file name of caller
- *  @param pre_prefix
+ *  @param retval_info   return value description
  *  @param format        format string for message
  *  @param ap            arguments for format string
  *
  *  @return **true** if message was output, **false** if not
  */
-bool vdbgtrc(
+static bool vdbgtrc(
         DDCA_Trace_Group  trace_group,
         Dbgtrc_Options    options,
         const char *      funcname,
         const int         lineno,
         const char *      filename,
-        const char *      pre_prefix,
+        const char *      retval_info,
         char *            format,
         va_list           ap)
 {
@@ -840,42 +814,41 @@ bool vdbgtrc(
              " filename=%s, lineno=%d, thread=%ld, fout() %s sysout, pre_prefix=|%s|, format=|%s|\n",
                        trace_group, funcname, filename, lineno, get_thread_id(),
                        (fout() == stdout) ? "==" : "!=",
-                       pre_prefix, format);
+                       retval_info, format);
    }
 
+   Thread_Output_Settings * thread_settings = get_thread_settings();
    bool msg_emitted = false;
+   // n. trace_group == DDCA_TRC_ALWAYS for SEVEREMSG()
    if ( is_tracing(trace_group, filename, funcname) || (options & DBGTRC_OPTIONS_SYSLOG) ) {
-      Thread_Output_Settings * thread_settings = get_thread_settings();
-
       char * buffer = g_strdup_vprintf(format, ap);
-      if (debug)
+      if (debug) {
          printf("(%s) buffer=%p->|%s|\n", __func__, buffer, buffer);
-
-      if (!pre_prefix)
-         pre_prefix="";
-      if (debug)
-         printf("(%s) pre_prefix=%p->|%s|\n", __func__, pre_prefix, pre_prefix);
-
+         printf("(%s) retval_info=%p->|%s|\n", __func__, retval_info, retval_info);
+      }
       char  elapsed_prefix[20]  = "";
       char  walltime_prefix[20] = "";
-      if (dbgtrc_show_time)
-         g_snprintf(elapsed_prefix, 20, "[%s]", formatted_elapsed_time());
-      if (dbgtrc_show_wall_time)
-         g_snprintf(walltime_prefix, 20, "[%s]", formatted_wall_time());
-
       char thread_prefix[15] = "";
-      if (dbgtrc_show_thread_id) {
+      if (dbgtrc_show_time      && !(options & DBGTRC_OPTIONS_SEVERE))
+         g_snprintf(elapsed_prefix, 20, "[%s]", formatted_elapsed_time(4));
+      if (dbgtrc_show_wall_time && !(options & DBGTRC_OPTIONS_SEVERE))
+         g_snprintf(walltime_prefix, 20, "[%s]", formatted_wall_time());
+      if (dbgtrc_show_thread_id && !(options & DBGTRC_OPTIONS_SEVERE) ) {
          // intmax_t tid = get_thread_id();
          // assert(tid == thread_settings->tid);
-         snprintf(thread_prefix, 15, "[%7jd]", thread_settings->tid);  // is this proper format for pid_t
+         snprintf(thread_prefix, 15, "[%7jd]", thread_settings->tid);
       }
-
-      char * buf2 = g_strdup_printf("%s%s%s(%-30s) %s%s",
+      char * buf2 = NULL;
+      if (options & DBGTRC_OPTIONS_SEVERE)
+         buf2 = g_strdup_printf("%s%s",
+                       retval_info, buffer);
+      else
+         buf2 = g_strdup_printf("%s%s%s(%-30s) %s%s",
                        thread_prefix, walltime_prefix, elapsed_prefix, funcname,
-                       pre_prefix, buffer);
+                       retval_info, buffer);
       char * syslog_buf = g_strdup_printf("%s(%-30s) %s%s",
             elapsed_prefix, funcname,
-            pre_prefix, buffer);
+            retval_info, buffer);
       if (debug)
          printf("(%s) buf2=%p->|%s|\n", __func__, buf2, buf2);
 #ifdef NO
@@ -913,10 +886,16 @@ bool vdbgtrc(
          syslog(LOG_INFO, "%s", syslog_buf);
       }
 
-      // assert(fout() == thread_settings->fout);
       if (is_tracing(trace_group, filename, funcname)) {
-         f0puts(buf2, thread_settings->fout);
-         f0putc('\n', thread_settings->fout);
+         FILE * where = NULL;
+         if (options & DBGTRC_OPTIONS_SEVERE) {
+            where = thread_settings->ferr;
+         }
+         else {
+            where = thread_settings->fout;
+         }
+         f0puts(buf2, where);
+         f0putc('\n', where);
          fflush(fout());
       }
       free(buffer);
@@ -931,7 +910,7 @@ bool vdbgtrc(
 }
 
 
-/** Core function for emitting debug or trace messages.
+/** Basic function for emitting debug or trace messages.
  *  Normally wrapped in a DBGMSG or TRCMSG macro to simplify calling.
  *
  *  The message is output if any of the following are true:
@@ -985,7 +964,10 @@ bool dbgtrc(
 }
 
 
-bool dbgtrc_returning(
+/** dbgtrc() variant that reports a numeric return code (normally of
+ *  type #DDCA_Status), in a standardized form.
+ */
+bool dbgtrc_ret_ddcrc(
         DDCA_Trace_Group  trace_group,
         Dbgtrc_Options    options,
         const char *      funcname,
@@ -1013,8 +995,9 @@ bool dbgtrc_returning(
 
       va_list(args);
       va_start(args, format);
-      if (debug)
-         printf("(%s) &args=%p, args=%p\n", __func__, &args, args);
+      // arm7l, aarch64: "on  error: cannot convert to a pointer type"
+      // if (debug)
+      //    printf("(%s) &args=%p, args=%p\n", __func__, (void*)&args, (void*)args);
       msg_emitted = vdbgtrc(trace_group, options, funcname, lineno, filename, pre_prefix, format, args);
       va_end(args);
    }
@@ -1024,6 +1007,9 @@ bool dbgtrc_returning(
 }
 
 
+/** dbgtrc() variant that reports a return code of type #Error_Info in a
+ *  standardized form.
+ */
 bool dbgtrc_returning_errinfo(
         DDCA_Trace_Group  trace_group,
         Dbgtrc_Options    options,
@@ -1041,7 +1027,7 @@ bool dbgtrc_returning_errinfo(
                        __func__,
                        trace_group, funcname, filename, lineno, get_thread_id(),
                        (fout() == stdout) ? "==" : "!=",
-                       errs, format);
+                       (void*)errs, format);
 
    bool msg_emitted = false;
    if ( is_tracing(trace_group, filename, funcname) ) {
@@ -1051,8 +1037,9 @@ bool dbgtrc_returning_errinfo(
 
       va_list(args);
       va_start(args, format);
-      if (debug)
-         printf("(%s) &args=%p, args=%p\n", __func__, &args, args);
+      // arm7l, aarch64: "on  error: cannot convert to a pointer type"
+      // if (debug)
+      //    printf("(%s) &args=%p, args=%p\n", __func__, (void*)&args, (void*)args);
       msg_emitted = vdbgtrc(trace_group, options, funcname, lineno, filename, pre_prefix, format, args);
       va_end(args);
       g_free(pre_prefix);
@@ -1064,7 +1051,8 @@ bool dbgtrc_returning_errinfo(
 }
 
 
-
+/** dbgtrc() variant that reports a return code specified as a string.
+ */
 bool dbgtrc_returning_expression(
         DDCA_Trace_Group  trace_group,
         Dbgtrc_Options    options,
@@ -1093,8 +1081,9 @@ bool dbgtrc_returning_expression(
 
       va_list(args);
       va_start(args, format);
-      if (debug)
-         printf("(%s) &args=%p, args=%p\n", __func__, &args, args);
+      // arm7l, aarch64: "on  error: cannot convert to a pointer type"
+      // if (debug)
+      //    printf("(%s) &args=%p, args=%p\n", __func__, (void*)&args, (void*)args);
       msg_emitted = vdbgtrc(trace_group, options, funcname, lineno, filename, pre_prefix, format, args);
       va_end(args);
    }
@@ -1109,6 +1098,7 @@ bool dbgtrc_returning_expression(
 // error messages and possible program termination.
 //
 
+#ifdef OLD
 /** Reports an IOCTL error.
  *  The message is written to the current **FERR** device and to the system log.
  *
@@ -1125,7 +1115,6 @@ void report_ioctl_error(
       const char * filename,
       int          lineno)
 {
-   int errsv = errno;
    char buffer[200];
    g_snprintf(buffer, 200, "(%s) Error in ioctl(%s), errno=%s",
                            funcname, ioctl_name, linux_errno_desc(errnum) );
@@ -1134,9 +1123,8 @@ void report_ioctl_error(
    fflush(ferr());
 
    syslog(LOG_ERR, "%s", buffer);
-
-   errno = errsv;
 }
+#endif
 
 
 /** Called when a condition that should be impossible has been detected.
