@@ -60,19 +60,6 @@ static Thread_Displays_Data *  get_thread_displays_data() {
 #endif
 
 
-// *** Miscellaneous ***
-
-/** Reports whether a #DDCA_Adlno value is set or is currently undefined.
- *  \param adlno ADL adapter/index number pair
- *
- *  \remark
- *  Used to hide the magic number for "undefined"
- */
-bool is_adlno_defined(DDCA_Adlno adlno) {
-   return adlno.iAdapterIndex >= 0 && adlno.iDisplayIndex >= 0;
-}
-
-
 // *** DDCA_IO_Path ***
 
 /** Tests 2 #DDCA_IO_Path instances for equality
@@ -228,13 +215,10 @@ void unlock_display_lock(Display_Async_Rec * async_rec) {
 }
 
 
-
-
 // *** Display_Identifier ***
 
 static char * Display_Id_Type_Names[] = {
       "DISP_ID_BUSNO",
-      "DISP_ID_ADL",
       "DISP_ID_MONSER",
       "DISP_ID_EDID",
       "DISP_ID_DISPNO",
@@ -258,8 +242,6 @@ Display_Identifier* common_create_display_identifier(Display_Id_Type id_type) {
    memcpy(pIdent->marker, DISPLAY_IDENTIFIER_MARKER, 4);
    pIdent->id_type = id_type;
    pIdent->busno  = -1;
-   pIdent->iAdapterIndex = -1;
-   pIdent->iDisplayIndex = -1;
    pIdent->usb_bus = -1;
    pIdent->usb_device = -1;
    memset(pIdent->edidbytes, '\0', 128);
@@ -268,6 +250,7 @@ Display_Identifier* common_create_display_identifier(Display_Id_Type id_type) {
    return pIdent;
 }
 
+
 /** Creates a #Display_Identifier using a **ddcutil** display number
  *
  * \param  dispno display number (1 based)
@@ -300,27 +283,6 @@ Display_Identifier* create_busno_display_identifier(int busno) {
 }
 
 
-/** Creates a #Display_Identifier using an ADL adapter number/display number pair.
- *
- * \param  iAdapterIndex ADL adapter number
- * \param  iDisplayIndex ADL display number
- * \return pointer to newly allocated #Display_Identifier
- *
- * \remark
- * It is the responsibility of the caller to free the allocated
- * #Display_Identifier using #free_display_identifier().
- */
-Display_Identifier* create_adlno_display_identifier(
-      int    iAdapterIndex,
-      int    iDisplayIndex)
-{
-   Display_Identifier* pIdent = common_create_display_identifier(DISP_ID_ADL);
-   pIdent->iAdapterIndex = iAdapterIndex;
-   pIdent->iDisplayIndex = iDisplayIndex;
-   return pIdent;
-}
-
-
 /** Creates a #Display_Identifier using an EDID value
  *
  * \param  edidbytes  pointer to 128 byte EDID value
@@ -330,15 +292,13 @@ Display_Identifier* create_adlno_display_identifier(
  * It is the responsibility of the caller to free the allocated
  * #Display_Identifier using #free_display_identifier().
  */
-Display_Identifier* create_edid_display_identifier(
-      const Byte* edidbytes
-      )
-{
+Display_Identifier* create_edid_display_identifier(const Byte* edidbytes) {
    Display_Identifier* pIdent = common_create_display_identifier(DISP_ID_EDID);
    memcpy(pIdent->edidbytes, edidbytes, 128);
    return pIdent;
 }
 
+
 /** Creates a #Display_Identifier using one or more of
  *  manufacturer id, model name, and/or serial number string
  *  as recorded in the EDID.
@@ -359,8 +319,7 @@ Display_Identifier* create_edid_display_identifier(
 Display_Identifier* create_mfg_model_sn_display_identifier(
       const char* mfg_id,
       const char* model_name,
-      const char* serial_ascii
-      )
+      const char* serial_ascii)
 {
    assert(!mfg_id       || strlen(mfg_id)       < EDID_MFG_ID_FIELD_SIZE);
    assert(!model_name   || strlen(model_name)   < EDID_MODEL_NAME_FIELD_SIZE);
@@ -432,8 +391,6 @@ void dbgrpt_display_identifier(Display_Identifier * pdid, int depth) {
    rpt_mapped_int("ddc_io_mode",   NULL, pdid->id_type, (Value_To_Name_Function) display_id_type_name, d1);
    rpt_int( "dispno",        NULL, pdid->dispno,        d1);
    rpt_int( "busno",         NULL, pdid->busno,         d1);
-   rpt_int( "iAdapterIndex", NULL, pdid->iAdapterIndex, d1);
-   rpt_int( "iDisplayIndex", NULL, pdid->iDisplayIndex, d1);
    rpt_int( "usb_bus",       NULL, pdid->usb_bus,       d1);
    rpt_int( "usb_device",    NULL, pdid->usb_device,    d1);
    rpt_int( "hiddev_devno",  NULL, pdid->hiddev_devno,  d1);
@@ -473,10 +430,6 @@ char * did_repr(Display_Identifier * pdid) {
                pdid->repr = g_strdup_printf(
                         "Display Id[type=%s, bus=/dev/i2c-%d]", did_type_name, pdid->busno);
                break;
-         case(DISP_ID_ADL):
-               pdid->repr = g_strdup_printf(
-                        "Display Id[type=%s, adlno=%d.%d]", did_type_name, pdid->iAdapterIndex, pdid->iDisplayIndex);
-               break;
          case(DISP_ID_MONSER):
                pdid->repr = g_strdup_printf(
                         "Display Id[type=%s, mfg=%s, model=%s, sn=%s]",
@@ -526,7 +479,7 @@ void free_display_identifier(Display_Identifier * pdid) {
 }
 
 
-#ifdef FUTURE
+// #ifdef FUTURE
 // *** Display Selector *** (future)
 
 Display_Selector * dsel_new() {
@@ -534,8 +487,6 @@ Display_Selector * dsel_new() {
    memcpy(dsel->marker, DISPLAY_SELECTOR_MARKER, 4);
    dsel->dispno        = -1;
    dsel->busno         = -1;
-   dsel->iAdapterIndex = -1;
-   dsel->iDisplayIndex = -1;
    dsel->usb_bus       = -1;
    dsel->usb_device    = -1;
    return dsel;
@@ -550,7 +501,8 @@ void dsel_free(Display_Selector * dsel) {
       free(dsel->edidbytes);
    }
 }
-#endif
+
+// #endif
 
 
 // *** DDCA_IO_Mode and DDCA_IO_Path ***
@@ -658,27 +610,6 @@ Display_Ref * create_bus_display_ref(int busno) {
 }
 
 
-/** Creates a #Display_Ref for IO mode #DDCA_IO_ADL
- *
- * @param  iAdapterIndex   ADL adapter index
- * @param  iDisplayIndex   ADL display index
- * \return pointer to newly allocated #Display_Ref
- */
-Display_Ref * create_adl_display_ref(int iAdapterIndex, int iDisplayIndex) {
-   bool debug = false;
-   DDCA_IO_Path io_path;
-   io_path.io_mode   = DDCA_IO_ADL;
-   io_path.path.adlno.iAdapterIndex = iAdapterIndex;
-   io_path.path.adlno.iDisplayIndex = iDisplayIndex;
-   Display_Ref * dref = create_base_display_ref(io_path);
-   if (debug) {
-      DBGMSG("Done.  Constructed ADL display ref:");
-      dbgrpt_display_ref(dref,0);
-   }
-   return dref;
-}
-
-
 #ifdef USE_USB
 /** Creates a #Display_Ref for IO mode #DDCA_IO_USB
  *
@@ -727,9 +658,9 @@ Display_Ref * clone_display_ref(Display_Ref * old) {
 #endif
 
 
-/** Free a display reference.
+/** Frees a display reference.
  *
- *  \param dref  display reference to free
+ *  \param  dref  ptr to display reference to free, if NULL no operation is performed
  *  \retval DDCRC_OK       success
  *  \retval DDCRC_ARG      invalid display reference
  *  \retval DDCRC_LOCKED   display reference not marked as transient
@@ -738,35 +669,35 @@ DDCA_Status free_display_ref(Display_Ref * dref) {
    bool debug = false;
    DBGTRC_STARTING(debug, DDCA_TRC_BASE, "dref=%p -> %s", dref, dref_repr_t(dref));
    DDCA_Status ddcrc = 0;
-   if (!dref || memcmp(dref->marker, DISPLAY_REF_MARKER, 4) != 0) {
-      ddcrc = DDCRC_ARG;
-      DBGMSG("Invalid dref.");
-      if (dref)
+   if (dref) {
+      if ( memcmp(dref->marker, DISPLAY_REF_MARKER, 4) != 0) {
+         ddcrc = DDCRC_ARG;
+         DBGMSG("Invalid dref.");
          rpt_hex_dump((Byte*) dref->marker, 4, 2);
-      goto bye;
-   }
-   if (dref && (dref->flags & DREF_TRANSIENT) ) {
-      if (dref->flags & DREF_OPEN) {
-         ddcrc = DDCRC_LOCKED;
+         goto bye;
       }
-      else {
-         dref->marker[3] = 'x';
-         if (dref->usb_hiddev_name)       // always set using strdup()
-            free(dref->usb_hiddev_name);
-         if (dref->capabilities_string)   // always a private copy
-            free(dref->capabilities_string);
-         if (dref->mmid)                  // always a private copy
-            free(dref->mmid);
-         // 9/2017: what about pedid, detail2?
-         // what to do with gdl, request_queue?
-         if (dref->dfr)
-            dfr_free(dref->dfr);
-         dref->marker[3] = 'x';
-         free(dref);
+      if (dref->flags & DREF_TRANSIENT)  {
+         if (dref->flags & DREF_OPEN) {
+            ddcrc = DDCRC_LOCKED;
+         }
+         else {
+            if (dref->usb_hiddev_name)       // always set using strdup()
+               free(dref->usb_hiddev_name);
+            if (dref->capabilities_string)   // always a private copy
+               free(dref->capabilities_string);
+            if (dref->mmid)                  // always a private copy
+               free(dref->mmid);
+            // 9/2017: what about pedid, detail2?
+            // what to do with gdl, request_queue?
+            if (dref->dfr)
+               dfr_free(dref->dfr);
+            dref->marker[3] = 'x';
+            free(dref);
+         }
       }
    }
 bye:
-   DBGTRC_RETURNING(debug, DDCA_TRC_BASE, ddcrc, "");
+   DBGTRC_RET_DDCRC(debug, DDCA_TRC_BASE, ddcrc, "");
    return ddcrc;
 }
 
@@ -787,7 +718,7 @@ bool dref_eq(Display_Ref* this, Display_Ref* that) {
 }
 
 
-/** Reports the contents of a #Display_Ref in a format appropriate for debugging.
+/** Reports the contents of a #Display_Ref in a format useful for debugging.
  *
  *  \param  dref  pointer to #Display_Ref instance
  *  \param  depth logical indentation depth
@@ -795,38 +726,11 @@ bool dref_eq(Display_Ref* this, Display_Ref* that) {
 void dbgrpt_display_ref(Display_Ref * dref, int depth) {
    bool debug = false;
    DBGMSF(debug, "Starting. dref=%p", dref);
+
    rpt_structure_loc("Display_Ref", dref, depth );
    int d1 = depth+1;
-   // int d2 = depth+2;
 
-#ifdef OLD
-   // old
-   rpt_mapped_int("ddc_io_mode", NULL, dref->io_mode, (Value_To_Name_Function) io_mode_name, d1);
-
-   switch (dref->io_mode) {
-
-   case DDCA_IO_I2C:
-      rpt_int("busno", NULL, dref->busno, d1);
-      break;
-
-   case DDCA_IO_ADL:
-      rpt_int("iAdapterIndex", NULL, dref->iAdapterIndex, d1);
-      rpt_int("iDisplayIndex", NULL, dref->iDisplayIndex, d1);
-      break;
-
-   case DDCA_IO_USB:
-      rpt_int("usb_bus",    NULL, dref->usb_bus,    d1);
-      rpt_int("usb_device", NULL, dref->usb_device, d1);
-      rpt_str("usb_hiddev_name", NULL, dref->usb_hiddev_name, d1);
-      rpt_int("usb_hiddev_devno", NULL, dref->usb_hiddev_devno, d1);
-      break;
-
-   }
-#endif
-
-   // alt:
    rpt_vstring(d1, "io_path:          %s", dpath_repr_t(&(dref->io_path)));
-
    if (dref->io_path.io_mode == DDCA_IO_USB) {
       rpt_int("usb_bus",         NULL, dref->usb_bus,         d1);
       rpt_int("usb_device",      NULL, dref->usb_device,      d1);
@@ -834,7 +738,6 @@ void dbgrpt_display_ref(Display_Ref * dref, int depth) {
    }
 
    rpt_vstring(d1, "vcp_version_xdf:  %s", format_vspec(dref->vcp_version_xdf) );
-   // dbgrpt_dref_flags(dref->flags, d1);
    rpt_vstring(d1, "flags:            %s", interpret_dref_flags_t(dref->flags) );
    rpt_vstring(d1, "mmid:             %s", (dref->mmid) ? mmk_repr(*dref->mmid) : "NULL");
 
@@ -842,45 +745,6 @@ void dbgrpt_display_ref(Display_Ref * dref, int depth) {
 }
 
 
-#ifdef OLD
-/** Creates a short description of a #Display_Ref in a buffer provided
- *  by the caller.
- *
- *  \param  dref   pointer to #Display_Ref
- *  \param  buf    pointer to buffer
- *  \param  bufsz  buffer size
- */
-static
-char * dref_short_name_r(Display_Ref * dref, char * buf, int bufsz) {
-   assert(buf);
-   assert(bufsz > 0);
-
-   switch (dref->io_mode) {
-
-   case DDCA_IO_I2C:
-      SAFE_SNPRINTF(buf, bufsz, "bus /dev/i2c-%d", dref->busno);
-
-      // snprintf(buf, bufsz, "bus /dev/i2c-%d", dref->busno);
-      // buf[bufsz-1] = '\0';  // ensure null terminated
-      break;
-
-   case DDCA_IO_ADL:
-      SAFE_SNPRINTF(buf, bufsz, "adl display %d.%d", dref->iAdapterIndex, dref->iDisplayIndex);
-      // snprintf(buf, bufsz, "adl display %d.%d", dref->iAdapterIndex, dref->iDisplayIndex);
-      // buf[bufsz-1] = '\0';  // ensure null terminated
-      break;
-
-   case DDCA_IO_USB:
-      SAFE_SNPRINTF(buf, bufsz, "usb %d:%d", dref->usb_bus, dref->usb_device);
-      // snprintf(buf, bufsz, "usb %d:%d", dref->usb_bus, dref->usb_device);
-      buf[bufsz-1] = '\0';  // ensure null terminated
-      break;
-
-   }
-   return buf;
-}
-#endif
-
 /** Thread safe function that returns a short description of a #Display_Ref.
  *  The returned value is valid until the next call to this function on
  *  the current thread.
@@ -890,13 +754,6 @@ char * dref_short_name_r(Display_Ref * dref, char * buf, int bufsz) {
  */
 char * dref_short_name_t(Display_Ref * dref) {
    return dpath_short_name_t(&dref->io_path);
-#ifdef OLD
-   static GPrivate  dref_short_name_key = G_PRIVATE_INIT(g_free);
-   char * buf = get_thread_fixed_buffer(&dref_short_name_key, 100);
-   char buf2[80];
-   snprintf(buf, 100, "Display_Ref[%s]", dref_short_name_r(dref, buf2, 80) );
-   return buf;
-#endif
 }
 
 
@@ -912,7 +769,7 @@ char * dref_repr_t(Display_Ref * dref) {
 
    char * buf = get_thread_fixed_buffer(&dref_repr_key, 100);
    if (dref)
-      g_snprintf(buf, 100, "Display_Ref[%s @%p]", dpath_short_name_t(&dref->io_path), dref);
+      g_snprintf(buf, 100, "Display_Ref[%s @%p]", dpath_short_name_t(&dref->io_path), (void*)dref);
    else
       strcpy(buf, "Display_Ref[NULL]");
    return buf;
@@ -921,63 +778,6 @@ char * dref_repr_t(Display_Ref * dref) {
 
 // *** Display_Handle ***
 
-#ifdef OLD
-
-/** Creates a #Display_Handle for an I2C #Display_Ref.
- *
- *  \param  fd   Linux file descriptor of open display
- *  \param  dref pointer to #Display_Ref
- *  \return newly allocated #Display_Handle
- *
- *  \remark
- *  This functions handles the boilerplate of creating a #Display_Handle.
- */
-Display_Handle * create_bus_display_handle_from_display_ref(int fd, Display_Ref * dref) {
-   // assert(dref->io_mode == DDCA_IO_DEVI2C);
-   assert(dref->io_path.io_mode == DDCA_IO_I2C);
-   Display_Handle * dh = calloc(1, sizeof(Display_Handle));
-   memcpy(dh->marker, DISPLAY_HANDLE_MARKER, 4);
-   dh->fd = fd;
-   dh->dref = dref;
-   // dref->vcp_version = DDCA_VSPEC_UNQUERIED;
-   dh->repr = g_strdup_printf(
-                "[i2c: fd=%d, busno=%d @%p]",
-                dh->fd, dh->dref->io_path.path.i2c_busno, dh);
-   return dh;
-}
-
-
-#ifdef USE_USB
-/** Creates a #Display_Handle for a USB #Display_Ref.
- *
- *  \param  fh    Linux file descriptor of open display
- *  \param  dref  pointer to #Display_Ref
- *  \return newly allocated #Display_Handle
- *
- *  \remark
- *  This functions handles to boilerplate of creating a #Display_Handle.
- */
-Display_Handle * create_usb_display_handle_from_display_ref(int fd, Display_Ref * dref) {
-   // assert(dref->io_mode == DDCA_IO_USB);
-   assert(dref->io_path.io_mode == DDCA_IO_USB);
-   Display_Handle * dh = calloc(1, sizeof(Display_Handle));
-   memcpy(dh->marker, DISPLAY_HANDLE_MARKER, 4);
-   dh->fd = fd;
-   dh->dref = dref;
-   dh->repr = g_strdup_printf(
-                "[usb: %d:%d, %s/hiddev%d @%p]",
-                // "Display_Handle[usb: %d:%d, %s/hiddev%d]",
-                dh->dref->usb_bus, dh->dref->usb_device,
-                usb_hiddev_directory(), dh->dref->io_path.path.hiddev_devno,
-                dh);
-   // dref->vcp_version = DDCA_VSPEC_UNQUERIED;
-   return dh;
-}
-#endif
-
-#endif
-
-
 /** Creates a #Display_Handle for a #Display_Ref.
  *
  *  \param  fd    Linux file descriptor of open display
@@ -995,8 +795,8 @@ Display_Handle * create_base_display_handle(int fd, Display_Ref * dref) {
    dh->dref = dref;
    if (dref->io_path.io_mode == DDCA_IO_I2C) {
       dh->repr = g_strdup_printf(
-                     "Display_Handle[i2c: fd=%d, busno=%d @%p]",
-                     dh->fd, dh->dref->io_path.path.i2c_busno, dh);
+                     "Display_Handle[i2c-%d: fd=%d @%p]",
+                     dh->dref->io_path.path.i2c_busno, dh->fd, (void*)dh);
    }
 #ifdef USE_USB
    else if (dref->io_path.io_mode == DDCA_IO_USB) {
@@ -1005,7 +805,7 @@ Display_Handle * create_base_display_handle(int fd, Display_Ref * dref) {
                 // "Display_Handle[usb: %d:%d, %s/hiddev%d]",
                 dh->dref->usb_bus, dh->dref->usb_device,
                 usb_hiddev_directory(), dh->dref->io_path.path.hiddev_devno,
-                dh);
+                (void*)dh);
    }
 #endif
    else {
@@ -1063,82 +863,17 @@ void dbgrpt_display_handle(Display_Handle * dh, const char * msg, int depth) {
 }
 
 
-/** Returns a string summarizing the specified #Display_Handle.
- *
- *  The string is valid until the next call to this function
- *  from within the current thread.
- *
- *  This variant of #dh_repr() is thread safe.
- *
- * \param   dh      display handle
- * \return  string  representation of handle
- */
-char * dh_repr_t(Display_Handle * dh) {
-   // dh_repr is precalculated when display handle is created, returning the
-   // value is thread safe
-   if (!dh)
-      return "Display_Handle[NULL]";
-   return dh->repr;
-
-#ifdef UNNECESSARY
-   static GPrivate  dh_buf_key = G_PRIVATE_INIT(g_free);
-   const int bufsz = 100;
-   char * buf = get_thread_fixed_buffer(&dh_buf_key, bufsz);
-
-   if (dh) {
-      if (memcmp(dh->marker, DISPLAY_HANDLE_MARKER, 4) == 0) {
-         assert(dh->dref);
-
-         switch (dh->dref->io_path.io_mode) {
-         case DDCA_IO_I2C:
-              snprintf(buf, bufsz,
-                       "Display_Handle[i2c: fd=%d, busno=%d @%p]",
-                       dh->fd, dh->dref->io_path.path.i2c_busno, dh);
-              break;
-          case DDCA_IO_ADL:
-              snprintf(buf, bufsz,
-                       "Display_Handle[adl: display %d.%d]",
-                       dh->dref->io_path.path.adlno.iAdapterIndex, dh->dref->io_path.path.adlno.iDisplayIndex);
-              break;
-          case DDCA_IO_USB:
-#ifdef ENABLE_USB
-              snprintf(buf, bufsz,
-                       "Display_Handle[usb: %d:%d, %s/hiddev%d @%p]",
-                       dh->dref->usb_bus, dh->dref->usb_device,
-                       usb_hiddev_directory(), dh->dref->io_path.path.hiddev_devno, dh);
-#else
-              PROGRAM_LOGIC_ERROR("io_path.io_mode == DDCA_IO_USB");
-#endif
-              break;
-          }
-          buf[bufsz-1] = '\0';
-      }
-      else {
-         snprintf(buf, bufsz, "Invalid Display_Handle@%p", dh);
-         //  strcpy(buf, "Invalid Display_Handle");
-      }
-   }
-   else {
-      strcpy(buf, "Display_Handle[NULL]");
-   }
-
-   return buf;
-#endif
-}
-
-
 /** Returns a string summarizing the specified #Display_Handle.
  *
  * \param  dh    display handle
- *
  * \return  string representation of handle
+ *
+ * \remark
+ * The value is calculated when the Display_Handle is created.
  */
 char * dh_repr(Display_Handle * dh) {
-   assert(dh);
-   assert(dh->dref);
-   assert(dh->repr);
-   // Do not calculate and memoize dh->repr here, due to possible race condition between threads
-   // Instead precalculate at time of Display_Handle creation
+   if (!dh)
+      return "Display_Handle[NULL]";
    return dh->repr;
 }
 
@@ -1149,7 +884,7 @@ char * dh_repr(Display_Handle * dh) {
  */
 void   free_display_handle(Display_Handle * dh) {
    bool debug = false;
-   DBGTRC_STARTING(debug, DDCA_TRC_BASE, "dh=%p -> %s", dh, dh_repr_t(dh));
+   DBGTRC_STARTING(debug, DDCA_TRC_BASE, "dh=%p -> %s", dh, dh_repr(dh));
    if (dh && memcmp(dh->marker, DISPLAY_HANDLE_MARKER, 4) == 0) {
       dh->marker[3] = 'x';
       free(dh->repr);
@@ -1161,19 +896,6 @@ void   free_display_handle(Display_Handle * dh) {
 
 // *** Miscellaneous ***
 
-/** Creates and initializes a #Video_Card_Info struct.
- *
- * \return new instance
- *
- * \remark
- * Currently unused.  Struct Video_Card_Info is referenced only in ADL code.
- */
-Video_Card_Info * create_video_card_info() {
-   Video_Card_Info * card_info = calloc(1, sizeof(Video_Card_Info));
-   memcpy(card_info->marker, VIDEO_CARD_INFO_MARKER, 4);
-   return card_info;
-}
-
 #ifdef USE_USB
 /** Given a hiddev device name, e.g. /dev/usb/hiddev3,
  *  extract its number, e.g. 3.
@@ -1181,7 +903,7 @@ Video_Card_Info * create_video_card_info() {
  *  \param   hiddev_name device name
  *  \return  device number, -1 if error
  */
-int hiddev_name_to_number(char * hiddev_name) {
+int hiddev_name_to_number(const char * hiddev_name) {
    assert(hiddev_name);
    char * p = strstr(hiddev_name, "hiddev");
 
@@ -1201,6 +923,7 @@ int hiddev_name_to_number(char * hiddev_name) {
 }
 
 
+#ifdef UNUSED
 /** Given a hiddev device number, e.g. 3, return its name, e.g. /dev/usb/hiddev3
  *
  *  \param   hiddev_number device number
@@ -1215,12 +938,12 @@ char * hiddev_number_to_name(int hiddev_number) {
    return s;
 }
 #endif
+#endif
 
 
 Value_Name_Table dref_flags_table = {
       VN(DREF_DDC_COMMUNICATION_CHECKED),
  //   VN(DREF_DDC_COMMUNICATION_WORKING),
-      VN(DREF_DDC_NULL_RESPONSE_CHECKED),
       VN(DREF_DDC_IS_MONITOR_CHECKED),
       VN(DREF_DDC_IS_MONITOR),
       VN(DREF_TRANSIENT),
