@@ -84,12 +84,14 @@ static bool                 debug_sleep_stats_mutex = false;
 static
 IO_Event_Type_Stats io_event_stats[] = {
       // id           name             desc           nanosec  count
-      {IE_WRITE,      "IE_WRITE",      "write calls",       0, 0},
-      {IE_READ,       "IE_READ",       "read calls",        0, 0},
-      {IE_WRITE_READ, "IE_WRITE_READ", "write/read calls",  0, 0},
-      {IE_OPEN,       "IE_OPEN",       "open file calls",   0, 0},
-      {IE_CLOSE,      "IE_CLOSE",      "close file calls",  0, 0},
-      {IE_OTHER,      "IE_OTHER",      "other I/O calls",   0, 0},
+      {IE_WRITE,      "IE_WRITE",      "write calls",            0, 0},
+      {IE_READ,       "IE_READ",       "read calls",             0, 0},
+      {IE_IOCTL_WRITE,"I2_IOCTL_WRITE","i2c writes using ioctl", 0, 0},
+      {IE_IOCTL_READ, "I2_IOCTL_READ", "i2c reads using ioctl",  0, 0},
+//    {IE_WRITE_READ, "IE_WRITE_READ", "write/read calls",       0, 0},
+      {IE_OPEN,       "IE_OPEN",       "open file calls",        0, 0},
+      {IE_CLOSE,      "IE_CLOSE",      "close file calls",       0, 0},
+      {IE_OTHER,      "IE_OTHER",      "other I/O calls",        0, 0},
 };
 #define IO_EVENT_TYPE_CT (sizeof(io_event_stats)/sizeof(IO_Event_Type_Stats))
 static GMutex io_event_stats_mutex;
@@ -210,7 +212,7 @@ void report_io_call_stats(int depth) {
       if (io_event_stats[ndx].call_count > 0) {
          IO_Event_Type_Stats* curstat = &io_event_stats[ndx];
          char buf[100];
-         snprintf(buf, 100, "%-17s (%s)", curstat->desc, curstat->name);
+         snprintf(buf, 100, "%-22s (%s)", curstat->desc, curstat->name);
          rpt_vstring(d1, "%-40s  %4d  %10" PRIu64 "  (%13" PRIu64 ")",
                      buf,
                      curstat->call_count,
@@ -499,17 +501,14 @@ int get_true_io_error_count(Status_Code_Counts * pcounts) {
 // Names for Sleep_Event enum values
 static const char * sleep_event_names[] = {
       "SE_WRITE_TO_READ",
-      "SE_POST_OPEN",
       "SE_POST_WRITE",
       "SE_POST_READ",
       "SE_DDC_NULL",
       "SE_POST_SAVE_SETTINGS",
-      "SE_PRE_EDID",
       "SE_PRE_MULTI_PART_READ",
       "SE_MULTI_PART_READ_TO_WRITE",
       "SE_BETWEEN_CAP_TABLE_SEGMENTS",
       "SE_POST_CAP_TABLE_COMMAND",
-      "SE_OTHER",
       "SE_SPECIAL",
      };
 #define SLEEP_EVENT_ID_CT (sizeof(sleep_event_names)/sizeof(char *))
