@@ -45,7 +45,9 @@ void report_elapsed_summary(int depth);
 typedef enum {
    IE_WRITE,               ///< write event
    IE_READ,                ///< read event
-   IE_WRITE_READ,          ///< write/read operation, typical for I2C
+   IE_IOCTL_WRITE,         ///< i2c writes using ioctl()
+   IE_IOCTL_READ,          ///< i2c reads using ioctl()
+// IE_WRITE_READ,          ///< write/read operation, typical for I2C
    IE_OPEN,                ///< device file open
    IE_CLOSE,               ///< device file close
    IE_OTHER                ///< other IO event
@@ -79,22 +81,17 @@ Public_Status_Code log_retryable_status_code(Public_Status_Code rc, const char *
 void report_all_status_counts(int depth);
 
 
-
-
 /** Sleep event type */
 typedef enum {
    SE_WRITE_TO_READ,         ///< between I2C write and read
-   SE_POST_OPEN,             ///< after I2C device opened
    SE_POST_WRITE,            ///< after I2C write without subsequent read
    SE_POST_READ,             ///< after I2C read
    SE_DDC_NULL,              ///< after DDC Null response
    SE_POST_SAVE_SETTINGS,    ///< after DDC Save Current Settings command
-   SE_PRE_EDID,              ///< before reading EDID
    SE_PRE_MULTI_PART_READ,      ///< before reading capabilities
    SE_MULTI_PART_WRITE_TO_READ, ///< within segments of multi-part read
    SE_AFTER_EACH_CAP_TABLE_SEGMENT,  ///< between segments of Capabilities or a Table command
    SE_POST_CAP_TABLE_COMMAND,
-   SE_OTHER,
    SE_SPECIAL                ///< explicit time specified
 } Sleep_Event_Type;
 const char * sleep_event_name(Sleep_Event_Type event_type);
