@@ -6,7 +6,7 @@
  * tracing and and maintain sleep statistics.
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 
@@ -107,7 +107,7 @@ void sleep_millis(int milliseconds) {
  * \param filename     name of file from which sleep was invoked
  * \param message      text to be appended to trace message
  */
-void sleep_millis_with_tracex(
+void sleep_millis_with_trace(
         int          milliseconds,
         const char * func,
         int          lineno,
