@@ -3,7 +3,7 @@
  *  Functions and strings that are independent of the parser package used.
  */
 
-// Copyright (C) 20014-2018 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 20014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 
@@ -14,6 +14,7 @@
 
 #include "cmdline/parsed_cmd.h"
 
+void init_cmd_parser_base();
 
 typedef
 struct {
@@ -28,14 +29,14 @@ Cmd_Desc * find_command(char * cmd);
 Cmd_Desc * get_command(int cmdid);
 void show_cmd_desc(Cmd_Desc * cmd_desc);   // debugging function
 
-void validate_cmdinfo();
-
 bool all_digits(char * val, int ct);
 bool parse_dot_separated_arg(  const char * val, int * pv1, int * pv2);
 bool parse_colon_separated_arg(const char * val, int * pv1, int * pv2);
 bool parse_int_arg(char * val, int * pIval);
 
 bool parse_feature_id_or_subset(char * val, int cmd_id, Feature_Set_Ref * fsref);
+bool parse_feature_ids(char ** vals, int vals_ct, int cmd_id, Feature_Set_Ref * fsref);
+Feature_Set_Ref * parse_feature_ids_or_subset(int cmd_id, char **vals, int vals_ct);
 
 bool validate_output_level(Parsed_Cmd* parsed_cmd);
 
