@@ -3,7 +3,7 @@
  *  Parse the command line using the glib goption functions.
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include <config.h>
@@ -76,7 +76,7 @@ stats_arg_func(const    gchar* option_name,
 
    bool ok = true;
    if (value) {
-      char * v2 = strupper(strdup(value));
+      char * v2 = strdup_uc(value);
       if ( streq(v2,"ALL") ) {
          stats_work |= DDCA_STATS_ALL;
       }
@@ -141,8 +141,12 @@ stats_arg_func(const    gchar* option_name,
  */
 Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    bool debug = false;
+   char * s = getenv("DDCUTIL_DEBUG_PARSE");
+   if (s && strlen(s) > 0)
+      debug = true;
+
    DBGMSF(debug, "Starting. parser_mode = %d", parser_mode );
-   validate_cmdinfo();   // assertions
+   init_cmd_parser_base();   // assertions
 
    if (debug) {
       DBGMSG("argc=%d", argc);
@@ -173,7 +177,9 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    gboolean syslog_flag    = false;
    gboolean verify_flag    = false;
    gboolean noverify_flag  = false;
+#ifdef OLD
    gboolean nodetect_flag  = false;
+#endif
    gboolean async_flag     = false;
    gboolean report_freed_excp_flag = false;
    gboolean notable_flag   = true;
@@ -181,15 +187,18 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    gboolean ro_only_flag   = false;
    gboolean wo_only_flag   = false;
    gboolean enable_udf_flag = DEFAULT_ENABLE_UDF;
-   const char * enable_udf_expl = (enable_udf_flag) ? "Enable User Define Features (default)" : "Enable User Define Features";
-   const char * disable_udf_expl = (enable_udf_flag) ? "Disable User Defined Features" : "Disable User Define Features (default)";
+   const char * enable_udf_expl = (enable_udf_flag) ? "Enable User Defined Features (default)" : "Enable User Defined Features";
+   const char * disable_udf_expl = (enable_udf_flag) ? "Disable User Defined Features" : "Disable User Defined Features (default)";
 #ifdef USE_USB
    gboolean enable_usb_flag = DEFAULT_ENABLE_USB;
    const char * enable_usb_expl = (enable_usb_flag) ? "Detect USB devices (default)" : "Detect USB devices";
    const char * disable_usb_expl = (enable_usb_flag) ? "Ignore USB devices" : "Ignore USB devices (default)";
 #endif
    gboolean timeout_i2c_io_flag = false;
+   gboolean reduce_sleeps_specified = false;
+#ifdef OLD
    gboolean reduce_sleeps_flag  = DEFAULT_SLEEP_LESS;
+#endif
    gboolean deferred_sleep_flag = false;
    gboolean per_thread_stats_flag = false;
    gboolean show_settings_flag = false;
@@ -281,8 +290,6 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    GOptionEntry common_options[] = {
    //  long_name short flags option-type          gpointer           description                    arg description
 
-
-
       // Diagnostic output
       {"ddc",     '\0', 0, G_OPTION_ARG_NONE,     &ddc_flag,         "Report DDC protocol and data errors", NULL},
       {"stats",   's',  G_OPTION_FLAG_OPTIONAL_ARG,
@@ -290,8 +297,6 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       {"per-thread-stats",
                   '\0', 0, G_OPTION_ARG_NONE,     &per_thread_stats_flag, "Include per-thread statistics",   NULL},
 
-
-
       // Behavior options
 #ifdef USE_USB
       {"enable-usb", '\0', G_OPTION_FLAG_NONE,
@@ -303,12 +308,12 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
                                G_OPTION_ARG_NONE, &enable_usb_flag,  disable_usb_expl, NULL},
 #endif
       {"mccs",    '\0', 0, G_OPTION_ARG_STRING,   &mccswork,         "MCCS version",            "major.minor" },
-      {"timeout-i2c-io",'\0', 0, G_OPTION_ARG_NONE, &timeout_i2c_io_flag, "Wrap I2C IO in timeout",  NULL},
+      {"timeout-i2c-io",'\0', 0, G_OPTION_ARG_NONE, &timeout_i2c_io_flag, "Deprecated",  NULL},
 //    {"no-timeout-ddc-io",'\0',G_OPTION_FLAG_REVERSE,
 //                            G_OPTION_ARG_NONE,  &timeout_i2c_io_flag,   "Do not wrap DDC IO in timeout (default)",  NULL},
 
       {"force-slave-address",
-                  '\0', 0, G_OPTION_ARG_NONE,     &force_slave_flag, "Force I2C slave address",         NULL},
+                  '\0', 0, G_OPTION_ARG_NONE,     &force_slave_flag, "Deprecated",         NULL},
       {"force",   'f',  G_OPTION_FLAG_HIDDEN,
                            G_OPTION_ARG_NONE,     &force_flag,       "Ignore certain checks",           NULL},
       {"verify",  '\0', 0, G_OPTION_ARG_NONE,     &verify_flag,      "Read VCP value after setting it", NULL},
@@ -333,6 +338,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       {"sleep-multiplier", '\0', 0,
                            G_OPTION_ARG_STRING,   &sleep_multiplier_work, "Multiplication factor for DDC sleeps", "number"},
 
+#ifdef OLD
       {"less-sleep" ,'\0', 0, G_OPTION_ARG_NONE, &reduce_sleeps_flag, "Eliminate some sleeps (default)",  NULL},
       {"sleep-less" ,'\0', 0, G_OPTION_ARG_NONE, &reduce_sleeps_flag, "Eliminate some sleeps (default)",  NULL},
       {"enable-sleep-less" ,'\0', 0, G_OPTION_ARG_NONE, &reduce_sleeps_flag, "Eliminate some sleeps (default)",  NULL},
@@ -341,6 +347,11 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
 //    {"reduce-sleeps",'\0', 0, G_OPTION_ARG_NONE, &reduce_sleeps_flag, "Eliminate some sleeps",  NULL},
 //    {"no-reduce-sleeps",'\0',G_OPTION_FLAG_REVERSE,
 //                               G_OPTION_ARG_NONE,  &reduce_sleeps_flag, "Do not eliminate any sleeps (default)",  NULL},
+#endif
+      {"less-sleep" ,       '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &reduce_sleeps_specified, "Deprecated",  NULL},
+      {"sleep-less" ,       '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &reduce_sleeps_specified, "Deprecated",  NULL},
+      {"enable-sleep-less" ,'\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, &reduce_sleeps_specified, "Deprecated",  NULL},
+      {"disable-sleep-less",'\0', G_OPTION_FLAG_REVERSE,G_OPTION_ARG_NONE, &reduce_sleeps_specified, "Deprecated",  NULL},
 
       {"lazy-sleep",  '\0', 0, G_OPTION_ARG_NONE, &deferred_sleep_flag, "Delay sleeps if possible",  NULL},
 //    {"defer-sleeps",'\0', 0, G_OPTION_ARG_NONE, &deferred_sleep_flag, "Delay sleeps if possible",  NULL},
@@ -479,8 +490,8 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       Pass a mangleable copy of argv to g_option_context_parse_strv().
    */
    Null_Terminated_String_Array temp_argv = ntsa_copy(argv, true);
-   bool ok = g_option_context_parse_strv(context, &temp_argv, &error);
-   if (!ok) {
+   bool parsing_ok = g_option_context_parse_strv(context, &temp_argv, &error);
+   if (!parsing_ok) {
       char * mode_name = (parser_mode == MODE_DDCUTIL) ? "ddcutil" : "libddcutil";
       if (error)
          fprintf(stderr, "%s option parsing failed: %s\n", mode_name, error->message);
@@ -489,12 +500,6 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    }
    ntsa_free(temp_argv, true);
 
-   // DBGMSG("buswork=%d", buswork);
-   // DBGMSG("dispwork=%d", dispwork);
-   // DBGMSG("stats_flag=%d", stats_flag);
-   // DBGMSG("output_level=%d", output_level);
-   // DBGMSG("stats3=0x%02x",stats_work);
-
    int explicit_display_spec_ct = 0;  // number of ways the display is explicitly specified
 
    int rwo_flag_ct = 0;
@@ -503,9 +508,16 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    if (wo_only_flag)   rwo_flag_ct++;
    if (rwo_flag_ct > 1) {
       fprintf(stderr, "Options -rw-only, --ro-only, --wo-only are mutually exclusive\n");
-      ok = false;
+      parsing_ok = false;
    }
 
+   if (reduce_sleeps_specified)
+      fprintf(stderr, "Deprecated option ignored: --enable-sleep-less, --disable-sleep-less, etc.\n");
+   if (force_slave_flag)
+      fprintf(stderr, "Deprecated option ignored: --force_slave_address\n");
+   if (timeout_i2c_io_flag)
+      fprintf(stderr, "Deprecated option ignored: --timeout-i2c-io\n");
+
 #define SET_CMDFLAG(_bit, _flag) \
    do { \
       if (_flag) \
@@ -524,7 +536,9 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    parsed_cmd->stats_types      = stats_work;
    parsed_cmd->i1               = i1_work;
    SET_CMDFLAG(CMD_FLAG_DDCDATA,           ddc_flag);
+#ifdef OLD
    SET_CMDFLAG(CMD_FLAG_FORCE_SLAVE_ADDR,  force_slave_flag);
+#endif
    SET_CMDFLAG(CMD_FLAG_TIMESTAMP_TRACE,   timestamp_trace_flag);
    SET_CMDFLAG(CMD_FLAG_WALLTIME_TRACE,    wall_timestamp_trace_flag);
    SET_CMDFLAG(CMD_FLAG_THREAD_ID_TRACE,   thread_id_trace_flag);
@@ -532,7 +546,9 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    SET_CMDFLAG(CMD_FLAG_VERIFY,            verify_flag || !noverify_flag);
    // if (verify_flag || !noverify_flag)
    //    parsed_cmd->flags |= CMD_FLAG_VERIFY;
+#ifdef OLD
    SET_CMDFLAG(CMD_FLAG_NODETECT,          nodetect_flag);
+#endif
    SET_CMDFLAG(CMD_FLAG_ASYNC,             async_flag);
    SET_CMDFLAG(CMD_FLAG_REPORT_FREED_EXCP, report_freed_excp_flag);
    SET_CMDFLAG(CMD_FLAG_NOTABLE,           notable_flag);
@@ -545,8 +561,10 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
 #ifdef USE_USB
    SET_CMDFLAG(CMD_FLAG_ENABLE_USB,        enable_usb_flag);
 #endif
+#ifdef OLD
    SET_CMDFLAG(CMD_FLAG_TIMEOUT_I2C_IO,    timeout_i2c_io_flag);
    SET_CMDFLAG(CMD_FLAG_REDUCE_SLEEPS,     reduce_sleeps_flag);
+#endif
    SET_CMDFLAG(CMD_FLAG_DSA,               dsa_flag);
    SET_CMDFLAG(CMD_FLAG_DEFER_SLEEPS,      deferred_sleep_flag);
    SET_CMDFLAG(CMD_FLAG_F1,                f1_flag);
@@ -568,7 +586,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       parsed_cmd->failsim_control_fn = failsim_fn_work;
 #else
       fprintf(stderr, "ddcutil not built with failure simulation support.  --failsim option invalid.\n");
-      ok = false;
+      parsing_ok = false;
 #endif
    }
 
@@ -592,8 +610,8 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
          arg_ok = parse_colon_separated_arg(usbwork, &busnum, &devicenum);
       if (!arg_ok) {
           fprintf(stderr, "Invalid USB argument: %s\n", usbwork );
-          ok = false;
-          // DBGMSG("After USB parse, ok=%d", ok);
+          parsing_ok = false;
+          // DBGMSG("After USB parse, parsing_ok=%d", parsing_ok);
       }
       else {
          // avoid memory leak in case parsed_cmd->pdid set in more than 1 way
@@ -605,7 +623,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       explicit_display_spec_ct++;
 #else
       fprintf(stderr, "ddcutil not built with support for USB connected monitors.  --usb option invalid.\n");
-      ok = false;
+      parsing_ok = false;
 #endif
    }
 
@@ -636,14 +654,14 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
    if (edidwork) {
       if (strlen(edidwork) != 256) {
          fprintf(stderr, "EDID hex string not 256 characters\n");
-         ok = false;
+         parsing_ok = false;
       }
       else {
          Byte * pba = NULL;
          int bytect = hhs_to_byte_array(edidwork, &pba);
          if (bytect < 0 || bytect != 128) {
             fprintf(stderr, "Invalid EDID hex string\n");
-            ok = false;
+            parsing_ok = false;
          }
          else {
             // avoid memory leak in case parsed_cmd->pdid set in more than 1 way
@@ -678,7 +696,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
        DBGMSF(debug, "ntsal=%d", ntsal );
        if (ntsa_length(pieces) != 3) {
           fprintf(stderr, "--retries requires 3 values\n");
-          ok = false;
+          parsing_ok = false;
        }
        else {
           int ndx = 0;
@@ -691,15 +709,15 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
                 int ct = sscanf(token, "%ud", &ival);
                 if (ct != 1) {
                    fprintf(stderr, "Invalid --maxtries value: %s\n", token);
-                   ok = false;
+                   parsing_ok = false;
                 }
                 else if (ival > MAX_MAX_TRIES) {
                    fprintf(stderr, "--maxtries value %d exceeds %d\n", ival, MAX_MAX_TRIES);
-                   ok = false;
+                   parsing_ok = false;
                 }
                 else if (ival < 0) {
                    fprintf(stderr, "negative --maxtries value: %d\n", ival);
-                   ok = false;
+                   parsing_ok = false;
                 }
 
                 else {
@@ -729,7 +747,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       }
       if (!arg_ok) {
           fprintf(stderr, "Invalid MCCS spec: %s\n", mccswork );
-          ok = false;
+          parsing_ok = false;
       }
       else {
          parsed_cmd->mccs_vspec = vspec;
@@ -748,7 +766,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
 
       if (!arg_ok) {
           fprintf(stderr, "Invalid sleep-multiplier: %s\n", sleep_multiplier_work );
-          ok = false;
+          parsing_ok = false;
       }
       else {
          parsed_cmd->sleep_multiplier = multiplier;
@@ -762,7 +780,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
        edid_read_size_work != 256)
    {
       fprintf(stderr, "Invalid EDID read size: %d\n", edid_read_size_work);
-      ok = false;
+      parsing_ok = false;
    }
    else
       parsed_cmd->edid_read_size = edid_read_size_work;
@@ -793,7 +811,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
              }
              else {
                 fprintf(stderr, "Invalid trace group: %s\n", token);
-                ok = false;
+                parsing_ok = false;
              }
           }
        }
@@ -828,7 +846,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
             }
             else {
                fprintf(stderr, "Invalid trace group: %s\n", token);
-               ok = false;
+               parsing_ok = false;
             }
         }
       }
@@ -874,7 +892,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       puts("");
       // if no command specified, include license in version information and terminate
       if (rest_ct == 0) {
-         puts("Copyright (C) 2015-2021 Sanford Rockowitz");
+         puts("Copyright (C) 2015-2022 Sanford Rockowitz");
          puts("License GPLv2: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>");
          puts("This is free software: you are free to change and redistribute it.");
          puts("There is NO WARRANTY, to the extent permitted by law.");
@@ -888,27 +906,27 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
       fprintf(stderr, "Monitor specified in more than one way\n");
       free_display_identifier(parsed_cmd->pdid);
       parsed_cmd->pdid = NULL;
-      ok = false;
+      parsing_ok = false;
    }
    // else if (explicit_display_spec_ct == 0)
    //   parsed_cmd->pdid = create_dispno_display_identifier(1);   // default monitor
 
    if (parser_mode == MODE_LIBDDCUTIL && rest_ct > 0) {
          fprintf(stderr, "Unrecognized configuration file options: %s\n", cmd_and_args[0]);
-         ok = false;
+         parsing_ok = false;
    }
-   else if (ok && parser_mode == MODE_DDCUTIL && rest_ct == 0) {
+   else if (parsing_ok && parser_mode == MODE_DDCUTIL && rest_ct == 0) {
       fprintf(stderr, "No command specified\n");
-      ok = false;
+      parsing_ok = false;
    }
-   if (ok && parser_mode == MODE_DDCUTIL) {
+   if (parsing_ok && parser_mode == MODE_DDCUTIL) {
       char * cmd = cmd_and_args[0];
       if (debug)
          printf("cmd=|%s|\n", cmd);
       Cmd_Desc * cmdInfo = find_command(cmd);
       if (cmdInfo == NULL) {
          fprintf(stderr, "Unrecognized command: %s\n", cmd);
-         ok = false;
+         parsing_ok = false;
       }
       else {
          if (debug)
@@ -922,7 +940,7 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
          while ( cmd_and_args[argctr] != NULL) {
             if (argctr > max_arg_ct) {
                fprintf(stderr, "Too many arguments\n");
-               ok = false;
+               parsing_ok = false;
                break;
             }
             char * thisarg = (char *) cmd_and_args[argctr];
@@ -935,36 +953,36 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
          // no more arguments specified
          if (argctr <= min_arg_ct) {
             fprintf(stderr, "Missing argument(s)\n");
-            ok = false;
+            parsing_ok = false;
          }
 
-         if ( ok &&
+         if ( parsing_ok &&
               (parsed_cmd->cmd_id == CMDID_VCPINFO ||
                parsed_cmd->cmd_id == CMDID_GETVCP)
             )
          {
-            Feature_Set_Ref * fsref = calloc(1, sizeof(Feature_Set_Ref));
-            char * val = (parsed_cmd->argct > 0) ? parsed_cmd->args[0] : "ALL";
-            ok = parse_feature_id_or_subset(val, parsed_cmd->cmd_id, fsref);
-            DBGMSF(debug, "parse_feature_id_or_subset() returned: %d", ok);
-            if (ok)
-               parsed_cmd->fref = fsref;
-            else
-               fprintf(stderr, "Invalid feature code or subset: %s\n", parsed_cmd->args[0]);
+            parsed_cmd->fref = parse_feature_ids_or_subset(
+                                  parsed_cmd->cmd_id,  parsed_cmd->args, parsed_cmd->argct);
+            if (!parsed_cmd->fref) {
+               parsing_ok = false;
+               char * s = strjoin((const char **)parsed_cmd->args, parsed_cmd->argct, " ");
+               fprintf(stderr, "Invalid feature code(s) or subset: %s\n", s);
+               free(s);
+            }
          }
 
-         // Ignore --notable for vcpinfo
-         if ( ok && parsed_cmd->cmd_id  == CMDID_VCPINFO) {
+         // Ignore option --notable for vcpinfo
+         if ( parsing_ok && parsed_cmd->cmd_id  == CMDID_VCPINFO) {
             parsed_cmd->flags &= ~CMD_FLAG_NOTABLE;
          }
 
-         if (ok && parsed_cmd->cmd_id == CMDID_GETVCP && (parsed_cmd->flags & CMD_FLAG_WO_ONLY) ) {
+         if (parsing_ok && parsed_cmd->cmd_id == CMDID_GETVCP
+                        && (parsed_cmd->flags & CMD_FLAG_WO_ONLY) ) {
             fprintf(stdout, "Ignoring option --wo-only\n");
             parsed_cmd->flags &= ~CMD_FLAG_WO_ONLY;
          }
 
-         // new way
-         if (ok && parsed_cmd->cmd_id == CMDID_SETVCP) {
+         if (parsing_ok && parsed_cmd->cmd_id == CMDID_SETVCP) {
             // for (int argpos = 0; argpos < parsed_cmd->argct; argpos+=2) {
             int argpos = 0;
             while(argpos < parsed_cmd->argct) {
@@ -974,14 +992,13 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
                              &psv.feature_code);
                if (!feature_code_ok) {
                   fprintf(stderr, "Invalid feature code: %s\n", parsed_cmd->args[argpos]);
-                  ok = false;
+                  parsing_ok = false;
                   break;
                }
-
                argpos++;
                if (argpos >= parsed_cmd->argct) {
                   fprintf(stderr, "Missing feature value\n");
-                  ok = false;
+                  parsing_ok = false;
                   break;
                }
                psv.feature_value_type = VALUE_TYPE_ABSOLUTE;
@@ -994,70 +1011,31 @@ Parsed_Cmd * parse_command(int argc, char * argv[], Parser_Mode parser_mode) {
                   argpos++;
                   if (argpos >= parsed_cmd->argct) {
                      fprintf(stderr, "Missing feature value\n");
-                     ok = false;
+                     parsing_ok = false;
                      break;
                   }
                }
-
                psv.feature_value = strdup(parsed_cmd->args[argpos]);
                g_array_append_val(parsed_cmd->setvcp_values, psv);
                argpos++;
             }
          }
 
-#ifdef OLD
-         if (ok && parsed_cmd->cmd_id == CMDID_SETVCP) {
-            for (int argpos = 0; argpos < parsed_cmd->argct; argpos+=2) {
-               // DBGMSG("argpos=%d, argct=%d", argpos, parsed_cmd->argct);
-               if ( (argpos+1) == parsed_cmd->argct) {
-                  fprintf(stderr, "Missing feature value\n");
-                  ok = false;
-                  break;
-               }
-               char * a1 = parsed_cmd->args[argpos+1];
-               if ( streq(a1,"+") || streq(a1,"-") ) {
-                  if ( (argpos+2) == parsed_cmd->argct) {
-                       fprintf(stderr, "Missing relative feature value\n");
-                       ok = false;
-                       break;
-                  }
-                  char * a2 = parsed_cmd->args[argpos+2];
-                  char * newval = calloc(1, 1 + strlen(a2) + 1);
-                  strcpy(newval, a1);
-                  strcat(newval, a2);
-                  free(a1);
-                  free(a2);
-                  parsed_cmd->args[argpos+1] = newval;
-                  int ndx = 0;
-                  for (ndx = argpos+2; ndx < (parsed_cmd->argct - 1); ndx++) {
-                     parsed_cmd->args[ndx] = parsed_cmd->args[ndx+1];
-                  }
-                  parsed_cmd->args[parsed_cmd->argct - 1] = NULL;
-                  parsed_cmd->argct--;
-               }
-            }
-         }
-#endif
-
       }  // recognized command
    }
 
-   if (ok)
-      ok = validate_output_level(parsed_cmd);
+   if (parsing_ok)
+      parsing_ok = validate_output_level(parsed_cmd);
 
    DBGMSF(debug, "Calling g_option_context_free(), context=%p...", context);
    g_option_context_free(context);
-   // if (trace_classes) {
-   //    DBGMSG("Freeing trace_classes=%p", trace_classes);
-   //    free(trace_classes);   // trying to avoid valgrind error re g_option_context_parse() - doesn't solve it
-   // }
 
    if (debug || debug_parse_flag) {
-      DBGMSG("ok=%s", sbool(ok));
+      DBGMSG("parsing_ok=%s", sbool(parsing_ok));
       dbgrpt_parsed_cmd(parsed_cmd, 0);
    }
 
-   if (!ok) {
+   if (!parsing_ok) {
       free_parsed_cmd(parsed_cmd);
       parsed_cmd = NULL;
    }
