@@ -3,7 +3,7 @@
  * Load/store VCP settings from/to file.
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "config.h"
@@ -41,6 +41,7 @@
 #include "i2c/i2c_bus_core.h"
 
 #include "ddc/ddc_displays.h"
+#include "ddc/ddc_display_selection.h"
 #include "ddc/ddc_output.h"
 #include "ddc/ddc_packet_io.h"
 #include "ddc/ddc_read_capabilities.h"
@@ -350,6 +351,9 @@ create_dumpload_data_from_g_ptr_array(
  *
  * This function stops applying values on the first error encountered, and
  * returns the value of that error as its status code.
+ *
+ * @remark
+ * Consider not stopping on error, instead accumulate errors in Error_Info.
  */
 Error_Info *
 ddc_set_multiple(
@@ -728,7 +732,7 @@ dumpvcp_as_dumpload_data(
       Dumpload_Data** dumpload_data_loc)
 {
    bool debug = false;
-   DBGMSF(debug, "Starting. dh=%s", dh_repr_t(dh));
+   DBGMSF(debug, "Starting. dh=%s", dh_repr(dh));
    Public_Status_Code psc = 0;
    Dumpload_Data * dumped_data = calloc(1, sizeof(Dumpload_Data));
 
@@ -852,7 +856,7 @@ convert_dumpload_data_to_string_array(Dumpload_Data * data) {
 Public_Status_Code
 dumpvcp_as_string(Display_Handle * dh, char ** result_loc) {
    bool debug = false;
-   DBGMSF(debug, "Starting, dh=%s", dh_repr_t(dh));
+   DBGMSF(debug, "Starting, dh=%s", dh_repr(dh));
 
    Public_Status_Code psc    = 0;
    Dumpload_Data *    data   = NULL;
