@@ -4,7 +4,7 @@
  * Capabilities.
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -166,10 +166,11 @@ try_multi_part_read(
 *  @param  all_zero_response_ok  if true, zero response is not an error
 *  @param  buffer_loc            address at which to return newly allocated #Buffer in which
 *                                result is returned
-*
 *  @retval  NULL    success
 *  @retval  #Ddc_Error containing status DDCRC_UNSUPPORTED does not support Capabilities Request
 *  @retval  #Ddc_Error containing status DDCRC_TRIES  maximum retries exceeded:
+*
+*  *buffer_loc is set iff returned value is NULL
 */
 Error_Info *
 multi_part_read_with_retry(
@@ -186,11 +187,9 @@ multi_part_read_with_retry(
           ", max_multi_part_read_tries=%d",
           request_type, request_subtype, sbool(all_zero_response_ok), max_multi_part_read_tries);
 
-
    Public_Status_Code rc = -1;   // dummy value for first call of while loop
    Error_Info * ddc_excp = NULL;
-   // Public_Status_Code try_status_codes[MAX_MAX_TRIES];
-   Error_Info *        try_errors[MAX_MAX_TRIES];
+   Error_Info * try_errors[MAX_MAX_TRIES];
 
    int tryctr = 0;
    bool can_retry = true;
@@ -251,7 +250,6 @@ multi_part_read_with_retry(
       }
    }
 
-
    if (rc < 0) {
       buffer_free(accumulator, "capabilities buffer, error");
       accumulator = NULL;
@@ -274,7 +272,12 @@ multi_part_read_with_retry(
 
    *buffer_loc = accumulator;
    ASSERT_IFF(ddc_excp, !*buffer_loc);
+   DBGTRC_RET_ERRINFO_STRUCT(debug, TRACE_GROUP, ddc_excp, buffer_loc, buffer_rpt);
+#ifdef OLD
    DBGTRC_RET_ERRINFO(debug, TRACE_GROUP, ddc_excp, "*buffer_loc=%p", *buffer_loc);
+   if (IS_DBGTRC(debug, TRACE_GROUP) && *buffer_loc)
+     buffer_rpt(*buffer_loc, 2);
+#endif
    return ddc_excp;
 }
 
@@ -357,7 +360,7 @@ multi_part_write_with_retry(
    if (IS_TRACING())
       puts("");
    DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, vcp_code=0x%02x",
-                              dh_repr_t(dh), vcp_code);
+                              dh_repr(dh), vcp_code);
 
    Public_Status_Code rc = -1;   // dummy value for first call of while loop
    Error_Info * ddc_excp = NULL;
