@@ -163,15 +163,9 @@ get_raw_value_for_feature_metadata(
    bool debug = false;
    DBGTRC_STARTING(debug, TRACE_GROUP, "frec=%p, feature_code=0x%02x", frec, (frec) ? frec->feature_code : 0x00);
 
-   // Public_Status_Code psc = 0;
    Error_Info * ddc_excp = NULL;
-
-   // DDCA_MCCS_Version_Spec vspec = get_vcp_version_by_dh(dh);
-   // char * feature_name = get_version_sensitive_feature_name(frec, vspec);
    char * feature_name = frec->feature_name;
-
    Byte feature_code = frec->feature_code;
-   // bool is_table_feature = is_table_feature_by_dh(frec, dh);
    bool is_table_feature = frec->feature_flags & DDCA_TABLE;
    DDCA_Vcp_Value_Type feature_type = (is_table_feature) ? DDCA_TABLE_VCP_VALUE : DDCA_NON_TABLE_VCP_VALUE;
    DDCA_Output_Level output_level = get_output_level();
@@ -196,10 +190,8 @@ get_raw_value_for_feature_metadata(
               feature_code,
               feature_type,
               &valrec);
-      // psc = ERRINFO_STATUS(ddc_excp);
    }
    ASSERT_IFF( ddc_excp, !valrec);
-   // assert ( (psc==0 && valrec) || (psc!=0 && !valrec) );
 
    // For now, only regard -EIO as unsupported feature for the
    // single model on which this has been observed
@@ -294,7 +286,7 @@ get_raw_value_for_feature_metadata(
       default:
          {
             char buf[200];
-            snprintf(buf, 200, "Invalid response. status code=%d, %s", psc, dh_repr_t(dh));
+            snprintf(buf, 200, "Invalid response. status code=%s, %s", psc_name_code(psc), dh_repr(dh));
             f0printf(msg_fh, FMT_CODE_NAME_DETAIL_W_NL,
                              feature_code, feature_name, buf);
          }
@@ -317,7 +309,7 @@ get_raw_value_for_feature_metadata(
 }
 
 
-#ifdef IN_PROGREESS
+#ifdef IN_PROGRESS
 Public_Status_Code
 get_raw_value_for_feature_metadata_dfm(
       Display_Handle *           dh,
@@ -415,7 +407,7 @@ get_raw_value_for_feature_metadata_dfm(
    default:
    {
       char buf[200];
-      snprintf(buf, 200, "Invalid response. status code=%s, %s", psc_desc(psc), dh_repr_t(dh));
+      snprintf(buf, 200, "Invalid response. status code=%s, %s", psc_desc(psc), dh_repr(dh));
       f0printf(msg_fh, FMT_CODE_NAME_DETAIL_W_NL,
                        feature_code, feature_name, buf);
    }
@@ -442,7 +434,6 @@ get_raw_value_for_feature_metadata_dfm(
 #endif
 
 
-
 /* Gather values for the features in a feature set.
  *
  * Arguments:
@@ -464,16 +455,16 @@ collect_raw_feature_set_values2_dfm(
       FILE *                msg_fh)
 {
    bool debug = false;
-   DBGMSF(debug, "Starting. dh=%s, msg_fh=%p", dh_repr_t(dh), msg_fh);
+   DBGMSF(debug, "Starting. dh=%s, msg_fh=%p", dh_repr(dh), msg_fh);
 
    Public_Status_Code master_status_code = 0;
-   int features_ct = dyn_get_feature_set_size2(feature_set);
+   int features_ct = dyn_get_feature_set_size(feature_set);
    // needed when called from C API, o.w. get get NULL response for first feature
    // DBGMSG("Inserting sleep() before first call to get_raw_value_for_feature_table_entry()");
    // sleep_millis_with_trace(DDC_TIMEOUT_MILLIS_DEFAULT, __func__, "initial");
    int ndx;
    for (ndx=0; ndx< features_ct; ndx++) {
-      Display_Feature_Metadata * dfm = dyn_get_feature_set_entry2(feature_set, ndx);
+      Display_Feature_Metadata * dfm = dyn_get_feature_set_entry(feature_set, ndx);
       DBGMSF(debug,"ndx=%d, feature = 0x%02x", ndx, dfm->feature_code);
       DDCA_Any_Vcp_Value *  pvalrec;
       // DDCA_Feature_Metadata * ddca_meta = dfm_to_ddca_feature_metadata(dfm);
@@ -542,7 +533,7 @@ ddc_collect_raw_subset_values(
    Feature_Set_Flags flags = FSF_NOTABLE;
    if (subset == VCP_SUBSET_PROFILE)
       flags |= FSF_RW_ONLY;
-   Dyn_Feature_Set * feature_set = dyn_create_feature_set2(
+   Dyn_Feature_Set * feature_set = dyn_create_feature_set(
                                      subset,
                                      dh->dref,          // vcp_version,
                                      flags);
@@ -654,7 +645,7 @@ ddc_get_formatted_value_for_dfm(
             *formatted_value_loc = formatted;
             free(hexbuf);
          }
-         else {                                // OL_PROGRAM, not table feature
+         else {                                // OL_PROGRAM, not table featdyn_create_feature_set2ure
             DDCA_Version_Feature_Flags vflags = dfm->feature_flags;
             // =   get_version_sensitive_feature_flags(vcp_entry, vspec);
             char buf[200];
@@ -736,7 +727,7 @@ ddc_get_formatted_value_for_dfm(
    if (pvalrec)
       free_single_vcp_value(pvalrec);
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, psc,
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, psc,
           "*formatted_value_loc=%p -> %s",
           *formatted_value_loc, *formatted_value_loc);
 
@@ -752,7 +743,7 @@ show_feature_set_values2_dfm(
       Dyn_Feature_Set*      feature_set,
       GPtrArray *           collector,     // if null, write to current stdout device
       Feature_Set_Flags     flags,
-      Byte_Value_Array      features_seen)     // if non-null, collect list of features seen
+      Bit_Set_256 *         features_seen)     // if non-null, collect list of features seen
 {
    bool debug = false;
    char * s0 = feature_set_flag_names_t(flags);
@@ -768,6 +759,9 @@ show_feature_set_values2_dfm(
    if ( (flags & FSF_SHOW_UNSUPPORTED)  ||
         output_level >= DDCA_OL_VERBOSE ||
         subset_id == VCP_SUBSET_SINGLE_FEATURE
+#ifdef FUTURE
+        ||        subset_id == VCP_SUBSET_MULTI_FEATURES
+#endif
        )
        show_unsupported = true;
    bool suppress_unsupported = !show_unsupported;
@@ -775,11 +769,11 @@ show_feature_set_values2_dfm(
    // DDCA_MCCS_Version_Spec vcp_version = get_vcp_version_by_dh(dh);
    bool prefix_value_with_feature_code = true;    // TO FIX
    FILE * msg_fh = outf;                        // TO FIX
-   int features_ct = dyn_get_feature_set_size2(feature_set);
+   int features_ct = dyn_get_feature_set_size(feature_set);
    DBGMSF(debug, "features_ct=%d", features_ct);
    int ndx;
    for (ndx=0; ndx< features_ct; ndx++) {
-      Display_Feature_Metadata * dfm = dyn_get_feature_set_entry2(feature_set, ndx);
+      Display_Feature_Metadata * dfm = dyn_get_feature_set_entry(feature_set, ndx);
       // DDCA_Feature_Metadata * extmeta = ifm->external_metadata;
       DBGMSF(debug,"ndx=%d, feature = 0x%02x", ndx, dfm->feature_code);
       if ( !(dfm->feature_flags & DDCA_READABLE) ) {
@@ -820,7 +814,7 @@ show_feature_set_values2_dfm(
                   f0printf(outf, "%s\n", formatted_value);
                free(formatted_value);
                if (features_seen)
-                  bbf_set(features_seen, dfm->feature_code);  // note that feature was read
+                  *features_seen = bs256_insert(*features_seen, dfm->feature_code);  // note that feature was read
             }
             else {
                // or should I check features_ct == 1?
@@ -844,7 +838,6 @@ show_feature_set_values2_dfm(
 }
 
 
-
 #ifdef FUTURE
 //typedef bool (*VCP_Feature_Set_Filter_Func)(VCP_Feature_Table_Entry * ventry);
 bool hack42(VCP_Feature_Table_Entry * ventry) {
@@ -864,27 +857,23 @@ bool hack42(VCP_Feature_Table_Entry * ventry) {
 #endif
 
 
-
-/* Shows the VCP values for all features in a VCP feature subset.
+/** Shows the VCP values for all features in a VCP feature subset.
  *
- * Arguments:
- *    dh         display handle for open display
- *    subset     feature subset id
- *    collector  accumulates output    // if null, write to current stdout device
- *    flags      feature set flags
- *    features_seen   if non-null, collect ids of features that exist
- *
- * Returns:
- *    status code
+ *  @param  dh         display handle for open display
+ *  @param  subset     feature subset id
+ *  @param  collector  accumulates output    // if null, write to current stdout device
+ *  @param  flags      feature set flags
+ *  @param  features_seen   collects ids of features that exist
+ *  @return status code
  */
-// 11/2019: only call is from app_getvcp.c
+// 11/2019: only call is from app_getvcp.c, move there?
 Public_Status_Code
 ddc_show_vcp_values(
         Display_Handle *    dh,
         VCP_Feature_Subset  subset,
         GPtrArray *         collector,    // not used
         Feature_Set_Flags   flags,
-        Byte_Bit_Flags      features_seen)
+        Bit_Set_256 *       features_seen)
 {
    bool debug = false;
    DBGTRC_STARTING(debug, TRACE_GROUP, "subset=%d, flags=%s,  dh=%s",
@@ -895,7 +884,7 @@ ddc_show_vcp_values(
    // DDCA_MCCS_Version_Spec vcp_version = get_vcp_version_by_dh(dh);
    // DBGMSG("VCP version = %d.%d", vcp_version.major, vcp_version.minor);
 
-   Dyn_Feature_Set* feature_set = dyn_create_feature_set2(
+   Dyn_Feature_Set* feature_set = dyn_create_feature_set(
                                     subset,
                                     dh->dref,   // vcp_version,
                                     flags);
@@ -917,7 +906,7 @@ ddc_show_vcp_values(
    psc = show_feature_set_values2_dfm(
             dh, feature_set, collector, flags, features_seen);
    dyn_free_feature_set(feature_set);
-   DBGTRC_RETURNING(debug, TRACE_GROUP, psc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, psc, "");
    return psc;
 }
 
