@@ -57,6 +57,8 @@
 // Trace class for this file
 static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_DDCIO;
 
+bool DDC_Read_Bytewise               = DEFAULT_DDC_READ_BYTEWISE;
+
 static GHashTable * open_displays = NULL;
 
 #ifdef DEPRECATED
@@ -93,7 +95,7 @@ ddc_is_valid_display_handle(Display_Handle * dh) {
    DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%p", dh);
    assert(open_displays);
    bool result = g_hash_table_contains(open_displays, dh);
-   DBGTRC_DONE(debug, TRACE_GROUP, "Rreturning %s. dh=%p", sbool(result), dh);
+   DBGTRC_RET_BOOL(debug, TRACE_GROUP, result, "dh=%s", dh_repr(dh));
    return result;
 }
 
@@ -105,7 +107,7 @@ void ddc_dbgrpt_valid_display_handles(int depth) {
    if (g_list_length(display_handles) > 0) {
       for (GList * cur = display_handles; cur; cur = cur->next) {
          Display_Handle * dh = cur->data;
-         rpt_vstring(depth+1, "%p -> %s", dh, dh_repr_t(dh));
+         rpt_vstring(depth+1, "%p -> %s", dh, dh_repr(dh));
       }
    }
    else {
@@ -127,7 +129,6 @@ void ddc_dbgrpt_valid_display_handles(int depth) {
  *  \return status code     as from #i2c_open_bus(), #usb_open_hiddev_device()
  *  \retval DDCRC_LOCKED    display open in another thread
  *  \retval DDCRC_ALREADY_OPEN display already open in current thread
- *  \retval -EBUSY          from i2c_set_addr()
  *
  *  **Call_Option** flags recognized:
  *  - CALLOPT_WAIT
@@ -186,16 +187,8 @@ ddc_open_display(
             ddcrc = fd;
          }
          else {
-            // DBGMSF(debug, "Calling set_addr(0x37) for %s", dref_repr_t(dref));
-            ddcrc =  i2c_set_addr(fd, 0x37, callopts);
-            if (ddcrc != 0) {
-               TRACED_ASSERT(ddcrc < 0);
-               if (ddcrc == -EBUSY)
-                  bus_info->flags |= I2C_BUS_BUSY;
-               close(fd);
-            }
-
-            else {
+            if (ddcrc == 0) {
+            // else {
                // Is this needed?
                // 10/24/15, try disabling:
                // sleepMillisWithTrace(DDC_TIMEOUT_MILLIS_DEFAULT, __func__, NULL);
@@ -249,8 +242,6 @@ ddc_open_display(
    TRACED_ASSERT(!dh || dh->dref->pedid);
 
    if (ddcrc == 0) {
-      if (dref->io_path.io_mode != DDCA_IO_USB)
-         TUNED_SLEEP_WITH_TRACE(dh, SE_POST_OPEN, NULL);
       dref->flags |= DREF_OPEN;
       // protect with lock?
       TRACED_ASSERT(open_displays);
@@ -268,7 +259,7 @@ bye:
    TRACED_ASSERT(ddcrc <= 0);
    TRACED_ASSERT( (ddcrc == 0 && *dh_loc) || (ddcrc < 0 && !*dh_loc) );
    // dbgrpt_distinct_display_descriptors(0);
-   DBGTRC_RETURNING(debug, TRACE_GROUP, ddcrc, "*dh_loc=%s", dh_repr_t(*dh_loc));
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, ddcrc, "*dh_loc=%s", dh_repr(*dh_loc));
    return ddcrc;
 }
 
@@ -285,7 +276,7 @@ Status_Errno
 ddc_close_display(Display_Handle * dh) {
    bool debug = false;
    DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, dref=%s, fd=%d, dpath=%s",
-              dh_repr_t(dh), dref_repr_t(dh->dref), dh->fd, dpath_short_name_t(&dh->dref->io_path) ) ;
+              dh_repr(dh), dref_repr_t(dh->dref), dh->fd, dpath_short_name_t(&dh->dref->io_path) ) ;
    Display_Ref * dref = dh->dref;
    Status_Errno rc = 0;
    if (dh->fd == -1) {
@@ -332,7 +323,7 @@ ddc_close_display(Display_Handle * dh) {
    g_hash_table_remove(open_displays, dh);
 
    free_display_handle(dh);
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "dref=%s", dref_repr_t(dref));
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "dref=%s", dref_repr_t(dref));
    return rc;
 }
 
@@ -388,7 +379,7 @@ DDCA_Status (*Write_Read_Raw_Function)(
  *   -errno if error in write
  *   DDCRC_READ_ALL_ZERO
  */
-// static  // allow function to appear in backtrace
+// not static so that function can appear in backtrace
 DDCA_Status ddc_i2c_write_read_raw(
          Display_Handle * dh,
          DDC_Packet *     request_packet_ptr,
@@ -399,7 +390,8 @@ DDCA_Status ddc_i2c_write_read_raw(
         )
 {
    bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, readbuf=%p",dh_repr_t(dh), readbuf);
+   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, read_bytewise=%s, max_read_bytes=%d, readbuf=%p",
+                              dh_repr(dh), SBOOL(read_bytewise), max_read_bytes, readbuf );
    // DBGMSG("request_packet_ptr=%p", request_packet_ptr);
    // dump_packet(request_packet_ptr);
 
@@ -439,9 +431,11 @@ DDCA_Status ddc_i2c_write_read_raw(
 
       CHECK_DEFERRED_SLEEP(dh);
       rc = invoke_i2c_reader(dh->fd, 0x37, read_bytewise, max_read_bytes, readbuf);
+
       // try adding sleep to see if improves capabilities read for P2411H
       // tuned_sleep_i2c_with_trace(SE_POST_READ, __func__, NULL);
       TUNED_SLEEP_WITH_TRACE(dh, SE_POST_READ, NULL);
+
       if (rc == 0)
          DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Response bytes: %s",
                                 hexstring3_t(readbuf, max_read_bytes, " ", 1, false) );
@@ -458,7 +452,7 @@ DDCA_Status ddc_i2c_write_read_raw(
       COUNT_STATUS_CODE(rc);
    }
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
    return rc;
 }
 
@@ -475,8 +469,8 @@ DDCA_Status ddc_write_read_raw(
      )
 {
    bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, readbuf=%p, max_read_bytes=%d",
-                              dh_repr_t(dh), readbuf, max_read_bytes);
+   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, read_bytewise=%s, max_read_bytes=%d, readbuf=%p",
+                              dh_repr(dh), SBOOL(read_bytewise), max_read_bytes, readbuf );
    if (debug) {
       // DBGMSG("request_packet_ptr->raw_bytes:");
       // dbgrpt_buffer(request_packet_ptr->raw_bytes, 1);
@@ -497,10 +491,11 @@ DDCA_Status ddc_write_read_raw(
                  p_rcvd_bytes_ct
               );
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, psc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, psc, "");
    if (psc == 0) {
       DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-             "readbuf: %s",
+             "*p_rcvd_bytes_ct=%d, readbuf: %s",
+             *p_rcvd_bytes_ct,
              hexstring3_t(readbuf, *p_rcvd_bytes_ct, " ", 4, false));
    }
    return psc;
@@ -533,9 +528,12 @@ ddc_write_read(
      )
 {
    bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, read_bytewise=%s, max_read_bytes=%d",
-                 dh_repr_t(dh), sbool(read_bytewise), max_read_bytes );
+   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, read_bytewise=%s, max_read_bytes=%d,"
+                                       " expected_response_type=0x%02x, expected_subtype=0x%02x",
+          dh_repr(dh), SBOOL(read_bytewise), max_read_bytes, expected_response_type, expected_subtype  );
 
+   DBGTRC_NOPREFIX(debug, DDCA_TRC_NONE, "Adding 1 to max_read_bytes to allow for initail double 0x63 quirk");
+   max_read_bytes++;   //allow for quirk of double 0x6e at start
    Byte * readbuf = calloc(1, max_read_bytes);
    int    bytes_received = max_read_bytes;
    DDCA_Status    psc;
@@ -563,6 +561,7 @@ ddc_write_read(
               "create_ddc_typed_response_packet() returned %s, *response_packet_ptr_loc=%p",
               ddcrc_desc_t(psc), *response_packet_ptr_loc );
 
+       // psc = -5;    // *** FOR TESTING ***
        if (psc != 0 && *response_packet_ptr_loc) {  // paranoid,  should never occur
           free(*response_packet_ptr_loc);
           *response_packet_ptr_loc = NULL;
@@ -581,6 +580,8 @@ ddc_write_read(
    if (psc < 0)
       excp = errinfo_new(psc, __func__);
 
+   DBGTRC_RET_ERRINFO_STRUCT(debug, TRACE_GROUP, excp, response_packet_ptr_loc, dbgrpt_packet);
+#ifdef OLD
    if (excp) {
       DBGTRC_DONE(debug, TRACE_GROUP, "Returning: %s", errinfo_summary(excp)  );
    }
@@ -589,6 +590,7 @@ ddc_write_read(
       if (debug || IS_TRACING())
          dbgrpt_packet(*response_packet_ptr_loc, 2);
    }
+#endif
 
    return excp;
 }
@@ -605,16 +607,6 @@ ddc_write_read(
  *  \param response_packet_ptr_loc  where to write address of response packet received
  *
  *  \return pointer to #Error_Info struct if failure, NULL if success
- *
- *  \remark
- *  status code from #ddc_write_read() may be positive for positive ADL status code ??
- *            status code from #ddc_write_read() if exactly 1 pass through try loop\n
- *            DDCRC_RETRIES, DDCRC_ALL_TRIES_ZERO, DDCRC_ALL_RESPONES_NULL if maximum tries exceeded
- *
- *\remark
- * Issue: positive ADL codes, need to handle?
- * \remark
- * The maximum number of tries is set in global variable max_write_read_exchange_tries.
  */
 Error_Info *
 ddc_write_read_with_retry(
@@ -628,8 +620,9 @@ ddc_write_read_with_retry(
         )
 {
    bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, all_zero_response_ok=%s",
-          dh_repr_t(dh), sbool(all_zero_response_ok)  );
+   DBGTRC_STARTING(debug, TRACE_GROUP, "dh=%s, max_read_bytes=%d, expected_response_type=0x%02x, "
+                                       "expected_subtype=0x%02x, all_zero_response_ok=%s",
+          dh_repr(dh), max_read_bytes, expected_response_type, expected_subtype, sbool(all_zero_response_ok)  );
    TRACED_ASSERT(dh->dref->io_path.io_mode != DDCA_IO_USB);
    // show_backtrace(1);
 
@@ -639,7 +632,7 @@ ddc_write_read_with_retry(
    bool retry_null_response = !(dh->dref->flags & DREF_DDC_USES_NULL_RESPONSE_FOR_UNSUPPORTED);
 
    DDCA_Status  psc;
-   bool read_bytewise = I2C_Read_Bytewise;   // normally set to DEFAULT_I2C_READ_BYTEWISE
+   bool read_bytewise = DDC_Read_Bytewise;   // normally set to DEFAULT_I2C_READ_BYTEWISE
    int  tryctr;
    bool retryable;
    int  ddcrc_read_all_zero_ct = 0;
@@ -682,7 +675,7 @@ ddc_write_read_with_retry(
       if (psc == 0 && ddcrc_null_response_ct > 0) {
          DBGTRC_NOPREFIX(debug, TRACE_GROUP | DDCA_TRC_RETRY,
                 "%s, ddc_write_read() succeeded after %d sleep and retry for DDC Null Response",
-                dh_repr_t(dh),
+                dh_repr(dh),
                 ddcrc_null_response_ct);
       }
 
@@ -692,56 +685,54 @@ ddc_write_read_with_retry(
 
          TRACED_ASSERT(dh->dref->io_path.io_mode == DDCA_IO_I2C);
 
-            // The problem: Does NULL response indicate an error condition, or
-            // is the monitor using NULL response to indicate unsupported?
-            // Acer monitor uses NULL response instead of setting the unsupported
-            // flag in a valid response
-            switch (psc) {
-            case DDCRC_NULL_RESPONSE:
-                  {
-                     retryable = (++ddcrc_null_response_ct < ddcrc_null_response_max);
-                     DBGMSF(debug, "DDCRC_NULL_RESPONSE, retryable=%s", sbool(retryable));
-                     if (retryable) {
-                        if (ddcrc_null_response_ct == 1 && get_output_level() >= DDCA_OL_VERBOSE)
-                           f0printf(fout(), "Extended delay as recovery from DDC Null Response...\n");
-                        tsd_set_sleep_multiplier_ct(ddcrc_null_response_ct+1);
-                        sleep_multiplier_incremented = true;
-                        // replaces: call_dynamic_tuned_sleep_i2c(SE_DDC_NULL, ddcrc_null_response_ct);
-                     }
+         // The problem: Does NULL response indicate an error condition, or
+         // is the monitor using NULL response to indicate unsupported?
+         // Acer monitor uses NULL response instead of setting the unsupported
+         // flag in a valid response
+         switch (psc) {
+         case DDCRC_NULL_RESPONSE:
+               {
+                  retryable = (++ddcrc_null_response_ct < ddcrc_null_response_max);
+                  DBGMSF(debug, "DDCRC_NULL_RESPONSE, retryable=%s", sbool(retryable));
+                  if (retryable) {
+                     if (ddcrc_null_response_ct == 1 && get_output_level() >= DDCA_OL_VERBOSE)
+                        f0printf(fout(), "Extended delay as recovery from DDC Null Response...\n");
+                     tsd_set_sleep_multiplier_ct(ddcrc_null_response_ct++);
+                     sleep_multiplier_incremented = true;
+                     // replaces: call_dynamic_tuned_sleep_i2c(SE_DDC_NULL, ddcrc_null_response_ct);
                   }
-                  break;
+               }
+               break;
 
-            case (DDCRC_READ_ALL_ZERO):
-                 // when is DDCRC_READ_ALL_ZERO actually an error vs the response of the monitor instead of NULL response?
-                 // On Dell monitors (P2411, U3011) all zero response occurs on unsupported Table features
-                 // But also seen as a bad response
-                 retryable = (all_zero_response_ok) ? false : true;
-                 break;
+         case (DDCRC_READ_ALL_ZERO):
+              // when is DDCRC_READ_ALL_ZERO actually an error vs the response of the monitor instead of NULL response?
+              // On Dell monitors (P2411, U3011) all zero response occurs on unsupported Table features
+              // But also seen as a bad response
+              retryable = (all_zero_response_ok) ? false : true;
+              ddcrc_read_all_zero_ct++;
+              break;
 
-            case (-EIO):
-                 // retryable = false;     // ??
-                 break;
+         case (-EIO):
+              // retryable = false;     // ??
+              break;
 
-            case (-EBADF):
-                 // DBGMSG("EBADF");
-                 retryable = false;
-                 break;
+         case (-EBADF):
+              // DBGMSG("EBADF");
+              retryable = false;
+              break;
 
-            case (-ENXIO):    // no such device or address, i915 driver
-                 retryable = false;  // have seen success after 7 retries of errors including ENXIO, DDCRC_DATA, make retryable?
-                 break;
+         case (-ENXIO):    // no such device or address, i915 driver
+              retryable = false;  // have seen success after 7 retries of errors including ENXIO, DDCRC_DATA, make retryable?
+              break;
 
-            default:
-                 retryable = true;     // for now
+         default:
+              retryable = true;     // for now
+         }
 
-            // try exponential backoff on all errors, not just SE_DDC_NULL
-            // if (retryable)
-            //    call_dynamic_tuned_sleep_i2c(SE_DDC_NULL, tryctr+1);
-                  }
+         // try exponential backoff on all errors, not just SE_DDC_NULL
+         // if (retryable)
+         //    call_dynamic_tuned_sleep_i2c(SE_DDC_NULL, tryctr+1);
 
-
-         if (psc == DDCRC_READ_ALL_ZERO)
-            ddcrc_read_all_zero_ct++;
       }    // rc < 0
       // DBGMSG("Bottom of try loop. psc=%d, tryctr=%d, retryable=%s", psc, tryctr, sbool(retryable));
    }
@@ -765,7 +756,8 @@ ddc_write_read_with_retry(
          char * s0 = (psc == 0) ? "Succeeded" : "Failed";
          char * s1 = (errct == 1) ? "" : "s";
          char * s = errinfo_array_summary(try_errors, errct);
-         DBGTRC_NOPREFIX(debug, TRACE_GROUP | DDCA_TRC_RETRY, "%s after %d error%s: %s", s0, errct, s1, s);
+         DBGTRC_NOPREFIX(debug, TRACE_GROUP | DDCA_TRC_RETRY, "%s,%s after %d error%s: %s",
+               dh_repr(dh), s0, errct, s1, s);
          free(s);
 
    }
@@ -851,7 +843,7 @@ ddc_i2c_write_only(
             : SE_POST_WRITE;
    // tuned_sleep_i2c_with_trace(sleep_type, __func__, NULL);
    TUNED_SLEEP_WITH_TRACE(dh, sleep_type, NULL);
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
    return rc;
 }
 
