@@ -3,7 +3,7 @@
  * ddc layer initialization and configuration, statistics management
  */
 
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #include "config.h"
@@ -23,20 +23,23 @@
 #include "base/thread_retry_data.h"
 #include "base/thread_sleep_data.h"
 
-#include "vcp/vcp_feature_codes.h"
+#include "vcp/parse_capabilities.h"
 #include "vcp/persistent_capabilities.h"
+#include "vcp/vcp_feature_codes.h"
 
 #include "dynvcp/dyn_feature_codes.h"
 #include "dynvcp/dyn_feature_files.h"
 
 #include "i2c/i2c_bus_core.h"
 #include "i2c/i2c_strategy_dispatcher.h"
+#include "i2c/i2c_sysfs.h"
 #ifdef USE_USB
 #include "usb/usb_displays.h"
 #endif
 
 #include "ddc/ddc_display_lock.h"
 #include "ddc/ddc_displays.h"
+#include "ddc/ddc_display_ref_reports.h"
 #include "ddc/ddc_dumpload.h"
 #include "ddc/ddc_multi_part_io.h"
 #include "ddc/ddc_output.h"
@@ -44,7 +47,9 @@
 #include "ddc/ddc_read_capabilities.h"
 #include "ddc/ddc_try_stats.h"
 #include "ddc/ddc_vcp.h"
+#ifdef BUILD_SHARED_LIB
 #include "ddc/ddc_watch_displays.h"
+#endif
 
 #include "ddc/ddc_services.h"
 
@@ -153,8 +158,8 @@ void init_ddc_services() {
    DBGMSF(debug, "Starting");
 
    // i2c:
-   i2c_set_io_strategy(DEFAULT_I2C_IO_STRATEGY);
    init_i2c_bus_core();
+   init_i2c_sysfs();
 
    // usb
 #ifdef USE_USB
@@ -164,10 +169,12 @@ void init_ddc_services() {
    // ddc:
    try_data_init();
    init_persistent_capabilities();
+   init_parse_capabilities();
    init_vcp_feature_codes();
    init_dyn_feature_codes();    // must come after init_vcp_feature_codes()
    init_dyn_feature_files();
    init_ddc_display_lock();
+   init_ddc_display_ref_reports();
    init_ddc_displays();
    init_ddc_dumpload();
    init_ddc_output();
@@ -175,7 +182,9 @@ void init_ddc_services() {
    init_ddc_read_capabilities();
    init_ddc_multi_part_io();
    init_ddc_vcp();
+#ifdef BUILD_SHARED_LIB
    init_ddc_watch_displays();
+#endif
 
    // dbgrpt_rtti_func_name_table(1);
    DBGMSF(debug, "Done");
