@@ -1,4 +1,4 @@
-/** \file i2c_bus_core.c
+/** @file i2c_bus_core.c
  *
  * I2C bus detection and inspection
  */
@@ -12,7 +12,7 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <glib-2.0/glib.h>
-#include <i2c/smbus.h>   // TEMP
+#include <limits.h>
 #include <stdlib.h>
 #include <string.h>
 #include <sys/ioctl.h>
@@ -56,6 +56,7 @@
 #endif
 #include "i2c/i2c_strategy_dispatcher.h"
 #include "i2c/i2c_sysfs.h"
+#include "i2c/i2c_execute.h"
 
 #include "i2c/i2c_bus_core.h"
 
@@ -63,19 +64,98 @@
 // Trace class for this file
 static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_I2C;
 
+bool EDID_Read_Bytewise              = DEFAULT_EDID_READ_BYTEWISE;
+int  EDID_Read_Size                  = DEFAULT_EDID_READ_SIZE;
+bool EDID_Write_Before_Read          = DEFAULT_EDID_WRITE_BEFORE_READ;
+
 /** All I2C buses.  GPtrArray of pointers to #I2C_Bus_Info - shared with i2c_bus_selector.c */
 /* static */ GPtrArray * i2c_buses = NULL;
 
-/** Global variable.  Controls whether function #i2c_set_addr() attempts retry
- *  after EBUSY error by changing ioctl op I2C_SLAVE to I2C_SLAVE_FORCE.
- */
-bool i2c_force_slave_addr_flag = false;
-
-
-// Another ugly global variable for testing purposes
-
 bool i2c_force_bus = false;
 
+static GMutex  open_failures_mutex;
+static Bit_Set_256 open_failures_reported;
+
+//
+// Local utility functions
+//
+
+/** Creates a string interpretation of I2C_Bus_Info.flags.
+ *
+ *  @param  flags flags value
+ *  @return string interpretation, caller must free
+ *
+ *  @remark
+ *  Keep the names in sync with flag definitions
+ */
+static char * interpret_i2c_bus_flags(uint16_t flags) {
+   GPtrArray * names = g_ptr_array_new();
+
+#define ADD_NAME(_name) \
+   if (_name & flags) g_ptr_array_add(names, #_name)
+
+   ADD_NAME(I2C_BUS_EXISTS             );
+   ADD_NAME(I2C_BUS_ACCESSIBLE         );
+   ADD_NAME(I2C_BUS_ADDR_0X50          );
+   ADD_NAME(I2C_BUS_ADDR_0X37          );
+   ADD_NAME(I2C_BUS_ADDR_0X30          );
+   ADD_NAME(I2C_BUS_EDP                );
+   ADD_NAME(I2C_BUS_LVDS               );
+   ADD_NAME(I2C_BUS_PROBED             );
+   ADD_NAME(I2C_BUS_VALID_NAME_CHECKED );
+   ADD_NAME(I2C_BUS_HAS_VALID_NAME     );
+   ADD_NAME(I2C_BUS_BUSY               );
+   ADD_NAME(I2C_BUS_SYSFS_EDID         );
+
+#undef ADD_NAME
+
+   char * joined =  join_string_g_ptr_array(names, " | ");
+   return joined;
+}
+
+
+#ifdef NOT_WORTH_THE_SPACE
+char * interpret_i2c_bus_flags_t(uint16_t flags) {
+   static GPrivate  buffer_key = G_PRIVATE_INIT(g_free);
+   static GPrivate  buffer_len_key = G_PRIVATE_INIT(g_free);
+
+   char * sflags = interpret_i2c_bus_flags(flags);
+   int required_size = strlen(sflags) + 1;
+   char * buf = get_thread_dynamic_buffer(&buffer_key, &buffer_len_key, required_size);
+   strncpy(buf, sflags, required_size);
+   free(sflags);
+   return buf;
+}
+#endif
+
+
+//
+// Bus open errors
+//
+
+/** Adds a set of bus numbers to the set of bus numbers
+ *  whose open failure has already been reported.
+ *
+ *  @param failures   set of bus numbers
+ */
+void add_open_failures_reported(Bit_Set_256 failures) {
+   g_mutex_lock(&open_failures_mutex);
+   open_failures_reported = bs256_or(open_failures_reported, failures);
+   g_mutex_unlock(&open_failures_mutex);
+}
+
+
+/** Adds a bus number to the set of open failures reported.
+ *
+ *  @param  busno     /dev/i2c-N bus number
+ */
+void include_open_failures_reported(int busno) {
+   g_mutex_lock(&open_failures_mutex);
+   open_failures_reported = bs256_insert(open_failures_reported, busno);
+   g_mutex_unlock(&open_failures_mutex);
+}
+
+
 //
 // Basic I2C bus operations
 //
@@ -109,7 +189,8 @@ int i2c_open_bus(int busno, Byte callopts) {
    int errsv = errno;
 
    if (fd < 0) {
-      f0printf(ferr(), "Open failed for %s: errno=%s\n", filename, linux_errno_desc(errsv));
+      if (!bs256_contains(open_failures_reported, busno))
+         f0printf(ferr(), "Open failed for %s: errno=%s\n", filename, linux_errno_desc(errsv));
       fd = -errsv;
    }
    else {
@@ -152,107 +233,7 @@ Status_Errno i2c_close_bus(int fd, Call_Options callopts) {
       result = -errsv;
    }
    assert(result <= 0);
-   DBGTRC_RETURNING(debug, TRACE_GROUP, result, "fd=%d, filename=%s",fd, filename_for_fd_t(fd));
-   return result;
-}
-
-
-/** Sets I2C slave address to be used on subsequent calls
- *
- * @param  fd        Linux file descriptor for open /dev/i2c-n
- * @param  addr      slave address
- * @param  callopts  call option flags, controlling failure action\n
- *                   if CALLOPT_FORCE set, use IOCTL op I2C_SLAVE_FORCE
- *                   to take control even if address is in use by another driver
- *
- * @retval  0 if success
- * @retval <0 negative Linux errno, if ioctl call fails
- *
- * \remark
- * Errors which are recovered are counted here using COUNT_STATUS_CODE().
- * The final status code is left for the caller to count
- */
-Status_Errno i2c_set_addr(int fd, int addr, Call_Options callopts) {
-   bool debug = false;
-#ifdef FOR_TESTING
-   bool force_i2c_slave_failure = false;
-#endif
-   // callopts |= CALLOPT_ERR_MSG;    // temporary
-   DBGTRC_STARTING(debug, TRACE_GROUP,
-                 "fd=%d, addr=0x%02x, filename=%s, i2c_force_slave_addr_flag=%s, callopts=%s",
-                 fd, addr,
-                 filename_for_fd_t(fd),
-                 sbool(i2c_force_slave_addr_flag),
-                 interpret_call_options_t(callopts) );
-   // FAILSIM;
-
-   Status_Errno result = 0;
-   int rc = 0;
-   int errsv = 0;
-   uint16_t op = (callopts & CALLOPT_FORCE_SLAVE_ADDR) ? I2C_SLAVE_FORCE : I2C_SLAVE;
-
-retry:
-   errno = 0;
-   RECORD_IO_EVENT( IE_OTHER, ( rc = ioctl(fd, op, addr) ) );
-#ifdef FOR_TESTING
-   if (force_i2c_slave_failure) {
-      if (op == I2C_SLAVE) {
-         DBGMSG("Forcing pseudo failure");
-         rc = -1;
-         errno=EBUSY;
-      }
-   }
-#endif
-   errsv = errno;
-
-   if (rc < 0) {
-      if (errsv == EBUSY) {
-         DBGTRC_NOPREFIX(debug, TRACE_GROUP, "ioctl(%s, I2C_SLAVE, 0x%02x) returned EBUSY",
-                   filename_for_fd_t(fd), addr);
-
-         if (op == I2C_SLAVE &&
-               i2c_force_slave_addr_flag )  // global setting
-             // future?: (i2c_force_slave_addr_flag || (callopts & CALLOPT_FORCE_SLAVE_ADDR)) )
-         {
-            DBGTRC_NOPREFIX(debug, TRACE_GROUP,
-                   "Retrying using IOCTL op I2C_SLAVE_FORCE for %s, slave address 0x%02x",
-                   filename_for_fd_t(fd), addr );
-            // normally errors counted at higher level, but in this case it would be
-            // lost because of retry
-            COUNT_STATUS_CODE(-errsv);
-            op = I2C_SLAVE_FORCE;
-            // debug = true;   // force final message for clarity
-            goto retry;
-         }
-      }
-      else {
-         REPORT_IOCTL_ERROR( (op == I2C_SLAVE) ? "I2C_SLAVE" : "I2C_SLAVE_FORCE", errsv);
-      }
-
-      result = -errsv;
-   }
-   if (result == -EBUSY) {
-      char msgbuf[60];
-      g_snprintf(msgbuf, 60, "set_addr(%s,%s,0x%02x) failed, error = EBUSY",
-                             filename_for_fd_t(fd),
-                             (op == I2C_SLAVE) ? "I2C_SLAVE" : "I2C_SLAVE_FORCE",
-                             addr);
-      DBGTRC(true, TRACE_GROUP, "%s", msgbuf);
-      syslog(LOG_ERR, "%s", msgbuf);
-
-   }
-   else if (result == 0 && op == I2C_SLAVE_FORCE) {
-      char msgbuf[80];
-      g_snprintf(msgbuf, 80, "set_addr(%s,I2C_SLAVE_FORCE,0x%02x) succeeded on retry after EBUSY error",
-            filename_for_fd_t(fd),
-            addr);
-      DBGTRC(debug || get_output_level() > DDCA_OL_VERBOSE, TRACE_GROUP, "%s", msgbuf);
-      syslog(LOG_INFO, "%s", msgbuf);
-   }
-
-   assert(result <= 0);
-   // if (addr == 0x37)  result = -EBUSY;    // for testing
-   DBGTRC_RETURNING(debug, TRACE_GROUP, result, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, result, "fd=%d, filename=%s",fd, filename_for_fd_t(fd));
    return result;
 }
 
@@ -301,180 +282,10 @@ static bool is_laptop_drm_connector(int busno, char * drm_name_fragment) {
 }
 
 
-#ifdef UNUSED
-/* Checks each address on an I2C bus to see if a device exists.
- * The bus device has already been opened.
- *
- * Arguments:
- *   fd  file descriptor for open bus object
- *
- * Returns:
- *   128 byte array of booleans, byte n is true iff a device is
- *   detected at bus address n
- *
- * This "exploratory" function is not currently used but is
- * retained for diagnostic purposes.
- *
- * TODO: exclude reserved I2C bus addresses from check
- */
-static
-bool * i2c_detect_all_slave_addrs_by_fd(int fd) {
-   bool debug = false;
-   DBGMSF(debug, "Starting. fd=%d", fd);
-   assert (fd >= 0);
-   bool * addrmap = NULL;
-
-   unsigned char byte_to_write = 0x00;
-   int addr;
-   addrmap = calloc(I2C_SLAVE_ADDR_MAX, sizeof(bool));
-   //bool addrmap[128] = {0};
-
-   for (addr = 3; addr < I2C_SLAVE_ADDR_MAX; addr++) {
-      int rc;
-      i2c_set_addr(fd, addr, CALLOPT_ERR_MSG);
-      rc = invoke_i2c_reader(fd, 1, &byte_to_write);
-      if (rc >= 0)
-         addrmap[addr] = true;
-   }
-
-   DBGMSF(debug, "Returning %p", addrmap);
-   return addrmap;
-}
-
-
-/* Examines all possible addresses on an I2C bus.
- *
- * Arguments:
- *    busno    bus number
- *
- * Returns:
- *   128 byte boolean array,
- *   NULL if unable to open I2C bus
- *
- * This "exploratory" function is not currently used but is
- * retained for diagnostic purposes.
- */
-bool * i2c_detect_all_slave_addrs(int busno) {
-   bool debug = false;
-   DBGMSF(debug, "Starting. busno=%d", busno);
-
-   int file = i2c_open_bus(busno, CALLOPT_ERR_MSG);  // return if failure
-   bool * addrmap = NULL;
-
-   if (file >= 0) {
-      addrmap = i2c_detect_all_slave_addrs_by_fd(file);
-      i2c_close_bus(file, busno, CALLOPT_NONE);
-   }
-
-   DBGMSF(debug, "Returning %p", addrmap);
-   return addrmap;
-}
-#endif
-
-
 //
 // I2C Bus Inspection - EDID Retrieval
 //
 
-static Status_Errno_DDC
-i2c_get_edid_bytes_directly(
-      int     fd,
-      Buffer* rawedid,
-      int     edid_read_size,
-      bool    read_bytewise)
-{
-   bool debug = false;
-#ifdef USE_SMBUS
-   read_bytewise = true;   // ** TEMP **
-#endif
-
-   DBGTRC_STARTING(debug, TRACE_GROUP, "Getting EDID. File descriptor = %d, filename=%s, edid_read_size=%d, read_bytewise=%s",
-                 fd, filename_for_fd_t(fd), edid_read_size, sbool(read_bytewise));
-   assert(rawedid && rawedid->buffer_size >= EDID_BUFFER_SIZE);
-
-   bool write_before_read = EDID_Write_Before_Read;
-   // write_before_read = false;
-   DBGTRC_NOPREFIX(debug, TRACE_GROUP, "write_before_read = %s", sbool(write_before_read));
-   int rc = 0;
-   if (write_before_read) {
-      Byte byte_to_write = 0x00;
-      RECORD_IO_EVENTX(
-          fd,
-          IE_WRITE,
-          ( rc = write(fd, &byte_to_write, 1) )
-         );
-      if (rc < 0) {
-         rc = -errno;
-         DBGTRC_NOPREFIX(debug, TRACE_GROUP, "write() failed.  rc = %s", psc_name_code(rc));
-      }
-      else {
-         rc = 0;
-         DBGTRC_NOPREFIX(debug, TRACE_GROUP, "write() succeeded");
-      }
-   }
-
-   if (rc == 0) {
-      if (read_bytewise) {
-         int ndx = 0;
-         for (; ndx < edid_read_size && rc == 0; ndx++) {
-#ifdef USE_SMBUS
-            __s32 smbus_result = 0;
-            RECORD_IO_EVENTX(
-                fd,
-                IE_READ,
-                ( smbus_result = i2c_smbus_read_byte_data(fd, ndx) )
-               );
-            // DBGMSG("smbus_result = 0x%08x, %d", smbus_result, smbus_result);
-            if (smbus_result < 0) {
-               rc = -errno;
-               break;
-            }
-            rawedid->bytes[ndx] = smbus_result;
-#else
-            RECORD_IO_EVENTX(
-                fd,
-                IE_READ,
-                ( rc = read(fd, &rawedid->bytes[ndx], 1) )
-               );
-            if (rc < 0) {
-               rc = -errno;
-               break;
-            }
-            assert(rc == 1);
-            rc = 0;
-#endif
-          }
-          rawedid->len = ndx;
-          DBGMSF(debug, "Final single byte read returned %d, ndx=%d", rc, ndx);
-      }
-      else {
-         RECORD_IO_EVENTX(
-             fd,
-             IE_READ,
-             ( rc = read(fd, rawedid->bytes, edid_read_size) )
-            );
-         if (rc >= 0) {
-            DBGMSF(debug, "read() returned %d", rc);
-            rawedid->len = rc;
-            // assert(rc == 128 || rc == 256);
-            rc = 0;
-         }
-         else {
-            rc = -errno;
-         }
-         DBGMSF(debug, "read() returned %s", psc_desc(rc) );
-      }
-   }
-
-   if ( (debug || IS_TRACING()) && rc == 0) {
-      DBGMSG("Returning buffer:");
-      rpt_hex_dump(rawedid->bytes, rawedid->len, 2);
-   }
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "");
-   return rc;
-}
-
-
 static Status_Errno_DDC
 i2c_get_edid_bytes_using_i2c_layer(
       int     fd,
@@ -483,8 +294,8 @@ i2c_get_edid_bytes_using_i2c_layer(
       bool    read_bytewise)
 {
    bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "Getting EDID. File descriptor=%d, filename=%s, read_bytewise=%s",
-                 fd, filename_for_fd_t(fd), sbool(read_bytewise));
+   DBGTRC_STARTING(debug, TRACE_GROUP, "fd=%d, filename=%s, rawedid=%p, edid_read_size=%d, read_bytewise=%s",
+                 fd, filename_for_fd_t(fd), (void*)rawedid, edid_read_size, sbool(read_bytewise));
    assert(rawedid && rawedid->buffer_size >= EDID_BUFFER_SIZE);
 
    bool write_before_read = EDID_Write_Before_Read;
@@ -516,7 +327,7 @@ i2c_get_edid_bytes_using_i2c_layer(
       DBGMSG("Returning buffer:");
       rpt_hex_dump(rawedid->bytes, rawedid->len, 2);
    }
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
    return rc;
 }
 
@@ -535,52 +346,23 @@ i2c_get_raw_edid_by_fd(int fd, Buffer * rawedid)
    bool debug  = false;
    DBGTRC_STARTING(debug, TRACE_GROUP, "Getting EDID. File descriptor = %d, filename=%s",
                               fd, filename_for_fd_t(fd));
-#ifdef OLD
-   bool conservative = false;
-#endif
-
    assert(rawedid && rawedid->buffer_size >= EDID_BUFFER_SIZE);
    Status_Errno_DDC rc;
    int tryctr = 0;
-
-   rc = i2c_set_addr(fd, 0x50, CALLOPT_ERR_MSG);
-   if (rc < 0) {
-      goto bye;
-   }
-
-#ifdef OLD
-   // need a different call since tuned_sleep_with_tracex() now takes Display_Handle *, not DDCA_IO_Type
-   // 10/23/15, try disabling sleep before write
-   if (conservative) {
-      TUNED_SLEEP_WITH_TRACE(DDCA_IO_I2C, SE_PRE_EDID, "Before write");
-   }
-#endif
-
-
    int max_tries = (EDID_Read_Size == 0) ?  4 : 2;
    DBGTRC_NOPREFIX(debug, TRACE_GROUP, "EDID_Read_Size=%d, max_tries=%d", EDID_Read_Size);
    rc = -1;
-   // DBGMSF(debug, "EDID read performed using %s,read_bytewise=%s",
-   //               (EDID_Read_Uses_I2C_Layer) ? "I2C layer" : "local io", sbool(read_bytewise));
 
    bool read_bytewise = EDID_Read_Bytewise;
    for (tryctr = 0; tryctr < max_tries && rc != 0; tryctr++) {
       int edid_read_size = EDID_Read_Size;
       if (EDID_Read_Size == 0)
          edid_read_size = (tryctr < 2) ? 128 : 256;
-
       DBGTRC_NOPREFIX(debug, TRACE_GROUP,
                     "Trying EDID read. tryctr=%d, max_tries=%d,"
-                    " edid_read_size=%d, read_bytewise=%s, using %s",
-                    tryctr, max_tries, edid_read_size, sbool(read_bytewise),
-                    (EDID_Read_Uses_I2C_Layer) ? "I2C layer" : "local io");
-
-      if (EDID_Read_Uses_I2C_Layer) {
-         rc = i2c_get_edid_bytes_using_i2c_layer(fd, rawedid, edid_read_size, read_bytewise);
-      }
-      else {
-         rc = i2c_get_edid_bytes_directly(fd, rawedid, edid_read_size, read_bytewise);
-      }
+                    " edid_read_size=%d, read_bytewise=%s",
+                    tryctr, max_tries, edid_read_size, sbool(read_bytewise) );
+      rc = i2c_get_edid_bytes_using_i2c_layer(fd, rawedid, edid_read_size, read_bytewise);
       if (rc == -ENXIO || rc == -EOPNOTSUPP || rc == -ETIMEDOUT) {    // removed -EIO 3/4/2021
          // DBGMSG("breaking");
          break;
@@ -588,7 +370,7 @@ i2c_get_raw_edid_by_fd(int fd, Buffer * rawedid)
       assert(rc <= 0);
       if (rc == 0) {
          // rawedid->len = 128;
-         if (debug || IS_TRACING_GROUP(DDCA_TRC_NONE) ) {    // only show if explicitly tracing this function
+         if (IS_DBGTRC(debug, DDCA_TRC_NONE) ) {  // only show if explicitly tracing this function
             DBGMSG("get bytes returned:");
             dbgrpt_buffer(rawedid, 1);
             DBGMSG("edid checksum = %d", edid_checksum(rawedid->bytes) );
@@ -596,29 +378,31 @@ i2c_get_raw_edid_by_fd(int fd, Buffer * rawedid)
          if (!is_valid_raw_edid(rawedid->bytes, rawedid->len)) {
             DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Invalid EDID");
             rc = DDCRC_INVALID_EDID;
-         }
-         if (rc == DDCRC_INVALID_EDID) {
             if (is_valid_raw_cea861_extension_block(rawedid->bytes, rawedid->len)) {
-               DBGTRC_NOPREFIX(debug, TRACE_GROUP, "EDID appears to start with a CEA 861 extension block");
+               DBGTRC_NOPREFIX(debug, TRACE_GROUP,
+                               "EDID appears to start with a CEA 861 extension block");
             }
          }
          if (rawedid->len == 256) {
             if (is_valid_raw_cea861_extension_block(rawedid->bytes+128, rawedid->len-128)) {
-                  DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Second physical EDID block appears to be a CEA 861 extension block");
+               DBGTRC_NOPREFIX(debug, TRACE_GROUP,
+                               "Second physical EDID block appears to be a CEA 861 extension block");
             }
             else if (is_valid_raw_edid(rawedid->bytes+128, rawedid->len-128)) {
-                  DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Second physical EDID block appears to be an initial EDID header block");
+               DBGTRC_NOPREFIX(debug, TRACE_GROUP,
+                               "Second physical EDID block read is actually the initial EDID block");
+               memcpy(rawedid->bytes, rawedid->bytes+128, 128);
+               buffer_set_length(rawedid, 128);
+               rc = 0;
             }
-
          }
       }  // get bytes succeeded
    }
 
-bye:
    if (rc < 0)
       rawedid->len = 0;
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "tries=%d", tryctr);
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "tries=%d", tryctr);
    return rc;
 }
 
@@ -628,7 +412,6 @@ bye:
  * @param fd      file descriptor for open /dev/i2c-n
  * @param edid_ptr_loc where to return pointer to newly allocated #Parsed_Edid,
  *                     or NULL if error
- *
  * @return status code
  */
 Status_Errno_DDC
@@ -641,7 +424,7 @@ i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc)
 
    Status_Errno_DDC rc = i2c_get_raw_edid_by_fd(fd, rawedidbuf);
    if (rc == 0) {
-      edid = create_parsed_edid(rawedidbuf->bytes);
+      edid = create_parsed_edid2(rawedidbuf->bytes, "I2C");
       if (debug) {
          if (edid)
             report_parsed_edid(edid, false /* verbose */, 0);
@@ -656,10 +439,10 @@ i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc)
 
    *edid_ptr_loc = edid;
    if (edid)
-      DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "*edid_ptr_loc = %p -> ...%s",
+      DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "*edid_ptr_loc = %p -> ...%s",
                                  edid, hexstring3_t(edid->bytes+124, 4, "", 1, false));
    else
-      DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "");
+      DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
 
    return rc;
 }
@@ -667,6 +450,7 @@ i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc)
 
 //
 // I2C Bus Inspection - Fill in and report Bus_Info
+//
 
 /** Allocates and initializes a new #I2C_Bus_Info struct
  *
@@ -681,64 +465,32 @@ static I2C_Bus_Info * i2c_new_bus_info(int busno) {
 }
 
 
-static bool
-i2c_detect_x37(int fd, bool* busy_loc) {
+static Status_Errno_DDC
+i2c_detect_x37(int fd) {
    bool debug = false;
-   bool result = false;
-   *busy_loc = false;
+   DBGTRC_STARTING(debug, TRACE_GROUP, "fd=%d - %s", fd, filename_for_fd_t(fd) );
 
    // Quirks
    // - i2c_set_addr() Causes screen corruption on Dell XPS 13, which has a QHD+ eDP screen
    //   avoided by never calling this function for an eDP screen
    // - Dell P2715Q does not respond to single byte read, but does respond to
    //   a write (7/2018), so this function checks both
-   Status_Errno_DDC rc = i2c_set_addr(fd, 0x37, CALLOPT_NONE);
-   if (rc == 0)  {
-      // regard either a successful write() or a read() as indication slave address is valid
-      Byte    writebuf = {0x00};
-      rc = write(fd, &writebuf, 1);
-      DBGTRC_NOPREFIX(debug, TRACE_GROUP,"write() for slave address x37 returned %s", psc_name_code(rc));
-      if (rc == 1)
-         result = true;
-
-      // Per DDC/CI v1.1, section 6.4
-      // The NULL message is used in the following cases:
-      //   To detect that the display is DDC/CI capable (by reading it at 0x6Fh I2c slave address)
-      //   ...
+   Status_Errno_DDC rc = 0;
+   // regard either a successful write() or a read() as indication slave address is valid
+   Byte    writebuf = {0x00};
 
+   rc = i2c_ioctl_writer(fd, 0x37, 1, &writebuf);
+   // rc = 6; // for testing
+   DBGTRC_NOPREFIX(debug, TRACE_GROUP,
+                   "i2c_ioctl_writer() for slave address x37 returned %s", psc_name_code(rc));
+   if (rc != 0) {
       Byte    readbuf[4];  //  4 byte buffer
-      rc = read(fd, readbuf, 4);
-      DBGTRC_NOPREFIX(debug, TRACE_GROUP,"read() for slave address x37 returned %s", psc_name_code(rc));
-      // test doesn't work, buffer contains random bytes (but same random bytes for every
-      // display in a single call to i2cdetect_x37
-      // Byte ddc_null_msg[4] = {0x6f, 0x6e, 0x80, 0xbe};
-      // if (rc == 4) {
-      //    DBGMSG("read x37 returned: 0x%08x", readbuf);
-      //    result = (memcmp( readbuf, ddc_null_msg, 4) == 0);
-      // }
-      if (rc >= 0)
-         result = true;
+      rc = i2c_ioctl_reader(fd, 0x37, false, 4, readbuf);
+      DBGTRC_NOPREFIX(debug, TRACE_GROUP,
+                      "i2c_ioctl_reader() for slave address x37 returned %s", psc_name_code(rc));
    }
-   else if (rc == -EBUSY)
-      *busy_loc = true;
-
-   DBGMSF(debug, "Returning %s, *busy_loc=%s", SBOOL(result), SBOOL(*busy_loc));
-   return result;
-}
-
-
-// Factored out of i2c_check_bus().  Not needed, since i2c_check_bus() is called
-// only when the bus name is valid
-void i2c_bus_check_valid_name(I2C_Bus_Info * bus_info) {
-  assert(bus_info && ( memcmp(bus_info->marker, I2C_BUS_INFO_MARKER, 4) == 0) );
-
-  if ( !(bus_info->flags & I2C_BUS_VALID_NAME_CHECKED) ) {
-      bus_info->flags |= I2C_BUS_VALID_NAME_CHECKED;
-      if ( !sysfs_is_ignorable_i2c_device(bus_info->busno) )
-         bus_info->flags |= I2C_BUS_HAS_VALID_NAME;
-   }
-
-   bus_info->flags |= I2C_BUS_HAS_VALID_NAME;
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc,"");
+   return rc;
 }
 
 
@@ -764,6 +516,7 @@ void i2c_check_bus(I2C_Bus_Info * bus_info) {
    if (!(bus_info->flags & I2C_BUS_PROBED)) {
       DBGMSF(debug, "Probing");
       bus_info->flags |= I2C_BUS_PROBED;
+      bus_info->driver = get_driver_for_busno(bus_info->busno);
       int fd = i2c_open_bus(bus_info->busno, CALLOPT_ERR_MSG);
       if (fd >= 0) {
           DBGMSF(debug, "Opened bus /dev/i2c-%d", bus_info->busno);
@@ -784,19 +537,29 @@ void i2c_check_bus(I2C_Bus_Info * bus_info) {
                 bus_info->flags |= I2C_BUS_LVDS;
              }
              else {
-                bool ebusy = false;
-                if ( i2c_detect_x37(fd, &ebusy) )
+                int rc = i2c_detect_x37(fd);
+                if (rc == 0)
                    bus_info->flags |= I2C_BUS_ADDR_0X37;
-                else if (ebusy)
+                else if (rc == -EBUSY)
                    bus_info->flags |= I2C_BUS_BUSY;
              }
           }
+          else if (ddcrc == -EBUSY)
+             bus_info->flags |= I2C_BUS_BUSY;
           i2c_close_bus(fd, CALLOPT_ERR_MSG);
       }
+      else {
+         bus_info->open_errno = -errno;
+      }
    }   // probing complete
 
-   DBGTRC_DONE(debug, TRACE_GROUP, "flags=0x%04x, bus info:", bus_info->flags );
+   // DBGTRC_DONE(debug, TRACE_GROUP, "flags=0x%04x, bus info:", bus_info->flags );
    if (debug || IS_TRACING() ) {
+      char * sflags = interpret_i2c_bus_flags(bus_info->flags);
+      DBGTRC_DONE(true, TRACE_GROUP, "flags = 0x%04x = %s", bus_info->flags, sflags);
+      // DBGTRC_NOPREFIX(true, TRACE_GROUP, "flags = %s", interpret_i2c_bus_flags_t(bus_info->flags));
+      free(sflags);
+      DBGTRC_NOPREFIX(true, TRACE_GROUP, "bus_info:");
       i2c_dbgrpt_bus_info(bus_info, 2);
    }
 }
@@ -810,6 +573,8 @@ void i2c_free_bus_info(I2C_Bus_Info * bus_info) {
          assert( memcmp(bus_info->marker, I2C_BUS_INFO_MARKER, 4) == 0);
          if (bus_info->edid)
             free_parsed_edid(bus_info->edid);
+         if (bus_info->driver)
+            free(bus_info->driver);
          bus_info->marker[3] = 'x';
          free(bus_info);
       }
@@ -817,7 +582,7 @@ void i2c_free_bus_info(I2C_Bus_Info * bus_info) {
 }
 
 // satisfies GDestroyNotify()
-void i2c_free_bus_info_gdestroy(gpointer data) {
+void i2c_gdestroy_bus_info(gpointer data) {
    i2c_free_bus_info((I2C_Bus_Info*) data);
 }
 
@@ -828,15 +593,13 @@ void i2c_free_bus_info_gdestroy(gpointer data) {
 
 /** Reports on a single I2C bus.
  *
- * \param   bus_info    pointer to Bus_Info structure describing bus
- * \param   depth       logical indentation depth
+ *  \param   bus_info    pointer to Bus_Info structure describing bus
+ *  \param   depth       logical indentation depth
  *
- * \remark
- * The format of the output as well as its extent is controlled by get_output_level(). - no longer!
+ *  \remark
+ *  Although this is a debug type report, it is called by used (indirectly) by the
+ *  ENVIRONMENT command.
  */
-// used by dbgreport_display_ref() in ddc_displays.c, always OL_VERBOSE
-// used by debug code within this file
-// used by i2c_report_buses() in this file, which is called by query_i2c_buses() in query_sysenv.c, always OL_VERBOSE
 void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth) {
    bool debug = false;
    DBGMSF(debug, "bus_info=%p", bus_info);
@@ -845,6 +608,7 @@ void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth) {
    rpt_vstring(depth, "Bus /dev/i2c-%d found:   %s", bus_info->busno, sbool(bus_info->flags&I2C_BUS_EXISTS));
    rpt_vstring(depth, "Bus /dev/i2c-%d probed:  %s", bus_info->busno, sbool(bus_info->flags&I2C_BUS_PROBED ));
    if ( bus_info->flags & I2C_BUS_PROBED ) {
+      rpt_vstring(depth, "Driver:                  %s", bus_info->driver);
       rpt_vstring(depth, "Bus accessible:          %s", sbool(bus_info->flags&I2C_BUS_ACCESSIBLE ));
       rpt_vstring(depth, "Bus is eDP:              %s", sbool(bus_info->flags&I2C_BUS_EDP ));
       rpt_vstring(depth, "Bus is LVDS:             %s", sbool(bus_info->flags&I2C_BUS_LVDS));
@@ -856,6 +620,7 @@ void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth) {
       rpt_vstring(depth, "Address 0x37 present:    %s", sbool(bus_info->flags & I2C_BUS_ADDR_0X37));
       rpt_vstring(depth, "Address 0x50 present:    %s", sbool(bus_info->flags & I2C_BUS_ADDR_0X50));
       rpt_vstring(depth, "Device busy:             %s", sbool(bus_info->flags & I2C_BUS_BUSY));
+      rpt_vstring(depth, "errno for open:          %d", bus_info->open_errno);
       // not useful and clutters the output
       // i2c_report_functionality_flags(bus_info->functionality, /* maxline */ 90, depth);
       if ( bus_info->flags & I2C_BUS_ADDR_0X50) {
@@ -867,7 +632,7 @@ void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth) {
 
 #ifndef TARGET_BSD
    I2C_Sys_Info * info = get_i2c_sys_info(bus_info->busno, -1);
-   report_i2c_sys_info(info, depth);
+   dbgrpt_i2c_sys_info(info, depth);
    free_i2c_sys_info(info);
 #endif
 
@@ -889,49 +654,71 @@ void i2c_report_active_display(I2C_Bus_Info * businfo, int depth) {
    bool debug = false;
    DBGMSF(debug, "Starting.  businfo=%p", businfo);
    assert(businfo);
+
+   int d1 = depth+1;
    DDCA_Output_Level output_level = get_output_level();
-   rpt_vstring(depth, "I2C bus:  /dev/"I2C"-%d", businfo->busno);
+   if (output_level >= DDCA_OL_NORMAL)
+      rpt_vstring(depth, "I2C bus:  /dev/"I2C"-%d", businfo->busno);
+   // will work for amdgpu, maybe others
+   Sys_Drm_Connector * drm_connector = find_sys_drm_connector_by_busno(businfo->busno);
+   if (!drm_connector && businfo->edid)
+      drm_connector = find_sys_drm_connector_by_edid(businfo->edid->bytes);
+   int title_width = (output_level >= DDCA_OL_VERBOSE) ? 36 : 25;
+   if (drm_connector && output_level >= DDCA_OL_NORMAL)
+      rpt_vstring((output_level >= DDCA_OL_VERBOSE) ? d1 : depth, "%-*s%s", title_width, "DRM connector:", drm_connector->connector_name);
 
    // 08/2018 Disable.
    // Test for DDC communication is now done more sophisticatedly at the DDC level
    // The simple X37 test can have both false positives (DDC turned off in monitor but
    // X37 responsive), and false negatives (Dell P2715Q)
    // if (output_level >= DDCA_OL_NORMAL)
-   // rpt_vstring(depth, "Supports DDC:        %s", sbool(businfo->flags & I2C_BUS_ADDR_0X37));
+   // rpt_vstring(depth, "Supports DDC:    %s", sbool(businfo->flags & I2C_BUS_ADDR_0X37));
 
    if (output_level >= DDCA_OL_VERBOSE) {
+      rpt_vstring(d1, "Driver:                             %s", (businfo->driver) ? businfo->driver : "Unknown");
 #ifdef DETECT_SLAVE_ADDRS
-      rpt_vstring(depth+1, "I2C address 0x30 (EDID block#)  present: %-5s", srepr(businfo->flags & I2C_BUS_ADDR_0X30));
-      rpt_vstring(depth+1, "I2C address 0x37 (DDC)          present: %-5s", srepr(businfo->flags & I2C_BUS_ADDR_0X37));
+      rpt_vstring(d1, "I2C address 0x30 (EDID block#)  present: %-5s", srepr(businfo->flags & I2C_BUS_ADDR_0X30));
+      rpt_vstring(d1, "I2C address 0x37 (DDC)          present: %-5s", srepr(businfo->flags & I2C_BUS_ADDR_0X37));
 #endif
-      rpt_vstring(depth+1, "I2C address 0x50 (EDID) responsive: %-5s", sbool(businfo->flags & I2C_BUS_ADDR_0X50));
-      rpt_vstring(depth+1, "Is eDP device:                      %-5s", sbool(businfo->flags & I2C_BUS_EDP));
-      rpt_vstring(depth+1, "Is LVDS device:                     %-5s", sbool(businfo->flags & I2C_BUS_LVDS));
+      rpt_vstring(d1, "I2C address 0x50 (EDID) responsive: %-5s", sbool(businfo->flags & I2C_BUS_ADDR_0X50));
+      rpt_vstring(d1, "Is eDP device:                      %-5s", sbool(businfo->flags & I2C_BUS_EDP));
+      rpt_vstring(d1, "Is LVDS device:                     %-5s", sbool(businfo->flags & I2C_BUS_LVDS));
 
       // if ( !(businfo->flags & (I2C_BUS_EDP|I2C_BUS_LVDS)) )
-      // rpt_vstring(depth+1, "I2C address 0x37 (DDC) responsive:  %-5s", sbool(businfo->flags & I2C_BUS_ADDR_0X37));
+      // rpt_vstring(d1, "I2C address 0x37 (DDC) responsive:  %-5s", sbool(businfo->flags & I2C_BUS_ADDR_0X37));
 
       char fn[PATH_MAX];     // yes, PATH_MAX is dangerous, but not as used here
       sprintf(fn, "/sys/bus/i2c/devices/i2c-%d/name", businfo->busno);
       char * sysattr_name = file_get_first_line(fn, /* verbose*/ false);
-      rpt_vstring(depth+1, "%s:   %s", fn, sysattr_name);
+      rpt_vstring(d1, "%-*s%s", title_width, fn, sysattr_name);
       free(sysattr_name);
+      sprintf(fn, "/sys/bus/i2c/devices/i2c-%d", businfo->busno);
+      char * path = NULL;
+      GET_ATTR_REALPATH(&path, fn);
+      rpt_vstring(d1, "PCI device path:                    %s", path);
+      free(path);
 
-#ifndef TARGET_BSD
+#ifdef REDUNDANT
+#ifndef TARGET_BSD2
       if (output_level >= DDCA_OL_VV) {
          I2C_Sys_Info * info = get_i2c_sys_info(businfo->busno, -1);
-         report_i2c_sys_info(info, depth);
+         dbgrpt_i2c_sys_info(info, depth);
          free_i2c_sys_info(info);
       }
+#endif
 #endif
    }
 
    if (businfo->edid) {
-      if (output_level == DDCA_OL_TERSE)
-         rpt_vstring(depth, "Monitor:             %s:%s:%s",
+      if (output_level == DDCA_OL_TERSE) {
+         rpt_vstring(depth, "I2C bus:          /dev/"I2C"-%d", businfo->busno);
+         if (drm_connector)
+            rpt_vstring(depth, "DRM connector:    %s", drm_connector->connector_name);
+         rpt_vstring(depth, "Monitor:          %s:%s:%s",
                             businfo->edid->mfg_id,
                             businfo->edid->model_name,
                             businfo->edid->serial_ascii);
+      }
       else
          report_parsed_edid_base(businfo->edid,
                            (output_level >= DDCA_OL_VERBOSE), // was DDCA_OL_VV
@@ -1019,6 +806,12 @@ Byte_Value_Array get_i2c_devices_by_existence_test() {
 int i2c_detect_buses() {
    bool debug = false;
    DBGTRC_STARTING(debug, DDCA_TRC_I2C, "i2c_buses = %p", i2c_buses);
+
+   // rpt_label(0, "*** Temporary code to exercise get_all_i2c_infos() ***");
+   // GPtrArray * i2c_infos = get_all_i2c_info(true, -1);
+   // dbgrpt_all_sysfs_i2c_info(i2c_infos, 2);
+
+
    if (!i2c_buses) {
       // only returns buses with valid name (arg=false)
 #ifdef ENABLE_UDEV
@@ -1027,7 +820,7 @@ int i2c_detect_buses() {
       Byte_Value_Array i2c_bus_bva = get_i2c_devices_by_existence_test();
 #endif
       i2c_buses = g_ptr_array_sized_new(bva_length(i2c_bus_bva));
-      g_ptr_array_set_free_func(i2c_buses, i2c_free_bus_info_gdestroy);
+      g_ptr_array_set_free_func(i2c_buses, i2c_gdestroy_bus_info);
       for (int ndx = 0; ndx < bva_length(i2c_bus_bva); ndx++) {
          int busno = bva_get(i2c_bus_bva, ndx);
          DBGMSF(debug, "Checking busno = %d", busno);
@@ -1036,6 +829,31 @@ int i2c_detect_buses() {
          i2c_check_bus(businfo);
          if (debug || IS_TRACING() )
             i2c_dbgrpt_bus_info(businfo, 0);
+         if (businfo->flags & I2C_BUS_BUSY) {
+            DBGMSF(debug, "Getting EDID from sysfs");
+            Sys_Drm_Connector * connector_rec = find_sys_drm_connector_by_busno(busno);
+            if (connector_rec && connector_rec->edid_bytes) {
+               businfo->edid = create_parsed_edid2(connector_rec->edid_bytes, "SYSFS");
+               if (debug) {
+                  if (businfo->edid)
+                     report_parsed_edid(businfo->edid, false /* verbose */, 0);
+                  else
+                     DBGMSG("create_parsed_edid() returned NULL");
+               }
+               if (businfo->edid) {
+                  businfo->flags |= I2C_BUS_ADDR_0X50;  // ???
+                  businfo->flags |= I2C_BUS_SYSFS_EDID;
+                  memcpy(businfo->edid->edid_source, "SYSFS", 6);
+               }
+            }
+
+            if (debug) {
+               GPtrArray * conflicts = collect_conflicting_drivers(busno, -1);
+               // report_conflicting_drivers(conflicts);
+               DBGMSG("Conflicting drivers: %s", conflicting_driver_names_string_t(conflicts));
+               free_conflicting_drivers(conflicts);
+            }
+         }
          DBGMSF(debug, "Valid bus: /dev/"I2C"-%d", busno);
          g_ptr_array_add(i2c_buses, businfo);
       }
@@ -1091,31 +909,20 @@ I2C_Bus_Info * i2c_detect_single_bus(int busno) {
  *          NULL if invalid index
  */
 I2C_Bus_Info * i2c_get_bus_info_by_index(uint busndx) {
-   // assert(busndx >= 0);
    assert(i2c_buses);
+   assert(busndx < i2c_buses->len);
 
    bool debug = false;
    DBGMSF(debug, "Starting.  busndx=%d", busndx );
-
-   I2C_Bus_Info * bus_info = NULL;
-#ifndef NDEBUG
-   int busct = i2c_buses->len;
-   assert(busndx < busct);
-#endif
-   bus_info = g_ptr_array_index(i2c_buses, busndx);
+   I2C_Bus_Info * bus_info = g_ptr_array_index(i2c_buses, busndx);
    // report_businfo(busInfo);
    if (debug) {
-      DBGMSG("flags=0x%04x", bus_info->flags);
-      DBGMSG("flags & I2C_BUS_PROBED = 0x%02x", (bus_info->flags & I2C_BUS_PROBED) );
+      char * s = interpret_i2c_bus_flags(bus_info->flags);
+      DBGMSG("busno=%d, flags = 0x%04x = %s", bus_info->busno, bus_info->flags, s);
+      free(s);
    }
    assert( bus_info->flags & I2C_BUS_PROBED );
-#ifdef OLD
-   if (!(bus_info->flags & I2C_BUS_PROBED)) {
-      // DBGMSG("Calling check_i2c_bus()");
-      i2c_check_bus(bus_info);
-   }
-#endif
-   DBGMSF(debug, "busndx=%d, returning %p", busndx, bus_info );
+   DBGMSF(debug, "busndx=%d, busno=%d, returning %p", busndx, bus_info->busno, bus_info );
    return bus_info;
 }
 
@@ -1218,9 +1025,9 @@ bool i2c_is_valid_bus(int busno, Call_Options callopts) {
  * @remark
  * Used by query-sysenv.c, always OL_VERBOSE
  */
-int i2c_report_buses(bool report_all, int depth) {
+int i2c_dbgrpt_buses(bool report_all, int depth) {
    bool debug = false;
-   DBGTRC_STARTING(debug, TRACE_GROUP, "report_all=%s\n", sbool(report_all));
+   DBGTRC_STARTING(debug, TRACE_GROUP, "report_all=%s", sbool(report_all));
 
    assert(i2c_buses);
    int busct = i2c_buses->len;
@@ -1243,28 +1050,19 @@ int i2c_report_buses(bool report_all, int depth) {
    if (reported_ct == 0)
       rpt_vstring(depth, "   No buses\n");
 
-   DBGTRC_DONE(debug, TRACE_GROUP, "Returning %d\n", reported_ct);
+   DBGTRC_DONE(debug, TRACE_GROUP, "Returning %d", reported_ct);
    return reported_ct;
 }
 
 
-#ifdef UNUSED
-bool is_probably_laptop_display(I2C_Bus_Info * businfo) {
-   assert(businfo);
-   bool result = (businfo->flags & I2C_BUS_EDP) || is_embedded_parsed_edid(businfo->edid);
-   return result;
-}
-#endif
-
-
 static void init_i2c_bus_core_func_name_table() {
    RTTI_ADD_FUNC(i2c_open_bus);
-   RTTI_ADD_FUNC(i2c_set_addr);
    RTTI_ADD_FUNC(i2c_close_bus);
    RTTI_ADD_FUNC(i2c_get_edid_bytes_using_i2c_layer);
-   RTTI_ADD_FUNC(i2c_get_edid_bytes_directly);
    RTTI_ADD_FUNC(i2c_detect_buses);
    RTTI_ADD_FUNC(i2c_detect_single_bus);
+   RTTI_ADD_FUNC(i2c_check_bus);
+   RTTI_ADD_FUNC(i2c_detect_x37);
    RTTI_ADD_FUNC(i2c_get_raw_edid_by_fd);
    RTTI_ADD_FUNC(i2c_get_parsed_edid_by_fd);
 }
@@ -1273,5 +1071,6 @@ static void init_i2c_bus_core_func_name_table() {
 void init_i2c_bus_core() {
    init_i2c_bus_core_func_name_table();
    init_i2c_execute_func_name_table();
+   open_failures_reported = EMPTY_BIT_SET_256;
 }
 
