@@ -24,6 +24,10 @@
 #include "base/status_code_mgt.h"
 
 
+extern bool EDID_Read_Bytewise;
+extern bool EDID_Write_Before_Read;
+extern int  EDID_Read_Size;
+
 /** \def I2C_BUS_MAX maximum number of i2c buses this code supports */
 #define I2C_BUS_MAX 32
 
@@ -33,16 +37,11 @@
 // shared with i2c_bus_selector.c
 extern GPtrArray * i2c_buses;
 
-// Controls whether function #i2c_set_addr() retries from EBUSY error by
-// changing ioctl op I2C_SLAVE to op I2C_SLAVE_FORCE.
-extern bool i2c_force_slave_addr_flag;
-
 extern bool i2c_force_bus;
 
 // Basic I2C bus operations
 int           i2c_open_bus(int busno, Call_Options callopts);
 Status_Errno  i2c_close_bus(int fd, Call_Options callopts);
-Status_Errno  i2c_set_addr(int fd, int addr, Call_Options callopts);
 
 // EDID inspection
 Status_Errno_DDC i2c_get_raw_edid_by_fd(int fd, Buffer * rawedid);
@@ -50,6 +49,7 @@ Status_Errno_DDC i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc);
 
 // Retrieve and inspect bus information
 
+// Keep interpret_i2c_bus_flags() in sync with these definitions
 #define I2C_BUS_EXISTS               0x80
 #define I2C_BUS_ACCESSIBLE           0x40
 #define I2C_BUS_ADDR_0X50            0x20      ///< detected I2C bus address 0x50
@@ -61,6 +61,7 @@ Status_Errno_DDC i2c_get_parsed_edid_by_fd(int fd, Parsed_Edid ** edid_ptr_loc);
 #define I2C_BUS_VALID_NAME_CHECKED 0x0800
 #define I2C_BUS_HAS_VALID_NAME     0x0400
 #define I2C_BUS_BUSY               0x0200      ///< for possible future use
+#define I2C_BUS_SYSFS_EDID         0x0100
 
 #define I2C_BUS_INFO_MARKER "BINF"
 /** Information about one I2C bus */
@@ -71,6 +72,8 @@ struct {
    unsigned long    functionality;      ///< i2c bus functionality flags
    Parsed_Edid *    edid;               ///< parsed EDID, if slave address x50 active
    uint16_t         flags;              ///< I2C_BUS_* flags
+   char *           driver;             ///< driver name
+   int              open_errno;         ///< errno if open fails (!I2C_BUS_ACCESSIBLE)
 } I2C_Bus_Info;
 
 void i2c_dbgrpt_bus_info(I2C_Bus_Info * bus_info, int depth);
@@ -80,6 +83,8 @@ void i2c_report_active_display(I2C_Bus_Info * businfo, int depth);
 bool i2c_device_exists(int busno);
 int  i2c_device_count();           // simple /dev/i2c-n count, no side effects
 Byte_Value_Array get_i2c_devices_by_existence_test();
+void add_open_failures_reported(Bit_Set_256 failures);
+void include_open_failures_reported(int busno);
 
 // Bus inventory - detect and probe buses
 int i2c_detect_buses();            // creates internal array of Bus_Info for I2C buses
@@ -93,7 +98,7 @@ I2C_Bus_Info * i2c_find_bus_info_by_busno(int busno);
 
 
 // Reports all detected i2c buses:
-int  i2c_report_buses(bool report_all, int depth);
+int  i2c_dbgrpt_buses(bool report_all, int depth);
 
 void init_i2c_bus_core();
 
