@@ -3,7 +3,7 @@
  *  Low level functions for writing to and reading from the I2C bus,
  *  using various mechanisms.
  */
-// Copyright (C) 2014-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef I2C_EXECUTE_H_
@@ -12,9 +12,6 @@
 #include "util/coredefs.h"
 #include "base/status_code_mgt.h"
 
-void set_i2c_fileio_use_timeout(bool yesno);
-bool get_i2c_fileio_use_timeout();
-
 /** Function template for I2C write function */
 typedef Status_Errno_DDC (*I2C_Writer)(
       int    fd,
@@ -30,19 +27,6 @@ typedef Status_Errno_DDC (*I2C_Reader)(
       int    bytect,
       Byte * readbuf);
 
-Status_Errno_DDC i2c_fileio_writer(
-      int    fd,
-      Byte   slave_address,
-      int    bytect,
-      Byte * pbytes);
-
-Status_Errno_DDC i2c_fileio_reader (
-      int    fd,
-      Byte   slave_address,
-      bool   read_bytewise,
-      int    bytect,
-      Byte * readbuf);
-
 Status_Errno_DDC i2c_ioctl_writer(
       int    fd,
       Byte   slave_address,
