@@ -1,8 +1,11 @@
 /** \file i2c_strategy_dispatcher.c
  *
  *  Allows for alternative mechanisms to read and write to the IC2 bus.
+ *
+ *  This is vestigial code that was used to to select alternative functions
+ *  for I2C IO.
  */
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 /** \cond */
@@ -16,31 +19,23 @@
 #include "base/core.h"
 #include "base/parms.h"
 #include "base/status_code_mgt.h"
-#include "base/last_io_event.h"
 
 #include "i2c_strategy_dispatcher.h"
 
-// I2C_IO_Strategy_Id Default_I2c_Strategy = DEFAULT_I2C_IO_STRATEGY;
-bool EDID_Read_Uses_I2C_Layer        = DEFAULT_EDID_READ_USES_I2C_LAYER;
-bool EDID_Write_Before_Read          = DEFAULT_EDID_WRITE_BEFORE_READ;
-bool I2C_Read_Bytewise               = DEFAULT_I2C_READ_BYTEWISE;
-bool EDID_Read_Bytewise              = DEFAULT_EDID_READ_BYTEWISE;
-int  EDID_Read_Size                  = DEFAULT_EDID_READ_SIZE;
-
+char * i2c_io_strategy_name(I2C_IO_Strategy_Id id) {
+   char * result = NULL;
+   switch(id) {
+   case I2C_IO_STRATEGY_IOCTL:
+      result = "I2C_IO_STRATEGY_IOCTL";
+      break;
+   }
+   return result;
+}
 
 
 // Trace class for this file
 static DDCA_Trace_Group TRACE_GROUP = DDCA_TRC_I2C;
 
-
-I2C_IO_Strategy  i2c_file_io_strategy = {
-      I2C_IO_STRATEGY_FILEIO,
-      i2c_fileio_writer,
-      i2c_fileio_reader,
-      "fileio_writer",
-      "fileio_reader"
-};
-
 I2C_IO_Strategy i2c_ioctl_io_strategy = {
       I2C_IO_STRATEGY_IOCTL,
       i2c_ioctl_writer,
@@ -49,8 +44,8 @@ I2C_IO_Strategy i2c_ioctl_io_strategy = {
       "ioctl_reader"
 };
 
+static I2C_IO_Strategy * i2c_io_strategy = &i2c_ioctl_io_strategy;
 
-static I2C_IO_Strategy * i2c_io_strategy = &i2c_file_io_strategy;  // current strategy
 
 /** Sets an alternative I2C IO strategy.
  *
@@ -61,9 +56,7 @@ I2C_IO_Strategy_Id
 i2c_set_io_strategy(I2C_IO_Strategy_Id strategy_id) {
    I2C_IO_Strategy_Id old = i2c_io_strategy->strategy_id;
    switch (strategy_id) {
-   case (I2C_IO_STRATEGY_FILEIO):
-         i2c_io_strategy = &i2c_file_io_strategy;
-         break;
+
    case (I2C_IO_STRATEGY_IOCTL):
          i2c_io_strategy= &i2c_ioctl_io_strategy;
          break;
@@ -72,6 +65,12 @@ i2c_set_io_strategy(I2C_IO_Strategy_Id strategy_id) {
 }
 
 
+I2C_IO_Strategy_Id
+i2c_get_io_strategy() {
+   return i2c_io_strategy->strategy_id;
+}
+
+
 /** Writes to the I2C bus, using the function specified in the
  * currently active strategy.
  *
@@ -98,14 +97,10 @@ Status_Errno_DDC invoke_i2c_writer(
                  hexstring_t(bytes_to_write, bytect));
 
    Status_Errno_DDC rc;
-   RECORD_IO_EVENT(
-      IE_WRITE,
-      ( rc = i2c_io_strategy->i2c_writer(fd, slave_address, bytect, bytes_to_write ) )
-     );
+   rc = i2c_io_strategy->i2c_writer(fd, slave_address, bytect, bytes_to_write );
    assert (rc <= 0);
-   RECORD_IO_FINISH_NOW(fd, IE_WRITE);
 
-   DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "");
+   DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
    return rc;
 }
 
@@ -138,42 +133,13 @@ Status_Errno_DDC invoke_i2c_reader(
                    readbuf);
 
      Status_Errno_DDC rc;
-     // RECORD_IO_EVENTX(
-     //    fd,
-     //    IE_READ,
-     //    ( rc = i2c_io_strategy->i2c_reader(fd, bytect, readbuf) )
-     //   );
      rc = i2c_io_strategy->i2c_reader(fd, slave_address, read_bytewise, bytect, readbuf);
      assert (rc <= 0);
 
      if (rc == 0) {
         DBGTRC_NOPREFIX(debug, TRACE_GROUP, "Bytes read: %s", hexstring_t(readbuf, bytect) );
      }
-     DBGTRC_RETURNING(debug, TRACE_GROUP, rc, "");
+     DBGTRC_RET_DDCRC(debug, TRACE_GROUP, rc, "");
      return rc;
 }
 
-
-#ifdef TEST_THAT_DIDNT_WORK
-// fails
-Status_Errno_DDC invoke_single_byte_i2c_reader(
-      int        fd,
-      Byte       slave_address,
-      int        bytect,
-      Byte *     readbuf)
-{
-   bool debug = false;
-   DBGMSF(debug, "bytect=%d", bytect);
-   Status_Errno_DDC psc = 0;
-   int ndx = 0;
-   for (;ndx < bytect; ndx++) {
-      psc = invoke_i2c_reader(fd, slave_address, 1, readbuf+ndx);
-      if (psc != 0)
-         break;
-      // call_tuned_sleep_i2c(SE_POST_READ);
-   }
-   DBGMSF(debug, "Returning psc=%s", psc_desc(psc));
-   return psc;
-}
-#endif
-
