@@ -1,8 +1,9 @@
 /** \file i2c_strategy_dispatcher.h
  *
- *  Allows for alternative mechanisms to read and write to the IC2 bus.
+ *  Vestigial code for testing alternative mechanisms to read from and write to
+ *  the IC2 bus.
  */
-// Copyright (C) 2014-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef I2C_STRATEGY_DISPATCHER_H_
@@ -15,12 +16,13 @@
 
 #include "i2c_execute.h"
 
-/** I2C IO strategy ids */
+/** I2C IO strategy ids  - currently only 1 option*/
 typedef enum {
-   I2C_IO_STRATEGY_FILEIO,    ///< use file write() and read()
    I2C_IO_STRATEGY_IOCTL}     ///< use ioctl(I2C_RDWR)
 I2C_IO_Strategy_Id;
 
+char * i2c_io_strategy_name(I2C_IO_Strategy_Id id);
+
 /** Describes one I2C IO strategy */
 typedef struct {
    I2C_IO_Strategy_Id strategy_id;       ///< id of strategy
@@ -30,17 +32,8 @@ typedef struct {
    char *             i2c_reader_name;   ///< read function name
 } I2C_IO_Strategy;
 
-I2C_IO_Strategy_Id
-i2c_set_io_strategy(I2C_IO_Strategy_Id strategy_id);
-
-// quick and dirty for use in testing framework
-// extern I2C_IO_Strategy Default_I2c_Strategy;
-extern bool I2C_Read_Bytewise;
-extern bool EDID_Read_Uses_I2C_Layer;
-extern bool EDID_Read_Bytewise;
-extern bool EDID_Write_Before_Read;
-extern int  EDID_Read_Size;
-
+I2C_IO_Strategy_Id i2c_set_io_strategy(I2C_IO_Strategy_Id strategy_id);
+I2C_IO_Strategy_Id i2c_get_io_strategy();
 
 Status_Errno_DDC
 invoke_i2c_writer(
@@ -57,13 +50,4 @@ invoke_i2c_reader(
        int        bytect,
        Byte *     readbuf);
 
-#ifdef TEST_THAT_DIDNT_WORK
-Status_Errno_DDC
-invoke_single_byte_i2c_reader(
-       int        fd,
-       Byte       slave_address,
-       int        bytect,
-       Byte *     readbuf);
-#endif
-
 #endif /* I2C_STRATEGY_DISPATCHER_H_ */
