@@ -39,6 +39,8 @@
 
 // #include "i2c/i2c_bus_core.h"   // for testing watch_devices
 
+#include "ddc/ddc_common_init.h"
+#include "ddc/ddc_display_lock.h"
 #include "ddc/ddc_displays.h"
 #include "ddc/ddc_multi_part_io.h"
 #include "ddc/ddc_packet_io.h"
@@ -47,8 +49,6 @@
 #include "ddc/ddc_vcp.h"
 #include "ddc/ddc_watch_displays.h"
 
-#include "ddc/common_init.h"
-
 #include "libmain/api_error_info_internal.h"
 #include "libmain/api_base_internal.h"
 #include "libmain/api_services_internal.h"
@@ -266,6 +266,10 @@ bool library_initialized = false;
 void __attribute__ ((constructor))
 _ddca_init(void) {
    bool debug = false;
+   char * s = getenv("DDCUTIL_DEBUG_LIBINIT");
+   if (s && strlen(s) > 0)
+      debug = true;
+
    if (debug)
       printf("(%s) Starting. library_initialized=%s\n", __func__, sbool(library_initialized));
    if (!library_initialized) {
@@ -356,6 +360,8 @@ _ddca_terminate(void) {
    bool debug = false;
    DBGTRC_STARTING(debug, DDCA_TRC_API, "library_initialized = %s", SBOOL(library_initialized));
    if (library_initialized) {
+      if (debug)
+         dbgrpt_distinct_display_descriptors(2);
       ddc_discard_detected_displays();
       release_base_services();
       ddc_stop_watch_displays();
@@ -680,16 +686,16 @@ void ddca_unlock_sleep_multiplier() {
 #endif
 
 
+// deprecated, now a NOOP
 bool
 ddca_enable_sleep_suppression(bool newval) {
-   bool old = is_sleep_suppression_enabled();
-   enable_sleep_suppression(newval);
-   return old;
+   return false;
 }
 
+// deprecated, now a NOOP
 bool
 ddca_is_sleep_suppression_enabled() {
-   return is_sleep_suppression_enabled();
+   return false;
 }
 
 
@@ -771,19 +777,16 @@ ddca_set_timeout_millis(
 
 bool
 ddca_enable_force_slave_address(bool onoff) {
-   bool old = i2c_force_slave_addr_flag;
-   i2c_force_slave_addr_flag = onoff;
-   return old;
+   return false;
 }
 
 
 bool
 ddca_is_force_slave_address_enabled(void) {
-   return i2c_force_slave_addr_flag;
+   return false;
 }
 
 
-
 //
 // Tracing
 //
