@@ -1,4 +1,4 @@
-/** \file api_displays.c */
+/** @file api_displays.c */
 
 // Copyright (C) 2018-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
@@ -14,6 +14,7 @@
 #include "public/ddcutil_status_codes.h"
 #include "public/ddcutil_c_api.h"
 
+#include "util/linux_util.h"
 #include "util/report_util.h"
 #include "util/string_util.h"
 
@@ -24,6 +25,8 @@
 #include "i2c/i2c_sysfs.h"
 
 #include "ddc/ddc_displays.h"
+#include "ddc/ddc_display_ref_reports.h"
+#include "ddc/ddc_display_selection.h"
 #include "ddc/ddc_packet_io.h"
 #include "ddc/ddc_vcp_version.h"
 
@@ -299,7 +302,7 @@ ddca_free_display_ref(DDCA_Display_Ref ddca_dref) {
          }
       );
    }
-   DBGTRC_RETURNING(debug, DDCA_TRC_API, psc, "");
+   DBGTRC_RET_DDCRC(debug, DDCA_TRC_API, psc, "");
    return psc;
 }
 
@@ -448,8 +451,8 @@ ddca_open_display3(
         *dh_loc = dh;
    }
 
-   DBGTRC_RETURNING(debug, DDCA_TRC_API, rc, "*dh_loc=%p -> %s",
-                                             *dh_loc, dh_repr_t(*dh_loc));
+   DBGTRC_RET_DDCRC(debug, DDCA_TRC_API, rc, "*dh_loc=%p -> %s",
+                                             *dh_loc, dh_repr(*dh_loc));
    TRACED_ASSERT_IFF(rc==0, *dh_loc);
    return rc;
 }
@@ -464,7 +467,6 @@ ddca_open_display2(
    return ddca_open_display3(ddca_dref,
                              (wait) ? DDCA_OPENOPT_WAIT : DDCA_OPENOPT_NONE,
                              dh_loc);
-
 }
 
 
@@ -475,7 +477,7 @@ ddca_close_display(DDCA_Display_Handle ddca_dh) {
    assert(library_initialized);
    DDCA_Status rc = 0;
    Display_Handle * dh = (Display_Handle *) ddca_dh;
-   DBGTRC_STARTING(debug, DDCA_TRC_API, "dh = %s", dh_repr_t(dh));
+   DBGTRC_STARTING(debug, DDCA_TRC_API, "dh = %s", dh_repr(dh));
    if (dh) {
       if (memcmp(dh->marker, DISPLAY_HANDLE_MARKER, 4) != 0 )  {
          rc = DDCRC_ARG;
@@ -555,6 +557,7 @@ ddca_get_mccs_version_with_default(
 }
 
 
+#ifdef MCCS_VERSION_ID
 //
 // DDCA_MCCS_Version_Id functions - Deprecated
 //
@@ -604,6 +607,7 @@ char *
 ddca_mccs_version_id_desc(DDCA_MCCS_Version_Id version_id) {
    return format_vcp_version_id(version_id);
 }
+#endif
 
 
 //
@@ -698,12 +702,19 @@ static void init_display_info(Display_Ref * dref, DDCA_Display_Info * curinfo) {
       vspec = get_vcp_version_by_dref(dref);
    }
    memcpy(curinfo->edid_bytes,    dref->pedid->bytes, 128);
+
+#if __GNUC__ >= 8
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wstringop-truncation"
    STRLCPY(curinfo->mfg_id,     dref->pedid->mfg_id,       EDID_MFG_ID_FIELD_SIZE);
    STRLCPY(curinfo->model_name, dref->pedid->model_name,   EDID_MODEL_NAME_FIELD_SIZE);
    STRLCPY(curinfo->sn,         dref->pedid->serial_ascii, DDCA_EDID_SN_ASCII_FIELD_SIZE);
 #pragma GCC diagnostic pop
+#else
+   STRLCPY(curinfo->mfg_id,     dref->pedid->mfg_id,       EDID_MFG_ID_FIELD_SIZE);
+   STRLCPY(curinfo->model_name, dref->pedid->model_name,   EDID_MODEL_NAME_FIELD_SIZE);
+   STRLCPY(curinfo->sn,         dref->pedid->serial_ascii, DDCA_EDID_SN_ASCII_FIELD_SIZE);
+#endif
    curinfo->product_code  = dref->pedid->product_code;
    curinfo->vcp_version    = vspec;
    curinfo->dref           = dref;
@@ -743,11 +754,35 @@ ddca_get_display_info(
          }
    )
 
-   DBGTRC_RETURNING(debug, DDCA_TRC_API, ddcrc, "");
+   DBGTRC_RET_DDCRC(debug, DDCA_TRC_API, ddcrc, "");
    return ddcrc;
 }
 
 
+void set_ddca_error_detail_from_open_errors() {
+   bool debug = false;
+   GPtrArray * errs = ddc_get_bus_open_errors();
+   if (errs && errs->len > 0) {
+      Error_Info * master_error = errinfo_new2(DDCRC_OTHER, __func__, "Error(s) opening ddc devices");
+      for (int ndx = 0; ndx < errs->len; ndx++) {
+         Bus_Open_Error * cur = g_ptr_array_index(errs, ndx);
+         Error_Info * errinfo = NULL;
+         if (cur->io_mode == DDCA_IO_I2C)
+            errinfo = errinfo_new2(cur->error, __func__, "Error %s opening /dev/i2c-%d",
+                                             psc_desc(cur->error), cur->devno);
+         else
+            errinfo = errinfo_new2(cur->error, __func__, "Error %s opening /dev/usb/hiddev%d",
+                                             psc_desc(cur->error), cur->devno);
+         errinfo_add_cause(master_error, errinfo);
+      }
+      DDCA_Error_Detail * public_error_detail = error_info_to_ddca_detail(master_error);
+      errinfo_free_with_report(master_error, debug, __func__);
+      save_thread_error_detail(public_error_detail);
+   }
+}
+
+
+
 DDCA_Status
 ddca_get_display_refs(
       bool                include_invalid_displays,
@@ -773,7 +808,7 @@ ddca_get_display_refs(
    g_ptr_array_free(filtered_displays, true);
 
    int dref_ct = 0;
-   if (debug || IS_TRACING_GROUP( DDCA_TRC_API|DDCA_TRC_DDC )) {
+   if (IS_DBGTRC(debug, DDCA_TRC_API|DDCA_TRC_DDC )) {
       DBGMSG("          *drefs_loc=%p");
       DDCA_Display_Ref * cur_ddca_dref = result_list;
       while (*cur_ddca_dref) {
@@ -786,7 +821,10 @@ ddca_get_display_refs(
 
    *drefs_loc = result_list;
    assert(*drefs_loc);
-   DBGTRC_DONE(debug, DDCA_TRC_API, "Returning: 0. Returned list has %d displays", dref_ct);
+
+   set_ddca_error_detail_from_open_errors();
+
+   DBGTRC_RET_DDCRC(debug, DDCA_TRC_API, 0, "Returned list has %d displays", dref_ct);
    return 0;
 }
 
@@ -827,14 +865,15 @@ ddca_get_display_info_list2(
    }
    g_ptr_array_free(filtered_displays, true);
 
-   if (debug || IS_TRACING_GROUP( DDCA_TRC_API|DDCA_TRC_DDC )) {
+   if (IS_DBGTRC(debug, DDCA_TRC_API|DDCA_TRC_DDC )) {
       DBGMSG("Final result list %p", result_list);
       dbgrpt_display_info_list(result_list, 2);
    }
 
+   set_ddca_error_detail_from_open_errors();
    *dlist_loc = result_list;
    assert(*dlist_loc);
-   DBGTRC_RETURNING(debug, DDCA_TRC_API|DDCA_TRC_DDC, 0,
+   DBGTRC_RET_DDCRC(debug, DDCA_TRC_API|DDCA_TRC_DDC, 0,
                            "Returned list has %d displays", result_list->ct);
    return 0;
 }
@@ -915,7 +954,7 @@ ddca_report_display_info(
 
    // binary SN is not part of DDCA_Display_Info
    Parsed_Edid * edid = create_parsed_edid(dinfo->edid_bytes);
-   if (edid) {     // should never fail, but being ultracautios
+   if (edid) {     // should never fail, but being ultra-cautious
       // Binary serial number is typically 0x00000000 or 0x01010101, but occasionally
       // useful for differentiating displays that share a generic ASCII "serial number"
       rpt_vstring(d1,"Binary serial number: %"PRIu32" (0x%08x)", edid->serial_binary, edid->serial_binary);
@@ -941,6 +980,7 @@ ddca_report_display_info(
 
 
    if (dinfo->dispno == DISPNO_BUSY) {
+#ifdef OLD
       rpt_nl();
       char fn[20];
       int busno =  dinfo->path.path.i2c_busno;
@@ -948,6 +988,25 @@ ddca_report_display_info(
       struct stat statrec;
       if (stat(fn, &statrec) == 0 )
          rpt_vstring(d1, "Driver ddcci is hogging I2C slave address x37 (DDC) on /dev/i2c-%d", busno);
+#endif
+      Display_Ref * dref = (Display_Ref *) dinfo->dref;
+      int busno = dref->io_path.path.i2c_busno;
+      GPtrArray * conflicts = collect_conflicting_drivers(busno, -1);
+      if (conflicts && conflicts->len > 0) {
+         rpt_vstring(d1, "I2C bus is busy. Likely conflicting driver(s): %s",
+                         conflicting_driver_names_string_t(conflicts));
+         free_conflicting_drivers(conflicts);
+      }
+      else {
+         struct stat stat_buf;
+         char buf[20];
+         g_snprintf(buf, 20, "/dev/bus/ddcci/%d", busno);
+         // DBGMSG("buf: %s", buf);
+         int rc = stat(buf, &stat_buf);
+         // DBGMSG("stat returned %d", rc);
+         if (rc == 0)
+            rpt_label(d1, "I2C bus is busy. Likely conflict with driver ddcci.");
+      }
       rpt_vstring(d1, "Consider using option --force-slave-address.");
    }
    DBGMSF(debug, "Done.");
