@@ -1,7 +1,7 @@
 /* ddc_vcp_tests.h
  *
  * <copyright>
- * Copyright (C) 2014-2019 Sanford Rockowitz <rockowitz@minsoft.com>
+ * Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -43,7 +43,7 @@
 #include "i2c/i2c_bus_core.h"
 #include "i2c/wrap_i2c-dev.h"
 
-#include "adl/adl_shim.h"
+// #include "adl/adl_shim.h"
 
 #include "ddc/ddc_packet_io.h"
 #include "ddc/ddc_vcp.h"
@@ -56,6 +56,14 @@
 
 // #define TIMEOUT 50000
 
+// replaces i2c_set_addr() in i2c_bus_core.c, i2c_set_addr() no longer exists
+int local_set_addr(int fd, int addr) {
+      int rc = ioctl(fd, I2C_SLAVE, addr);
+      if (rc < 0)
+         rc = -errno;
+      return rc;
+}
+
 
 
 char * hexstring0(unsigned char * bytes, int len) {
@@ -260,14 +268,14 @@ void probe_get_luminosity(int busno, char * write_mode, char * read_mode) {
       free_ddc_packet(request_packet_ptr);
       return;
    }
-   rc = i2c_set_addr(file, 0x37, CALLOPT_ERR_MSG);
+   rc = local_set_addr(file, 0x37);
    if (rc < 0) {
       free_ddc_packet(request_packet_ptr);
       goto bye;
    }
    assert(rc == 0);    // CALLOPT_ERR_ABORT was set
    // usleep(DEFAULT_TIMEOUT);
-   sleep_millis_with_tracex(DDC_TIMEOUT_MILLIS_DEFAULT, __func__, __LINE__, __FILE__, NULL);
+   sleep_millis_with_trace(DDC_TIMEOUT_MILLIS_DEFAULT, __func__, __LINE__, __FILE__, NULL);
 
    printf("(%s) calling perform_write()\n", __func__);
    set_i2c_write_mode(write_mode);
