@@ -1,14 +1,14 @@
 /** @file hiddev_util.h
  */
 
-// Copyright (C) 2016-2020 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2016-2021 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 
 #ifndef HIDDEV_UTIL_H_
 #define HIDDEV_UTIL_H_
 
-#include <glib.h>
+#include <glib-2.0/glib.h>
 #include <linux/hiddev.h>
 // so callers will have definition of strerror() used in REPORT_IOCTL_ERROR macro:
 #include <string.h>
