@@ -1,4 +1,4 @@
-/** \file edid.c
+/** @file edid.c
  *
  *  Functions to interpret the EDID data structure, irrespective of how
  *  the bytes of the EDID are obtained.
@@ -20,6 +20,7 @@
 #include <string.h>
 /** \endcond */
 
+#include "pnp_ids.h"
 #include "report_util.h"
 #include "string_util.h"
 
@@ -28,16 +29,6 @@
 
 // Direct writes to stdout/stderr: NO
 
-#ifdef UNUSED
-static inline bool all_bytes_zero(Byte * bytes, int len) {
-   for (int ndx = 0; ndx < len; ndx++) {
-      if (bytes[ndx])
-         return false;
-   }
-   return true;
-}
-#endif
-
 
 /** Calculates checksum for a 128 byte EDID
  *
@@ -55,10 +46,12 @@ Byte edid_checksum(Byte * edid) {
    return checksum;
 }
 
+
 bool is_valid_edid_checksum(Byte * edidbytes) {
    return (edid_checksum(edidbytes) == 0);
 }
 
+
 bool is_valid_edid_header(Byte * edidbytes) {
    bool debug = false;
    bool result = true;
@@ -80,10 +73,9 @@ bool is_valid_raw_edid(Byte * edid, int len) {
    return (len >= 128) && is_valid_edid_header(edid) && is_valid_edid_checksum(edid);
 }
 
-bool is_valid_raw_cea861_extension_block(Byte * edid, int len) {
-   bool result = len >= 128 && edid[0] == 0x02 && is_valid_edid_checksum(edid);
 
-   return result;
+bool is_valid_raw_cea861_extension_block(Byte * edid, int len) {
+   return (len >= 128) && edid[0] == 0x02 && is_valid_edid_checksum(edid);
 }
 
 
@@ -121,7 +113,6 @@ void parse_mfg_id_in_buffer(Byte * mfg_id_bytes, char * result, int bufsize) {
  *  @param  bufsize      buffer size (must be >= 4)
  */
 void get_edid_mfg_id_in_buffer(Byte* edidbytes, char * result, int bufsize) {
-   // parse_mfg_id_in_buffer(&edidbytes[8], result, bufsize);
    parse_mfg_id_in_buffer(edidbytes+8, result, bufsize);
 }
 
@@ -198,13 +189,12 @@ static void get_edid_descriptor_strings(
             Byte * textstart = descriptor+5;
             // DBGMSF(debug, "String in descriptor: %s", hexstring(textstart, 14));
             int    offset = 0;
-            while (*(textstart+offset) != 0x0a && offset < 13) {
-               // DBGMSG("textlen=%d, char=0x%02x", textlen, *(textstart+textlen));
-               nameslot[offset] = *(textstart+offset);
+            while (textstart[offset] != 0x0a && offset < 13) {
+               nameslot[offset] = textstart[offset];
                offset++;
             }
-            // memcpy(nameslot, textstart, offset);
             nameslot[offset] = '\0';
+            rtrim_in_place(nameslot);   // handle no terminating LF but blank padded
             if (debug)
                printf("(%s) name = %s\n", __func__, nameslot);
 
@@ -226,9 +216,6 @@ static void get_edid_descriptor_strings(
 Parsed_Edid * create_parsed_edid(Byte* edidbytes) {
    assert(edidbytes);
    // bool debug = false;
-#ifdef UNNEEDED
-   bool ok = true;
-#endif
    Parsed_Edid* parsed_edid = NULL;
 
    if ( !is_valid_edid_header(edidbytes) || !is_valid_edid_checksum(edidbytes) )
@@ -262,12 +249,6 @@ Parsed_Edid * create_parsed_edid(Byte* edidbytes) {
    parsed_edid->is_model_year = edidbytes[16] == 0xff;
    parsed_edid->manufacture_week = edidbytes[16];
    parsed_edid->edid_version_major = edidbytes[18];
-#ifdef UNNEEDED
-   if (parsed_edid->edid_version_major != 1 && parsed_edid->edid_version_major != 2) {
-      DBGMSF(debug, "Invalid EDID major version number: %d", parsed_edid->edid_version_major);
-      ok = false;
-   }
-#endif
    parsed_edid->edid_version_minor = edidbytes[19];
 
    parsed_edid->rx = edidbytes[0x1b] << 2 | ( (edidbytes[0x19]&0b11000000)>>6 );
@@ -288,18 +269,31 @@ Parsed_Edid * create_parsed_edid(Byte* edidbytes) {
    parsed_edid->supported_features = edidbytes[0x18];
    parsed_edid->extension_flag = edidbytes[0x7e];
 
-#ifdef UNNEEDED
-   if (!ok) {
-      free(parsed_edid);
-      parsed_edid = NULL;
-   }
-#endif
-
 bye:
    return parsed_edid;
 }
 
 
+/** Parses an EDID and sets the edid_source field.
+ *
+ * @param edidbytes   pointer to 128 byte EDID block
+ * @param source      source of EDID, typically I2C but may be X11,
+ *                    USB, SYSFS, DRM
+ *
+ * @return pointer to newly allocated Parsed_Edid struct,
+ *         or NULL if the bytes could not be parsed.
+ *         It is the responsibility of the caller to free this memory.
+ */
+Parsed_Edid * create_parsed_edid2(Byte* edidbytes, char * source) {
+   Parsed_Edid * edid = create_parsed_edid(edidbytes);
+   if (edid) {
+      assert(source && strlen(source) < EDID_SOURCE_FIELD_SIZE);
+      STRLCPY(edid->edid_source, source, EDID_SOURCE_FIELD_SIZE);
+   }
+   return edid;
+}
+
+
 /** Frees a Parsed_Edid struct.
  *
  * @param  parsed_edid  pointer to Parsed_Edid struct to free
@@ -332,17 +326,17 @@ void report_parsed_edid_base(
 {
    bool debug = false;
    if (debug)
-      printf("(%s) Starting. edid=%p", __func__, edid);
+      printf("(%s) Starting. edid=%p", __func__, (void*)edid);
 
    int d1 = depth+1;
    int d2 = depth+2;
    // verbose = true;
    if (edid) {
       rpt_vstring(depth,"EDID synopsis:");
-      rpt_vstring(d1,"Mfg id:               %s",          edid->mfg_id);
+      rpt_vstring(d1,"Mfg id:               %s - %s",     edid->mfg_id, pnp_name(edid->mfg_id));
       rpt_vstring(d1,"Model:                %s",          edid->model_name);
-   // rpt_vstring(d1,"Product code:         0x%04x (%u)", edid->product_code, edid->product_code);
-      rpt_vstring(d1,"Product code:         %u",          edid->product_code);
+      rpt_vstring(d1,"Product code:         %u  (0x%04x)", edid->product_code, edid->product_code);
+   // rpt_vstring(d1,"Product code:         %u",          edid->product_code);
       rpt_vstring(d1,"Serial number:        %s",          edid->serial_ascii);
       // Binary serial number is typically 0x00000000 or 0x01010101, but occasionally
       // useful for differentiating displays that share a generic ASCII "serial number"
