@@ -187,8 +187,8 @@ file_get_first_line(
  *  \param  fn        file name
  *  \param  est_size  estimated size
  *  \param  verbose   if open fails, write message to stderr
- *  \return if successful, a **GByteArray** of bytes, caller is responsible for freeing
- *          if failure, then NULL
+ *  \return if file opened, a **GByteArray** of bytes (may be 0 lengh), caller is responsible for freeing
+ *          if file cannot be opened, then NULL
  */
 GByteArray *
 read_binary_file(
@@ -200,7 +200,7 @@ read_binary_file(
 
    bool debug = false;
    if (debug)
-      printf("(%s) fn=%s,est_size=%d\n", __func__, fn, est_size);
+      printf("(%s) Starting. fn=%s,est_size=%d\n", __func__, fn, est_size);
 
    Byte  buf[1];
 
@@ -232,7 +232,8 @@ bye:
    // printf("(%s) bye\n", __func__);
    if (debug) {
       if (gbarray)
-         printf("(%s) Returning GByteArray of size %d\n", __func__, gbarray->len);
+         printf("(%s) Done. Returning GByteArray at %p, gbarray->data=%p, gbarray->len=%d\n",
+                __func__, (void*)gbarray, (void*)gbarray->data, gbarray->len);
       else
          printf("(%s) Returning NULL\n", __func__);
    }
@@ -440,7 +441,7 @@ dir_ordered_foreach(
         void *                accumulator,
         int                   depth)
 {
-   GPtrArray * simple_filenames = g_ptr_array_new();
+   GPtrArray * simple_filenames = g_ptr_array_new_with_free_func(g_free);
 
    struct dirent *dent;
    DIR           *d;
@@ -469,6 +470,61 @@ dir_ordered_foreach(
          func(dirname, fn, accumulator, depth);
       }
    }
+   g_ptr_array_free(simple_filenames, true);
+}
+
+
+void
+dir_ordered_foreach_with_arg(
+        const char *          dirname,
+        Filename_Filter_Func_With_Arg
+                              fn_filter,
+        const char *          fn_filter_argument,
+        GCompareFunc          compare_func,
+        Dir_Foreach_Func      func,
+        void *                accumulator,
+        int                   depth)
+{
+   bool debug = false;
+   if (debug)
+      printf("(%s) Starting. dirname=%s, fn_filter_argument=|%s|\n", __func__, dirname, fn_filter_argument);
+   GPtrArray * simple_filenames = g_ptr_array_new_with_free_func(g_free);
+
+   struct dirent *dent;
+   DIR           *d;
+   d = opendir(dirname);
+   if (!d) {
+      rpt_vstring(depth,"Unable to open directory %s: %s", dirname, strerror(errno));
+   }
+   else {
+      while ((dent = readdir(d)) != NULL) {
+         if (debug)
+            printf("(%s) %s\n", __func__, dent->d_name);
+         if (!streq(dent->d_name, ".") && !streq(dent->d_name, "..") ) {
+            if (!fn_filter || fn_filter(dent->d_name, fn_filter_argument)) {
+               if (debug)
+                  printf("(%s) Adding simple filename |%s|\n", __func__, dent->d_name);
+               g_ptr_array_add(simple_filenames, strdup(dent->d_name));
+            }
+         }
+      }
+      closedir(d);
+
+      if (compare_func)
+         g_ptr_array_sort(simple_filenames, compare_func);
+      else
+         g_ptr_array_sort(simple_filenames, indirect_strcmp);
+
+      for (int ndx = 0; ndx < simple_filenames->len; ndx++) {
+         char * fn = g_ptr_array_index(simple_filenames, ndx);
+         if (debug)
+            printf("(%s) Calling Dir_Foreach_Func, dirname=%s, fn=%s\n", __func__, dirname, fn);
+         func(dirname, fn, accumulator, depth);
+      }
+      g_ptr_array_free(simple_filenames, true);
+   }
+   if (debug)
+      printf("(%s) Done.\n", __func__);
 }
 
 
@@ -526,8 +582,6 @@ dir_filtered_ordered_foreach(
 }
 
 
-
-
 /** Reads the contents of a file into a #GPtrArray of lines, optionally keeping only
  *  those lines containing at least one in a list of terms.  After filtering, the set
  *  of returned lines may be further reduced to either the first or last N number of
@@ -562,7 +616,7 @@ int read_file_with_filter(
    bool debug = false;
    if (debug) {
       printf("(%s) line_array=%p, fn=%s, ct(filter_terms)=%d, ignore_case=%s, limit=%d\n",
-             __func__, line_array, fn, ntsa_length(filter_terms), sbool(ignore_case), limit);
+             __func__, (void*)line_array, fn, ntsa_length(filter_terms), sbool(ignore_case), limit);
       if (ntsa_length(filter_terms) > 0) {
          printf("(%s) filter_terms:\n", __func__);
          for (char ** term_ptr = filter_terms; *term_ptr; term_ptr++)
@@ -710,7 +764,7 @@ int fopen_mkdir(
 {
    bool debug = false;
    if (debug)
-      printf("(%s) Starting. path=%s, mode=%s, fp_loc=%p\n", __func__, path, mode, fp_loc);
+      printf("(%s) Starting. path=%s, mode=%s, fp_loc=%p\n", __func__, path, mode, (void*)fp_loc);
 
    int rc = 0;
    *fp_loc = NULL;
