@@ -1,8 +1,8 @@
-/** \file sysfs_i2c_util.h
+/** @file sysfs_i2c_util.h
  *  i2c specific /sys functions
  */
 
-// Copyright (C) 2020-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2020-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef SYSFS_I2C_UTIL_H_
@@ -32,10 +32,12 @@ bool
 sysfs_is_ignorable_i2c_device(
       int busno);
 
+#ifdef UNUSED
 int
 get_sysfs_drm_edid_count();
+#endif
 
-Byte_Bit_Flags
+Bit_Set_256
 get_sysfs_drm_card_numbers();
 
 #endif /* SYSFS_I2C_UTIL_H_ */
