@@ -3,7 +3,7 @@
   * Functions for reading /sys file system
   */
 
-// Copyright (C) 2016-2021 Sanford Rockowitz <rockowitz@minsoft.com>
+// Copyright (C) 2016-2022 Sanford Rockowitz <rockowitz@minsoft.com>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
 //* \cond */
@@ -261,7 +261,7 @@ get_single_subdir_name(
    DIR* dir2 = opendir(dirname);
    char * result = NULL;
    if (!dir2) {
-      rpt_vstring(d1, "Unexpected error. Unable to open sysfs directory %s: %s\n",
+      rpt_vstring(d1, "Unexpected error. Unable to open sysfs directory %s: %s",
                       dirname, strerror(errno));
      }
      else {
@@ -300,9 +300,13 @@ assemble_sysfs_path2(
 {
    assert(buffer && bufsz > 0);
    bool debug = false;
+   if (debug)
+      printf("(%s) Starting.  bufsz=%d, fn_segment=|%s|\n", __func__, bufsz, fn_segment);
    STRLCPY(buffer, fn_segment, bufsz-1);
    while(true) {
       char * segment = va_arg(ap, char*);
+      if (debug)
+         printf("(%s) segment |%s|\n", __func__, segment);
       if (!segment)
          break;
       STRLCAT(buffer, "/", bufsz);
@@ -368,6 +372,9 @@ rpt_attr_text(
 
   if (debug)
      printf("(%s) Done.\n", __func__);
+
+  if (value_loc)
+     ASSERT_IFF(found, *value_loc);
   return found;
 }
 
@@ -377,7 +384,7 @@ rpt_attr_text(
  *  \param  depth      logical indentation depth, if < 0, output nothing
  *  \param  value_loc  if non-NULL, the address at which to return a pointer to
  *                     a GByteArray containing the value. (caller is responsible for freeing).
- *                     If the attribute cannot be read NULL is returned.
+ *                     If the attribute cannot be read, or is 0 length, NULL is returned.
  *  \param  fn_segment first segment of attribute name
  *  \param  ap         remaining segments of name
  *  \return true if attribute found, false if not
@@ -392,6 +399,13 @@ rpt_attr_binary(
       const char *  fn_segment,
       ...)
 {
+   bool debug = false;
+   if (debug) {
+      printf("(%s) Starting.  depth=%d, value_loc=%p\n", __func__, depth, value_loc);
+      if (debug && depth < 0)
+         depth=1;
+   }
+
    char pb1[PATH_MAX];
    va_list ap;
    va_start(ap, fn_segment);
@@ -402,17 +416,27 @@ rpt_attr_binary(
    if (value_loc)
       *value_loc = NULL;
    GByteArray * bytes = read_binary_file(pb1, /*estimated size=*/ 256, true);
-   if (bytes && bytes->len > 0) {
-      found = true;
-      rpt_attr_output(depth, pb1, ":", "Found");
-      // rpt_vstring(depth, "%-*s =  %s", offset, pb1, val);
-      if (value_loc)
-         *value_loc = bytes;
-      else
+   if (bytes) {
+      if (bytes->len > 0) {
+         found = true;
+         rpt_attr_output(depth, pb1, ":", "Found");
+         // rpt_vstring(depth, "%-*s =  %s", offset, pb1, val);
+         if (value_loc)
+            *value_loc = bytes;
+      }
+      else {
          g_byte_array_free(bytes, true);
+         rpt_attr_output(depth, pb1, ": ", "0 length");
+      }
    }
    else
       rpt_attr_output(depth, pb1, ": ", "Not Found");
+   if (debug) {
+      if (value_loc)
+         printf("(%s) Returning: %s. *value_loc=%p\n", __func__, SBOOL(found), (void*)*value_loc);
+      else
+         printf("(%s) Returning: %s\n", __func__, SBOOL(found));
+   }
    return found;
 }
 
@@ -422,7 +446,7 @@ rpt_attr_binary(
  *  \param  depth      logical indentation depth, if < 0, output nothing
  *  \param  value_loc  if non-NULL, the address at which to return a pointer to
  *                     a GByteArray containing the value. (caller is responsible for freeing).
- *                     If the attribute cannot be read NULL is returned.
+ *                     If the attribute cannot be read NULL is set.
  *  \param  fn_segment first segment of attribute name
  *  \param  ...        remaining segments of name
  *  \return true if attribute found, false if not
@@ -437,6 +461,13 @@ rpt_attr_edid(
        const char *  fn_segment,
        ...)
  {
+    bool debug = false;
+    if (debug) {
+       printf("(%s) Starting.  depth=%d, value_loc=%p\n", __func__, depth, value_loc);
+       if (debug && depth < 0)
+          depth=1;
+    }
+
     char pb1[PATH_MAX];
     va_list ap;
     va_start(ap, fn_segment);
@@ -449,8 +480,8 @@ rpt_attr_edid(
        *value_loc = NULL;
     GByteArray * edid = NULL;
     found = rpt_attr_binary(depth, &edid, pb1, NULL);
+    assert( (found && edid) || (!found && edid==NULL) );
     if (edid) {
-       assert(found);
        if (depth >= 0)
           rpt_hex_dump(edid->data, edid->len, depth+4);
        if (value_loc)
@@ -460,6 +491,17 @@ rpt_attr_edid(
        }
     }
 
+    if (debug) {
+       printf("(%s) Returning %s. *value_loc=%p\n", __func__, SBOOL(found), *value_loc);
+       if (*value_loc) {
+          GByteArray * gba = *value_loc;
+          printf("(%s)               data=%p, len=%d\n",
+                 __func__, (void*) gba->data, gba->len);
+       }
+    }
+
+    if (value_loc)
+       ASSERT_IFF(found, *value_loc);
     return found;
  }
 
@@ -506,6 +548,9 @@ rpt_attr_realpath(
    else {
       rpt_attr_output(depth, pb1, "->", "Invalid path");
    }
+
+   if (value_loc)
+      ASSERT_IFF(found, *value_loc);
    return found;
 }
 
@@ -554,13 +599,15 @@ rpt_attr_realpath_basename(
    if (!found) {
       rpt_attr_output(depth, pb1, "->", "Invalid path");
    }
+
+   if (value_loc)
+      ASSERT_IFF(found, *value_loc);
    return found;
 }
 
 
 /** Checks for the first subdirectory of a given directory whose name satisfies
  *  some predicate, and reports whether it is found and if so its name.
- *  is invalid.
  *
  *  \param  depth      logical indentation depth, if < 0, output nothing
  *  \param  value_loc  if non-NULL, the address at which to return a pointer to
@@ -586,7 +633,7 @@ rpt_attr_single_subdir(
 {
    bool debug = false;
    if (debug)
-      printf("(%s) Starting. depth=%d, value_loc=%p\n", __func__, depth, value_loc);
+      printf("(%s) Starting. depth=%d, value_loc=%p\n", __func__, depth, (void*)value_loc);
 
    char pb1[PATH_MAX];
    va_list ap;
@@ -617,6 +664,9 @@ rpt_attr_single_subdir(
    }
    if (debug)
       printf("(%s) Done.    Returning %s\n", __func__, SBOOL(found));
+
+   if (value_loc)
+      ASSERT_IFF(found, *value_loc);
    return found;
 }
 
